Class: Google::Apis::DriveV3::App

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

The apps resource provides a list of apps that a user has installed, with information about each app's supported MIME types, file extensions, and other details. Some resource methods (such as apps.get) require an appId. Use the apps.list method to retrieve the ID for an installed application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ App

Returns a new instance of App.



477
478
479
# File 'lib/google/apis/drive_v3/classes.rb', line 477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorizedBoolean Also known as: authorized?

Whether the app is authorized to access data on the user's Drive. Corresponds to the JSON property authorized

Returns:

  • (Boolean)


345
346
347
# File 'lib/google/apis/drive_v3/classes.rb', line 345

def authorized
  @authorized
end

#create_in_folder_templateString

The template URL to create a file with this app in a given folder. The template contains the folderId to be replaced by the folder ID house the new file. Corresponds to the JSON property createInFolderTemplate

Returns:

  • (String)


353
354
355
# File 'lib/google/apis/drive_v3/classes.rb', line 353

def create_in_folder_template
  @create_in_folder_template
end

#create_urlString

The URL to create a file with this app. Corresponds to the JSON property createUrl

Returns:

  • (String)


358
359
360
# File 'lib/google/apis/drive_v3/classes.rb', line 358

def create_url
  @create_url
end

#has_drive_wide_scopeBoolean Also known as: has_drive_wide_scope?

Whether the app has Drive-wide scope. An app with Drive-wide scope can access all files in the user's Drive. Corresponds to the JSON property hasDriveWideScope

Returns:

  • (Boolean)


364
365
366
# File 'lib/google/apis/drive_v3/classes.rb', line 364

def has_drive_wide_scope
  @has_drive_wide_scope
end

#iconsArray<Google::Apis::DriveV3::AppIcons>

The various icons for the app. Corresponds to the JSON property icons



370
371
372
# File 'lib/google/apis/drive_v3/classes.rb', line 370

def icons
  @icons
end

#idString

The ID of the app. Corresponds to the JSON property id

Returns:

  • (String)


375
376
377
# File 'lib/google/apis/drive_v3/classes.rb', line 375

def id
  @id
end

#installedBoolean Also known as: installed?

Whether the app is installed. Corresponds to the JSON property installed

Returns:

  • (Boolean)


380
381
382
# File 'lib/google/apis/drive_v3/classes.rb', line 380

def installed
  @installed
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "drive#app". Corresponds to the JSON property kind

Returns:

  • (String)


387
388
389
# File 'lib/google/apis/drive_v3/classes.rb', line 387

def kind
  @kind
end

#long_descriptionString

A long description of the app. Corresponds to the JSON property longDescription

Returns:

  • (String)


392
393
394
# File 'lib/google/apis/drive_v3/classes.rb', line 392

def long_description
  @long_description
end

#nameString

The name of the app. Corresponds to the JSON property name

Returns:

  • (String)


397
398
399
# File 'lib/google/apis/drive_v3/classes.rb', line 397

def name
  @name
end

#object_typeString

The type of object this app creates such as a Chart. If empty, the app name should be used instead. Corresponds to the JSON property objectType

Returns:

  • (String)


403
404
405
# File 'lib/google/apis/drive_v3/classes.rb', line 403

def object_type
  @object_type
end

#open_url_templateString

The template URL for opening files with this app. The template contains ids or exportIds to be replaced by the actual file IDs. For more information, see Open Files for the full documentation. Corresponds to the JSON property openUrlTemplate

Returns:

  • (String)


410
411
412
# File 'lib/google/apis/drive_v3/classes.rb', line 410

def open_url_template
  @open_url_template
end

#primary_file_extensionsArray<String>

The list of primary file extensions. Corresponds to the JSON property primaryFileExtensions

Returns:

  • (Array<String>)


415
416
417
# File 'lib/google/apis/drive_v3/classes.rb', line 415

def primary_file_extensions
  @primary_file_extensions
end

#primary_mime_typesArray<String>

The list of primary MIME types. Corresponds to the JSON property primaryMimeTypes

Returns:

  • (Array<String>)


420
421
422
# File 'lib/google/apis/drive_v3/classes.rb', line 420

def primary_mime_types
  @primary_mime_types
end

#product_idString

The ID of the product listing for this app. Corresponds to the JSON property productId

Returns:

  • (String)


425
426
427
# File 'lib/google/apis/drive_v3/classes.rb', line 425

def product_id
  @product_id
end

#product_urlString

A link to the product listing for this app. Corresponds to the JSON property productUrl

Returns:

  • (String)


430
431
432
# File 'lib/google/apis/drive_v3/classes.rb', line 430

def product_url
  @product_url
end

#secondary_file_extensionsArray<String>

The list of secondary file extensions. Corresponds to the JSON property secondaryFileExtensions

Returns:

  • (Array<String>)


435
436
437
# File 'lib/google/apis/drive_v3/classes.rb', line 435

def secondary_file_extensions
  @secondary_file_extensions
end

#secondary_mime_typesArray<String>

The list of secondary MIME types. Corresponds to the JSON property secondaryMimeTypes

Returns:

  • (Array<String>)


440
441
442
# File 'lib/google/apis/drive_v3/classes.rb', line 440

def secondary_mime_types
  @secondary_mime_types
end

#short_descriptionString

A short description of the app. Corresponds to the JSON property shortDescription

Returns:

  • (String)


445
446
447
# File 'lib/google/apis/drive_v3/classes.rb', line 445

def short_description
  @short_description
end

#supports_createBoolean Also known as: supports_create?

Whether this app supports creating objects. Corresponds to the JSON property supportsCreate

Returns:

  • (Boolean)


450
451
452
# File 'lib/google/apis/drive_v3/classes.rb', line 450

def supports_create
  @supports_create
end

#supports_importBoolean Also known as: supports_import?

Whether this app supports importing from Google Docs. Corresponds to the JSON property supportsImport

Returns:

  • (Boolean)


456
457
458
# File 'lib/google/apis/drive_v3/classes.rb', line 456

def supports_import
  @supports_import
end

#supports_multi_openBoolean Also known as: supports_multi_open?

Whether this app supports opening more than one file. Corresponds to the JSON property supportsMultiOpen

Returns:

  • (Boolean)


462
463
464
# File 'lib/google/apis/drive_v3/classes.rb', line 462

def supports_multi_open
  @supports_multi_open
end

#supports_offline_createBoolean Also known as: supports_offline_create?

Whether this app supports creating files when offline. Corresponds to the JSON property supportsOfflineCreate

Returns:

  • (Boolean)


468
469
470
# File 'lib/google/apis/drive_v3/classes.rb', line 468

def supports_offline_create
  @supports_offline_create
end

#use_by_defaultBoolean Also known as: use_by_default?

Whether the app is selected as the default handler for the types it supports. Corresponds to the JSON property useByDefault

Returns:

  • (Boolean)


474
475
476
# File 'lib/google/apis/drive_v3/classes.rb', line 474

def use_by_default
  @use_by_default
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
# File 'lib/google/apis/drive_v3/classes.rb', line 482

def update!(**args)
  @authorized = args[:authorized] if args.key?(:authorized)
  @create_in_folder_template = args[:create_in_folder_template] if args.key?(:create_in_folder_template)
  @create_url = args[:create_url] if args.key?(:create_url)
  @has_drive_wide_scope = args[:has_drive_wide_scope] if args.key?(:has_drive_wide_scope)
  @icons = args[:icons] if args.key?(:icons)
  @id = args[:id] if args.key?(:id)
  @installed = args[:installed] if args.key?(:installed)
  @kind = args[:kind] if args.key?(:kind)
  @long_description = args[:long_description] if args.key?(:long_description)
  @name = args[:name] if args.key?(:name)
  @object_type = args[:object_type] if args.key?(:object_type)
  @open_url_template = args[:open_url_template] if args.key?(:open_url_template)
  @primary_file_extensions = args[:primary_file_extensions] if args.key?(:primary_file_extensions)
  @primary_mime_types = args[:primary_mime_types] if args.key?(:primary_mime_types)
  @product_id = args[:product_id] if args.key?(:product_id)
  @product_url = args[:product_url] if args.key?(:product_url)
  @secondary_file_extensions = args[:secondary_file_extensions] if args.key?(:secondary_file_extensions)
  @secondary_mime_types = args[:secondary_mime_types] if args.key?(:secondary_mime_types)
  @short_description = args[:short_description] if args.key?(:short_description)
  @supports_create = args[:supports_create] if args.key?(:supports_create)
  @supports_import = args[:supports_import] if args.key?(:supports_import)
  @supports_multi_open = args[:supports_multi_open] if args.key?(:supports_multi_open)
  @supports_offline_create = args[:supports_offline_create] if args.key?(:supports_offline_create)
  @use_by_default = args[:use_by_default] if args.key?(:use_by_default)
end