Class: Google::Apis::DriveV3::Approval
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::Approval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Metadata for an approval. An approval is a review or approve process for a Drive item.
Instance Attribute Summary collapse
-
#approval_id ⇒ String
The approval ID.
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#due_time ⇒ String
The time that the approval is due.
-
#initiator ⇒ Google::Apis::DriveV3::User
Information about a Drive user.
-
#kind ⇒ String
This is always drive#approval.
-
#modify_time ⇒ String
Output only.
-
#reviewer_responses ⇒ Array<Google::Apis::DriveV3::ReviewerResponse>
The responses made on the approval by reviewers.
-
#status ⇒ String
Output only.
-
#target_file_id ⇒ String
Target file id of the approval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Approval
constructor
A new instance of Approval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Approval
Returns a new instance of Approval.
639 640 641 |
# File 'lib/google/apis/drive_v3/classes.rb', line 639 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_id ⇒ String
The approval ID.
Corresponds to the JSON property approvalId
591 592 593 |
# File 'lib/google/apis/drive_v3/classes.rb', line 591 def approval_id @approval_id end |
#complete_time ⇒ String
Output only. The time the approval was completed.
Corresponds to the JSON property completeTime
596 597 598 |
# File 'lib/google/apis/drive_v3/classes.rb', line 596 def complete_time @complete_time end |
#create_time ⇒ String
Output only. The time the approval was created.
Corresponds to the JSON property createTime
601 602 603 |
# File 'lib/google/apis/drive_v3/classes.rb', line 601 def create_time @create_time end |
#due_time ⇒ String
The time that the approval is due.
Corresponds to the JSON property dueTime
606 607 608 |
# File 'lib/google/apis/drive_v3/classes.rb', line 606 def due_time @due_time end |
#initiator ⇒ Google::Apis::DriveV3::User
Information about a Drive user.
Corresponds to the JSON property initiator
611 612 613 |
# File 'lib/google/apis/drive_v3/classes.rb', line 611 def initiator @initiator end |
#kind ⇒ String
This is always drive#approval.
Corresponds to the JSON property kind
616 617 618 |
# File 'lib/google/apis/drive_v3/classes.rb', line 616 def kind @kind end |
#modify_time ⇒ String
Output only. The most recent time the approval was modified.
Corresponds to the JSON property modifyTime
621 622 623 |
# File 'lib/google/apis/drive_v3/classes.rb', line 621 def modify_time @modify_time end |
#reviewer_responses ⇒ Array<Google::Apis::DriveV3::ReviewerResponse>
The responses made on the approval by reviewers.
Corresponds to the JSON property reviewerResponses
626 627 628 |
# File 'lib/google/apis/drive_v3/classes.rb', line 626 def reviewer_responses @reviewer_responses end |
#status ⇒ String
Output only. The status of the approval at the time this resource was
requested.
Corresponds to the JSON property status
632 633 634 |
# File 'lib/google/apis/drive_v3/classes.rb', line 632 def status @status end |
#target_file_id ⇒ String
Target file id of the approval.
Corresponds to the JSON property targetFileId
637 638 639 |
# File 'lib/google/apis/drive_v3/classes.rb', line 637 def target_file_id @target_file_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
644 645 646 647 648 649 650 651 652 653 654 655 |
# File 'lib/google/apis/drive_v3/classes.rb', line 644 def update!(**args) @approval_id = args[:approval_id] if args.key?(:approval_id) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @due_time = args[:due_time] if args.key?(:due_time) @initiator = args[:initiator] if args.key?(:initiator) @kind = args[:kind] if args.key?(:kind) @modify_time = args[:modify_time] if args.key?(:modify_time) @reviewer_responses = args[:reviewer_responses] if args.key?(:reviewer_responses) @status = args[:status] if args.key?(:status) @target_file_id = args[:target_file_id] if args.key?(:target_file_id) end |