Class: Google::Apis::DriveV3::ApprovalList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::ApprovalList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
The response of an approvals list request.
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::DriveV3::Approval>
The list of approvals.
-
#kind ⇒ String
This is always drive#approvalList Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
The page token for the next page of approvals.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApprovalList
constructor
A new instance of ApprovalList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApprovalList
Returns a new instance of ApprovalList.
687 688 689 |
# File 'lib/google/apis/drive_v3/classes.rb', line 687 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::DriveV3::Approval>
The list of approvals. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property items
672 673 674 |
# File 'lib/google/apis/drive_v3/classes.rb', line 672 def items @items end |
#kind ⇒ String
This is always drive#approvalList
Corresponds to the JSON property kind
677 678 679 |
# File 'lib/google/apis/drive_v3/classes.rb', line 677 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of approvals. This is absent if the end of
the approvals list has been reached. If the token is rejected for any reason,
it should be discarded, and pagination should be restarted from the first page
of results.
Corresponds to the JSON property nextPageToken
685 686 687 |
# File 'lib/google/apis/drive_v3/classes.rb', line 685 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
692 693 694 695 696 |
# File 'lib/google/apis/drive_v3/classes.rb', line 692 def update!(**args) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |