Class: Google::Apis::DriveV3::CancelApprovalRequest
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::CancelApprovalRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Request for cancelling an approval as an initiator.
Instance Attribute Summary collapse
-
#message ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CancelApprovalRequest
constructor
A new instance of CancelApprovalRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CancelApprovalRequest
Returns a new instance of CancelApprovalRequest.
731 732 733 |
# File 'lib/google/apis/drive_v3/classes.rb', line 731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ String
Optional. A message to accompany the cancellation of the approval. This
message is included in notifications for the action and in the approval
activity log.
Corresponds to the JSON property message
729 730 731 |
# File 'lib/google/apis/drive_v3/classes.rb', line 729 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
736 737 738 |
# File 'lib/google/apis/drive_v3/classes.rb', line 736 def update!(**args) @message = args[:message] if args.key?(:message) end |