Class: Google::Apis::DriveV3::Change

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A change to a file or shared drive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Change

Returns a new instance of Change.



806
807
808
# File 'lib/google/apis/drive_v3/classes.rb', line 806

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_typeString

The type of the change. Possible values are file and drive. Corresponds to the JSON property changeType

Returns:

  • (String)


748
749
750
# File 'lib/google/apis/drive_v3/classes.rb', line 748

def change_type
  @change_type
end

#driveGoogle::Apis::DriveV3::Drive

Representation of a shared drive. Some resource methods (such as drives. update) require a driveId. Use the drives.list method to retrieve the ID for a shared drive. Corresponds to the JSON property drive



755
756
757
# File 'lib/google/apis/drive_v3/classes.rb', line 755

def drive
  @drive
end

#drive_idString

The ID of the shared drive associated with this change. Corresponds to the JSON property driveId

Returns:

  • (String)


760
761
762
# File 'lib/google/apis/drive_v3/classes.rb', line 760

def drive_id
  @drive_id
end

#fileGoogle::Apis::DriveV3::File

The metadata for a file. Some resource methods (such as files.update) require a fileId. Use the files.list method to retrieve the ID for a file. Corresponds to the JSON property file



766
767
768
# File 'lib/google/apis/drive_v3/classes.rb', line 766

def file
  @file
end

#file_idString

The ID of the file which has changed. Corresponds to the JSON property fileId

Returns:

  • (String)


771
772
773
# File 'lib/google/apis/drive_v3/classes.rb', line 771

def file_id
  @file_id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "drive# change". Corresponds to the JSON property kind

Returns:

  • (String)


777
778
779
# File 'lib/google/apis/drive_v3/classes.rb', line 777

def kind
  @kind
end

#removedBoolean Also known as: removed?

Whether the file or shared drive has been removed from this list of changes, for example by deletion or loss of access. Corresponds to the JSON property removed

Returns:

  • (Boolean)


783
784
785
# File 'lib/google/apis/drive_v3/classes.rb', line 783

def removed
  @removed
end

#team_driveGoogle::Apis::DriveV3::TeamDrive

Deprecated: use the drive collection instead. Next ID: 33 Corresponds to the JSON property teamDrive



789
790
791
# File 'lib/google/apis/drive_v3/classes.rb', line 789

def team_drive
  @team_drive
end

#team_drive_idString

Deprecated: Use driveId instead. Corresponds to the JSON property teamDriveId

Returns:

  • (String)


794
795
796
# File 'lib/google/apis/drive_v3/classes.rb', line 794

def team_drive_id
  @team_drive_id
end

#timeDateTime

The time of this change (RFC 3339 date-time). Corresponds to the JSON property time

Returns:

  • (DateTime)


799
800
801
# File 'lib/google/apis/drive_v3/classes.rb', line 799

def time
  @time
end

#typeString

Deprecated: Use changeType instead. Corresponds to the JSON property type

Returns:

  • (String)


804
805
806
# File 'lib/google/apis/drive_v3/classes.rb', line 804

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/google/apis/drive_v3/classes.rb', line 811

def update!(**args)
  @change_type = args[:change_type] if args.key?(:change_type)
  @drive = args[:drive] if args.key?(:drive)
  @drive_id = args[:drive_id] if args.key?(:drive_id)
  @file = args[:file] if args.key?(:file)
  @file_id = args[:file_id] if args.key?(:file_id)
  @kind = args[:kind] if args.key?(:kind)
  @removed = args[:removed] if args.key?(:removed)
  @team_drive = args[:team_drive] if args.key?(:team_drive)
  @team_drive_id = args[:team_drive_id] if args.key?(:team_drive_id)
  @time = args[:time] if args.key?(:time)
  @type = args[:type] if args.key?(:type)
end