Class: Google::Apis::DriveV3::ChangeList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A list of changes for a user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChangeList

Returns a new instance of ChangeList.



855
856
857
# File 'lib/google/apis/drive_v3/classes.rb', line 855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#changesArray<Google::Apis::DriveV3::Change>

The list of changes. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property changes

Returns:



834
835
836
# File 'lib/google/apis/drive_v3/classes.rb', line 834

def changes
  @changes
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "drive# changeList". Corresponds to the JSON property kind

Returns:

  • (String)


840
841
842
# File 'lib/google/apis/drive_v3/classes.rb', line 840

def kind
  @kind
end

#new_start_page_tokenString

The starting page token for future changes. This will be present only if the end of the current changes list has been reached. The page token doesn't expire. Corresponds to the JSON property newStartPageToken

Returns:

  • (String)


847
848
849
# File 'lib/google/apis/drive_v3/classes.rb', line 847

def new_start_page_token
  @new_start_page_token
end

#next_page_tokenString

The page token for the next page of changes. This will be absent if the end of the changes list has been reached. The page token doesn't expire. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


853
854
855
# File 'lib/google/apis/drive_v3/classes.rb', line 853

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



860
861
862
863
864
865
# File 'lib/google/apis/drive_v3/classes.rb', line 860

def update!(**args)
  @changes = args[:changes] if args.key?(:changes)
  @kind = args[:kind] if args.key?(:kind)
  @new_start_page_token = args[:new_start_page_token] if args.key?(:new_start_page_token)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end