Class: Google::Apis::DriveV3::CommentList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::CommentList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of comments on a file.
Instance Attribute Summary collapse
-
#comments ⇒ Array<Google::Apis::DriveV3::Comment>
The list of comments.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The page token for the next page of comments.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommentList
constructor
A new instance of CommentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommentList
Returns a new instance of CommentList.
1070 1071 1072 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comments ⇒ Array<Google::Apis::DriveV3::Comment>
The list of comments. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property comments
1053 1054 1055 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1053 def comments @comments end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
commentList".
Corresponds to the JSON property kind
1059 1060 1061 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1059 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of comments. This will be absent if the end
of the comments list has been reached. If the token is rejected for any reason,
it should be discarded, and pagination should be restarted from the first
page of results. The page token is typically valid for several hours. However,
if new items are added or removed, your expected results might differ.
Corresponds to the JSON property nextPageToken
1068 1069 1070 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1068 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1075 1076 1077 1078 1079 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1075 def update!(**args) @comments = args[:comments] if args.key?(:comments) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |