Class: Google::Apis::DriveV3::ContentRestriction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A restriction for accessing the content of the file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentRestriction

Returns a new instance of ContentRestriction.



1220
1221
1222
# File 'lib/google/apis/drive_v3/classes.rb', line 1220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#owner_restrictedBoolean Also known as: owner_restricted?

Whether the content restriction can only be modified or removed by a user who owns the file. For files in shared drives, any user with organizer capabilities can modify or remove this content restriction. Corresponds to the JSON property ownerRestricted

Returns:

  • (Boolean)


1178
1179
1180
# File 'lib/google/apis/drive_v3/classes.rb', line 1178

def owner_restricted
  @owner_restricted
end

#read_onlyBoolean Also known as: read_only?

Whether the content of the file is read-only. If a file is read-only, a new revision of the file may not be added, comments may not be added or modified, and the title of the file may not be modified. Corresponds to the JSON property readOnly

Returns:

  • (Boolean)


1186
1187
1188
# File 'lib/google/apis/drive_v3/classes.rb', line 1186

def read_only
  @read_only
end

#reasonString

Reason for why the content of the file is restricted. This is only mutable on requests that also set readOnly=true. Corresponds to the JSON property reason

Returns:

  • (String)


1193
1194
1195
# File 'lib/google/apis/drive_v3/classes.rb', line 1193

def reason
  @reason
end

#restricting_userGoogle::Apis::DriveV3::User

Information about a Drive user. Corresponds to the JSON property restrictingUser



1198
1199
1200
# File 'lib/google/apis/drive_v3/classes.rb', line 1198

def restricting_user
  @restricting_user
end

#restriction_timeDateTime

The time at which the content restriction was set (formatted RFC 3339 timestamp). Only populated if readOnly is true. Corresponds to the JSON property restrictionTime

Returns:

  • (DateTime)


1204
1205
1206
# File 'lib/google/apis/drive_v3/classes.rb', line 1204

def restriction_time
  @restriction_time
end

#system_restrictedBoolean Also known as: system_restricted?

Output only. Whether the content restriction was applied by the system, for example due to an esignature. Users cannot modify or remove system restricted content restrictions. Corresponds to the JSON property systemRestricted

Returns:

  • (Boolean)


1211
1212
1213
# File 'lib/google/apis/drive_v3/classes.rb', line 1211

def system_restricted
  @system_restricted
end

#typeString

Output only. The type of the content restriction. Currently the only possible value is globalContentRestriction. Corresponds to the JSON property type

Returns:

  • (String)


1218
1219
1220
# File 'lib/google/apis/drive_v3/classes.rb', line 1218

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1225
1226
1227
1228
1229
1230
1231
1232
1233
# File 'lib/google/apis/drive_v3/classes.rb', line 1225

def update!(**args)
  @owner_restricted = args[:owner_restricted] if args.key?(:owner_restricted)
  @read_only = args[:read_only] if args.key?(:read_only)
  @reason = args[:reason] if args.key?(:reason)
  @restricting_user = args[:restricting_user] if args.key?(:restricting_user)
  @restriction_time = args[:restriction_time] if args.key?(:restriction_time)
  @system_restricted = args[:system_restricted] if args.key?(:system_restricted)
  @type = args[:type] if args.key?(:type)
end