Class: Google::Apis::DriveV3::DeclineApprovalRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Request for declining an approval as a reviewer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeclineApprovalRequest

Returns a new instance of DeclineApprovalRequest.



1247
1248
1249
# File 'lib/google/apis/drive_v3/classes.rb', line 1247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageString

Optional. A message to accompany the reviewer response on the approval. This message is included in notifications for the action and in the approval activity log. Corresponds to the JSON property message

Returns:

  • (String)


1245
1246
1247
# File 'lib/google/apis/drive_v3/classes.rb', line 1245

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1252
1253
1254
# File 'lib/google/apis/drive_v3/classes.rb', line 1252

def update!(**args)
  @message = args[:message] if args.key?(:message)
end