Class: Google::Apis::DriveV3::Drive::BackgroundImageFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

An image file and cropping parameters from which a background image for this shared drive is set. This is a write only field; it can only be set on drive. drives.update requests that don't set themeId. When specified, all fields of the backgroundImageFile must be set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackgroundImageFile

Returns a new instance of BackgroundImageFile.



1403
1404
1405
# File 'lib/google/apis/drive_v3/classes.rb', line 1403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The ID of an image file in Google Drive to use for the background image. Corresponds to the JSON property id

Returns:

  • (String)


1376
1377
1378
# File 'lib/google/apis/drive_v3/classes.rb', line 1376

def id
  @id
end

#widthFloat

The width of the cropped image in the closed range of 0 to 1. This value represents the width of the cropped image divided by the width of the entire image. The height is computed by applying a width to height aspect ratio of 80 to 9. The resulting image must be at least 1280 pixels wide and 144 pixels high. Corresponds to the JSON property width

Returns:

  • (Float)


1385
1386
1387
# File 'lib/google/apis/drive_v3/classes.rb', line 1385

def width
  @width
end

#x_coordinateFloat

The X coordinate of the upper left corner of the cropping area in the background image. This is a value in the closed range of 0 to 1. This value represents the horizontal distance from the left side of the entire image to the left side of the cropping area divided by the width of the entire image. Corresponds to the JSON property xCoordinate

Returns:

  • (Float)


1393
1394
1395
# File 'lib/google/apis/drive_v3/classes.rb', line 1393

def x_coordinate
  @x_coordinate
end

#y_coordinateFloat

The Y coordinate of the upper left corner of the cropping area in the background image. This is a value in the closed range of 0 to 1. This value represents the vertical distance from the top side of the entire image to the top side of the cropping area divided by the height of the entire image. Corresponds to the JSON property yCoordinate

Returns:

  • (Float)


1401
1402
1403
# File 'lib/google/apis/drive_v3/classes.rb', line 1401

def y_coordinate
  @y_coordinate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1408
1409
1410
1411
1412
1413
# File 'lib/google/apis/drive_v3/classes.rb', line 1408

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @width = args[:width] if args.key?(:width)
  @x_coordinate = args[:x_coordinate] if args.key?(:x_coordinate)
  @y_coordinate = args[:y_coordinate] if args.key?(:y_coordinate)
end