Class: Google::Apis::DriveV3::File

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

The metadata for a file. Some resource methods (such as files.update) require a fileId. Use the files.list method to retrieve the ID for a file.

Defined Under Namespace

Classes: Capabilities, ContentHints, ImageMediaMetadata, LabelInfo, LinkShareMetadata, ShortcutDetails, VideoMediaMetadata

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ File

Returns a new instance of File.



2223
2224
2225
# File 'lib/google/apis/drive_v3/classes.rb', line 2223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_propertiesHash<String,String>

A collection of arbitrary key-value pairs which are private to the requesting app. Entries with null values are cleared in update and copy requests. These properties can only be retrieved using an authenticated request. An authenticated request uses an access token obtained with a OAuth 2 client ID. You cannot use an API key to retrieve private properties. Corresponds to the JSON property appProperties

Returns:

  • (Hash<String,String>)


1818
1819
1820
# File 'lib/google/apis/drive_v3/classes.rb', line 1818

def app_properties
  @app_properties
end

#capabilitiesGoogle::Apis::DriveV3::File::Capabilities

Output only. Capabilities the current user has on this file. Each capability corresponds to a fine-grained action that a user may take. For more information, see Understand file capabilities. Corresponds to the JSON property capabilities



1826
1827
1828
# File 'lib/google/apis/drive_v3/classes.rb', line 1826

def capabilities
  @capabilities
end

#client_encryption_detailsGoogle::Apis::DriveV3::ClientEncryptionDetails

Details about the client-side encryption applied to the file. Corresponds to the JSON property clientEncryptionDetails



1831
1832
1833
# File 'lib/google/apis/drive_v3/classes.rb', line 1831

def client_encryption_details
  @client_encryption_details
end

#content_hintsGoogle::Apis::DriveV3::File::ContentHints

Additional information about the content of the file. These fields are never populated in responses. Corresponds to the JSON property contentHints



1837
1838
1839
# File 'lib/google/apis/drive_v3/classes.rb', line 1837

def content_hints
  @content_hints
end

#content_restrictionsArray<Google::Apis::DriveV3::ContentRestriction>

Restrictions for accessing the content of the file. Only populated if such a restriction exists. Corresponds to the JSON property contentRestrictions



1843
1844
1845
# File 'lib/google/apis/drive_v3/classes.rb', line 1843

def content_restrictions
  @content_restrictions
end

#copy_requires_writer_permissionBoolean Also known as: copy_requires_writer_permission?

Whether the options to copy, print, or download this file should be disabled for readers and commenters. Corresponds to the JSON property copyRequiresWriterPermission

Returns:

  • (Boolean)


1849
1850
1851
# File 'lib/google/apis/drive_v3/classes.rb', line 1849

def copy_requires_writer_permission
  @copy_requires_writer_permission
end

#created_timeDateTime

The time at which the file was created (RFC 3339 date-time). Corresponds to the JSON property createdTime

Returns:

  • (DateTime)


1855
1856
1857
# File 'lib/google/apis/drive_v3/classes.rb', line 1855

def created_time
  @created_time
end

#descriptionString

A short description of the file. Corresponds to the JSON property description

Returns:

  • (String)


1860
1861
1862
# File 'lib/google/apis/drive_v3/classes.rb', line 1860

def description
  @description
end

#download_restrictionsGoogle::Apis::DriveV3::DownloadRestrictionsMetadata

Download restrictions applied to the file. Corresponds to the JSON property downloadRestrictions



1865
1866
1867
# File 'lib/google/apis/drive_v3/classes.rb', line 1865

def download_restrictions
  @download_restrictions
end

#drive_idString

Output only. ID of the shared drive the file resides in. Only populated for items in shared drives. Corresponds to the JSON property driveId

Returns:

  • (String)


1871
1872
1873
# File 'lib/google/apis/drive_v3/classes.rb', line 1871

def drive_id
  @drive_id
end

#explicitly_trashedBoolean Also known as: explicitly_trashed?

Output only. Whether the file has been explicitly trashed, as opposed to recursively trashed from a parent folder. Corresponds to the JSON property explicitlyTrashed

Returns:

  • (Boolean)


1877
1878
1879
# File 'lib/google/apis/drive_v3/classes.rb', line 1877

def explicitly_trashed
  @explicitly_trashed
end

Output only. Links for exporting Docs Editors files to specific formats. Corresponds to the JSON property exportLinks

Returns:

  • (Hash<String,String>)


1883
1884
1885
# File 'lib/google/apis/drive_v3/classes.rb', line 1883

def export_links
  @export_links
end

#file_extensionString

Output only. The final component of fullFileExtension. This is only available for files with binary content in Google Drive. Corresponds to the JSON property fileExtension

Returns:

  • (String)


1889
1890
1891
# File 'lib/google/apis/drive_v3/classes.rb', line 1889

def file_extension
  @file_extension
end

#folder_color_rgbString

The color for a folder or a shortcut to a folder as an RGB hex string. The supported colors are published in the folderColorPalette field of the about resource. If an unsupported color is specified, the closest color in the palette is used instead. Corresponds to the JSON property folderColorRgb

Returns:

  • (String)


1898
1899
1900
# File 'lib/google/apis/drive_v3/classes.rb', line 1898

def folder_color_rgb
  @folder_color_rgb
end

#full_file_extensionString

Output only. The full file extension extracted from the name field. May contain multiple concatenated extensions, such as "tar.gz". This is only available for files with binary content in Google Drive. This is automatically updated when the name field changes, however it's not cleared if the new name doesn't contain a valid extension. Corresponds to the JSON property fullFileExtension

Returns:

  • (String)


1907
1908
1909
# File 'lib/google/apis/drive_v3/classes.rb', line 1907

def full_file_extension
  @full_file_extension
end

#has_augmented_permissionsBoolean Also known as: has_augmented_permissions?

Output only. Whether there are permissions directly on this file. This field is only populated for items in shared drives. Corresponds to the JSON property hasAugmentedPermissions

Returns:

  • (Boolean)


1913
1914
1915
# File 'lib/google/apis/drive_v3/classes.rb', line 1913

def has_augmented_permissions
  @has_augmented_permissions
end

#has_thumbnailBoolean Also known as: has_thumbnail?

Output only. Whether this file has a thumbnail. This doesn't indicate whether the requesting app has access to the thumbnail. To check access, look for the presence of the thumbnailLink field. Corresponds to the JSON property hasThumbnail

Returns:

  • (Boolean)


1921
1922
1923
# File 'lib/google/apis/drive_v3/classes.rb', line 1921

def has_thumbnail
  @has_thumbnail
end

#head_revision_idString

Output only. The ID of the file's head revision. This is currently only available for files with binary content in Google Drive. Corresponds to the JSON property headRevisionId

Returns:

  • (String)


1928
1929
1930
# File 'lib/google/apis/drive_v3/classes.rb', line 1928

def head_revision_id
  @head_revision_id
end

Output only. A static, unauthenticated link to the file's icon. Corresponds to the JSON property iconLink

Returns:

  • (String)


1933
1934
1935
# File 'lib/google/apis/drive_v3/classes.rb', line 1933

def icon_link
  @icon_link
end

#idString

The ID of the file. Corresponds to the JSON property id

Returns:

  • (String)


1938
1939
1940
# File 'lib/google/apis/drive_v3/classes.rb', line 1938

def id
  @id
end

#image_media_metadataGoogle::Apis::DriveV3::File::ImageMediaMetadata

Output only. Additional metadata about image media, if available. Corresponds to the JSON property imageMediaMetadata



1943
1944
1945
# File 'lib/google/apis/drive_v3/classes.rb', line 1943

def 
  @image_media_metadata
end

#inherited_permissions_disabledBoolean Also known as: inherited_permissions_disabled?

Whether this file has inherited permissions disabled. Inherited permissions are enabled by default. Corresponds to the JSON property inheritedPermissionsDisabled

Returns:

  • (Boolean)


1949
1950
1951
# File 'lib/google/apis/drive_v3/classes.rb', line 1949

def inherited_permissions_disabled
  @inherited_permissions_disabled
end

#is_app_authorizedBoolean Also known as: is_app_authorized?

Output only. Whether the file was created or opened by the requesting app. Corresponds to the JSON property isAppAuthorized

Returns:

  • (Boolean)


1955
1956
1957
# File 'lib/google/apis/drive_v3/classes.rb', line 1955

def is_app_authorized
  @is_app_authorized
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "drive#file". Corresponds to the JSON property kind

Returns:

  • (String)


1962
1963
1964
# File 'lib/google/apis/drive_v3/classes.rb', line 1962

def kind
  @kind
end

#label_infoGoogle::Apis::DriveV3::File::LabelInfo

Label information on the file. Corresponds to the JSON property labelInfo



1967
1968
1969
# File 'lib/google/apis/drive_v3/classes.rb', line 1967

def label_info
  @label_info
end

#last_modifying_userGoogle::Apis::DriveV3::User

Information about a Drive user. Corresponds to the JSON property lastModifyingUser



1972
1973
1974
# File 'lib/google/apis/drive_v3/classes.rb', line 1972

def last_modifying_user
  @last_modifying_user
end

Contains details about the link URLs that clients are using to refer to this item. Corresponds to the JSON property linkShareMetadata



1978
1979
1980
# File 'lib/google/apis/drive_v3/classes.rb', line 1978

def 
  @link_share_metadata
end

#md5_checksumString

Output only. The MD5 checksum for the content of the file. This is only applicable to files with binary content in Google Drive. Corresponds to the JSON property md5Checksum

Returns:

  • (String)


1984
1985
1986
# File 'lib/google/apis/drive_v3/classes.rb', line 1984

def md5_checksum
  @md5_checksum
end

#mime_typeString

The MIME type of the file. Google Drive attempts to automatically detect an appropriate value from uploaded content, if no value is provided. The value cannot be changed unless a new revision is uploaded. If a file is created with a Google Doc MIME type, the uploaded content is imported, if possible. The supported import formats are published in the about resource. Corresponds to the JSON property mimeType

Returns:

  • (String)


1994
1995
1996
# File 'lib/google/apis/drive_v3/classes.rb', line 1994

def mime_type
  @mime_type
end

#modified_by_meBoolean Also known as: modified_by_me?

Output only. Whether the file has been modified by this user. Corresponds to the JSON property modifiedByMe

Returns:

  • (Boolean)


1999
2000
2001
# File 'lib/google/apis/drive_v3/classes.rb', line 1999

def modified_by_me
  @modified_by_me
end

#modified_by_me_timeDateTime

The last time the file was modified by the user (RFC 3339 date-time). Corresponds to the JSON property modifiedByMeTime

Returns:

  • (DateTime)


2005
2006
2007
# File 'lib/google/apis/drive_v3/classes.rb', line 2005

def modified_by_me_time
  @modified_by_me_time
end

#modified_timeDateTime

he last time the file was modified by anyone (RFC 3339 date-time). Note that setting modifiedTime will also update modifiedByMeTime for the user. Corresponds to the JSON property modifiedTime

Returns:

  • (DateTime)


2011
2012
2013
# File 'lib/google/apis/drive_v3/classes.rb', line 2011

def modified_time
  @modified_time
end

#nameString

The name of the file. This isn't necessarily unique within a folder. Note that for immutable items such as the top-level folders of shared drives, the My Drive root folder, and the Application Data folder, the name is constant. Corresponds to the JSON property name

Returns:

  • (String)


2018
2019
2020
# File 'lib/google/apis/drive_v3/classes.rb', line 2018

def name
  @name
end

#original_filenameString

The original filename of the uploaded content if available, or else the original value of the name field. This is only available for files with binary content in Google Drive. Corresponds to the JSON property originalFilename

Returns:

  • (String)


2025
2026
2027
# File 'lib/google/apis/drive_v3/classes.rb', line 2025

def original_filename
  @original_filename
end

#owned_by_meBoolean Also known as: owned_by_me?

Output only. Whether the user owns the file. Not populated for items in shared drives. Corresponds to the JSON property ownedByMe

Returns:

  • (Boolean)


2031
2032
2033
# File 'lib/google/apis/drive_v3/classes.rb', line 2031

def owned_by_me
  @owned_by_me
end

#ownersArray<Google::Apis::DriveV3::User>

Output only. The owner of this file. Only certain legacy files may have more than one owner. This field isn't populated for items in shared drives. Corresponds to the JSON property owners

Returns:



2038
2039
2040
# File 'lib/google/apis/drive_v3/classes.rb', line 2038

def owners
  @owners
end

#parentsArray<String>

The ID of the parent folder containing the file. A file can only have one parent folder; specifying multiple parents isn't supported. If not specified as part of a create request, the file is placed directly in the user's My Drive folder. If not specified as part of a copy request, the file inherits any discoverable parent of the source file. Update requests must use the addParents and removeParents parameters to modify the parents list. Corresponds to the JSON property parents

Returns:

  • (Array<String>)


2048
2049
2050
# File 'lib/google/apis/drive_v3/classes.rb', line 2048

def parents
  @parents
end

#permission_idsArray<String>

Output only. List of permission IDs for users with access to this file. Corresponds to the JSON property permissionIds

Returns:

  • (Array<String>)


2053
2054
2055
# File 'lib/google/apis/drive_v3/classes.rb', line 2053

def permission_ids
  @permission_ids
end

#permissionsArray<Google::Apis::DriveV3::Permission>

Output only. The full list of permissions for the file. This is only available if the requesting user can share the file. Not populated for items in shared drives. Corresponds to the JSON property permissions



2060
2061
2062
# File 'lib/google/apis/drive_v3/classes.rb', line 2060

def permissions
  @permissions
end

#propertiesHash<String,String>

A collection of arbitrary key-value pairs which are visible to all apps. Entries with null values are cleared in update and copy requests. Corresponds to the JSON property properties

Returns:

  • (Hash<String,String>)


2066
2067
2068
# File 'lib/google/apis/drive_v3/classes.rb', line 2066

def properties
  @properties
end

#quota_bytes_usedFixnum

Output only. The number of storage quota bytes used by the file. This includes the head revision as well as previous revisions with keepForever enabled. Corresponds to the JSON property quotaBytesUsed

Returns:

  • (Fixnum)


2072
2073
2074
# File 'lib/google/apis/drive_v3/classes.rb', line 2072

def quota_bytes_used
  @quota_bytes_used
end

#resource_keyString

Output only. A key needed to access the item via a shared link. Corresponds to the JSON property resourceKey

Returns:

  • (String)


2077
2078
2079
# File 'lib/google/apis/drive_v3/classes.rb', line 2077

def resource_key
  @resource_key
end

#sha1_checksumString

Output only. The SHA1 checksum associated with this file, if available. This field is only populated for files with content stored in Google Drive; it's not populated for Docs Editors or shortcut files. Corresponds to the JSON property sha1Checksum

Returns:

  • (String)


2084
2085
2086
# File 'lib/google/apis/drive_v3/classes.rb', line 2084

def sha1_checksum
  @sha1_checksum
end

#sha256_checksumString

Output only. The SHA256 checksum associated with this file, if available. This field is only populated for files with content stored in Google Drive; it's not populated for Docs Editors or shortcut files. Corresponds to the JSON property sha256Checksum

Returns:

  • (String)


2091
2092
2093
# File 'lib/google/apis/drive_v3/classes.rb', line 2091

def sha256_checksum
  @sha256_checksum
end

#sharedBoolean Also known as: shared?

Output only. Whether the file has been shared. Not populated for items in shared drives. Corresponds to the JSON property shared

Returns:

  • (Boolean)


2097
2098
2099
# File 'lib/google/apis/drive_v3/classes.rb', line 2097

def shared
  @shared
end

#shared_with_me_timeDateTime

The time at which the file was shared with the user, if applicable (RFC 3339 date-time). Corresponds to the JSON property sharedWithMeTime

Returns:

  • (DateTime)


2104
2105
2106
# File 'lib/google/apis/drive_v3/classes.rb', line 2104

def shared_with_me_time
  @shared_with_me_time
end

#sharing_userGoogle::Apis::DriveV3::User

Information about a Drive user. Corresponds to the JSON property sharingUser



2109
2110
2111
# File 'lib/google/apis/drive_v3/classes.rb', line 2109

def sharing_user
  @sharing_user
end

#shortcut_detailsGoogle::Apis::DriveV3::File::ShortcutDetails

Information about a shortcut file. Corresponds to the JSON property shortcutDetails



2114
2115
2116
# File 'lib/google/apis/drive_v3/classes.rb', line 2114

def shortcut_details
  @shortcut_details
end

#sizeFixnum

Output only. Size in bytes of blobs and Google Workspace editor files. Won't be populated for files that have no size, like shortcuts and folders. Corresponds to the JSON property size

Returns:

  • (Fixnum)


2120
2121
2122
# File 'lib/google/apis/drive_v3/classes.rb', line 2120

def size
  @size
end

#spacesArray<String>

Output only. The list of spaces which contain the file. The currently supported values are drive, appDataFolder, and photos. Corresponds to the JSON property spaces

Returns:

  • (Array<String>)


2126
2127
2128
# File 'lib/google/apis/drive_v3/classes.rb', line 2126

def spaces
  @spaces
end

#starredBoolean Also known as: starred?

Whether the user has starred the file. Corresponds to the JSON property starred

Returns:

  • (Boolean)


2131
2132
2133
# File 'lib/google/apis/drive_v3/classes.rb', line 2131

def starred
  @starred
end

#team_drive_idString

Deprecated: Output only. Use driveId instead. Corresponds to the JSON property teamDriveId

Returns:

  • (String)


2137
2138
2139
# File 'lib/google/apis/drive_v3/classes.rb', line 2137

def team_drive_id
  @team_drive_id
end

Output only. A short-lived link to the file's thumbnail, if available. Typically lasts on the order of hours. Not intended for direct usage on web applications due to Cross-Origin Resource Sharing (CORS) policies. Consider using a proxy server. Only populated when the requesting app can access the file's content. If the file isn't shared publicly, the URL returned in files.thumbnailLink must be fetched using a credentialed request. Corresponds to the JSON property thumbnailLink

Returns:

  • (String)


2148
2149
2150
# File 'lib/google/apis/drive_v3/classes.rb', line 2148

def thumbnail_link
  @thumbnail_link
end

#thumbnail_versionFixnum

Output only. The thumbnail version for use in thumbnail cache invalidation. Corresponds to the JSON property thumbnailVersion

Returns:

  • (Fixnum)


2153
2154
2155
# File 'lib/google/apis/drive_v3/classes.rb', line 2153

def thumbnail_version
  @thumbnail_version
end

#trashedBoolean Also known as: trashed?

Whether the file has been trashed, either explicitly or from a trashed parent folder. Only the owner may trash a file, but other users can still access the file in the owner's trash until it's permanently deleted. Corresponds to the JSON property trashed

Returns:

  • (Boolean)


2160
2161
2162
# File 'lib/google/apis/drive_v3/classes.rb', line 2160

def trashed
  @trashed
end

#trashed_timeDateTime

The time that the item was trashed (RFC 3339 date-time). Only populated for items in shared drives. Corresponds to the JSON property trashedTime

Returns:

  • (DateTime)


2167
2168
2169
# File 'lib/google/apis/drive_v3/classes.rb', line 2167

def trashed_time
  @trashed_time
end

#trashing_userGoogle::Apis::DriveV3::User

Information about a Drive user. Corresponds to the JSON property trashingUser



2172
2173
2174
# File 'lib/google/apis/drive_v3/classes.rb', line 2172

def trashing_user
  @trashing_user
end

#versionFixnum

Output only. A monotonically increasing version number for the file. This reflects every change made to the file on the server, even those not visible to the user. Corresponds to the JSON property version

Returns:

  • (Fixnum)


2179
2180
2181
# File 'lib/google/apis/drive_v3/classes.rb', line 2179

def version
  @version
end

#video_media_metadataGoogle::Apis::DriveV3::File::VideoMediaMetadata

Output only. Additional metadata about video media. This may not be available immediately upon upload. Corresponds to the JSON property videoMediaMetadata



2185
2186
2187
# File 'lib/google/apis/drive_v3/classes.rb', line 2185

def 
  @video_media_metadata
end

#viewed_by_meBoolean Also known as: viewed_by_me?

Output only. Whether the file has been viewed by this user. Corresponds to the JSON property viewedByMe

Returns:

  • (Boolean)


2190
2191
2192
# File 'lib/google/apis/drive_v3/classes.rb', line 2190

def viewed_by_me
  @viewed_by_me
end

#viewed_by_me_timeDateTime

The last time the file was viewed by the user (RFC 3339 date-time). Corresponds to the JSON property viewedByMeTime

Returns:

  • (DateTime)


2196
2197
2198
# File 'lib/google/apis/drive_v3/classes.rb', line 2196

def viewed_by_me_time
  @viewed_by_me_time
end

#viewers_can_copy_contentBoolean Also known as: viewers_can_copy_content?

Deprecated: Use copyRequiresWriterPermission instead. Corresponds to the JSON property viewersCanCopyContent

Returns:

  • (Boolean)


2201
2202
2203
# File 'lib/google/apis/drive_v3/classes.rb', line 2201

def viewers_can_copy_content
  @viewers_can_copy_content
end

Output only. A link for downloading the content of the file in a browser. This is only available for files with binary content in Google Drive. Corresponds to the JSON property webContentLink

Returns:

  • (String)


2208
2209
2210
# File 'lib/google/apis/drive_v3/classes.rb', line 2208

def web_content_link
  @web_content_link
end

Output only. A link for opening the file in a relevant Google editor or viewer in a browser. Corresponds to the JSON property webViewLink

Returns:

  • (String)


2214
2215
2216
# File 'lib/google/apis/drive_v3/classes.rb', line 2214

def web_view_link
  @web_view_link
end

#writers_can_shareBoolean Also known as: writers_can_share?

Whether users with only writer permission can modify the file's permissions. Not populated for items in shared drives. Corresponds to the JSON property writersCanShare

Returns:

  • (Boolean)


2220
2221
2222
# File 'lib/google/apis/drive_v3/classes.rb', line 2220

def writers_can_share
  @writers_can_share
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/google/apis/drive_v3/classes.rb', line 2228

def update!(**args)
  @app_properties = args[:app_properties] if args.key?(:app_properties)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @client_encryption_details = args[:client_encryption_details] if args.key?(:client_encryption_details)
  @content_hints = args[:content_hints] if args.key?(:content_hints)
  @content_restrictions = args[:content_restrictions] if args.key?(:content_restrictions)
  @copy_requires_writer_permission = args[:copy_requires_writer_permission] if args.key?(:copy_requires_writer_permission)
  @created_time = args[:created_time] if args.key?(:created_time)
  @description = args[:description] if args.key?(:description)
  @download_restrictions = args[:download_restrictions] if args.key?(:download_restrictions)
  @drive_id = args[:drive_id] if args.key?(:drive_id)
  @explicitly_trashed = args[:explicitly_trashed] if args.key?(:explicitly_trashed)
  @export_links = args[:export_links] if args.key?(:export_links)
  @file_extension = args[:file_extension] if args.key?(:file_extension)
  @folder_color_rgb = args[:folder_color_rgb] if args.key?(:folder_color_rgb)
  @full_file_extension = args[:full_file_extension] if args.key?(:full_file_extension)
  @has_augmented_permissions = args[:has_augmented_permissions] if args.key?(:has_augmented_permissions)
  @has_thumbnail = args[:has_thumbnail] if args.key?(:has_thumbnail)
  @head_revision_id = args[:head_revision_id] if args.key?(:head_revision_id)
  @icon_link = args[:icon_link] if args.key?(:icon_link)
  @id = args[:id] if args.key?(:id)
  @image_media_metadata = args[:image_media_metadata] if args.key?(:image_media_metadata)
  @inherited_permissions_disabled = args[:inherited_permissions_disabled] if args.key?(:inherited_permissions_disabled)
  @is_app_authorized = args[:is_app_authorized] if args.key?(:is_app_authorized)
  @kind = args[:kind] if args.key?(:kind)
  @label_info = args[:label_info] if args.key?(:label_info)
  @last_modifying_user = args[:last_modifying_user] if args.key?(:last_modifying_user)
  @link_share_metadata = args[:link_share_metadata] if args.key?(:link_share_metadata)
  @md5_checksum = args[:md5_checksum] if args.key?(:md5_checksum)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @modified_by_me = args[:modified_by_me] if args.key?(:modified_by_me)
  @modified_by_me_time = args[:modified_by_me_time] if args.key?(:modified_by_me_time)
  @modified_time = args[:modified_time] if args.key?(:modified_time)
  @name = args[:name] if args.key?(:name)
  @original_filename = args[:original_filename] if args.key?(:original_filename)
  @owned_by_me = args[:owned_by_me] if args.key?(:owned_by_me)
  @owners = args[:owners] if args.key?(:owners)
  @parents = args[:parents] if args.key?(:parents)
  @permission_ids = args[:permission_ids] if args.key?(:permission_ids)
  @permissions = args[:permissions] if args.key?(:permissions)
  @properties = args[:properties] if args.key?(:properties)
  @quota_bytes_used = args[:quota_bytes_used] if args.key?(:quota_bytes_used)
  @resource_key = args[:resource_key] if args.key?(:resource_key)
  @sha1_checksum = args[:sha1_checksum] if args.key?(:sha1_checksum)
  @sha256_checksum = args[:sha256_checksum] if args.key?(:sha256_checksum)
  @shared = args[:shared] if args.key?(:shared)
  @shared_with_me_time = args[:shared_with_me_time] if args.key?(:shared_with_me_time)
  @sharing_user = args[:sharing_user] if args.key?(:sharing_user)
  @shortcut_details = args[:shortcut_details] if args.key?(:shortcut_details)
  @size = args[:size] if args.key?(:size)
  @spaces = args[:spaces] if args.key?(:spaces)
  @starred = args[:starred] if args.key?(:starred)
  @team_drive_id = args[:team_drive_id] if args.key?(:team_drive_id)
  @thumbnail_link = args[:thumbnail_link] if args.key?(:thumbnail_link)
  @thumbnail_version = args[:thumbnail_version] if args.key?(:thumbnail_version)
  @trashed = args[:trashed] if args.key?(:trashed)
  @trashed_time = args[:trashed_time] if args.key?(:trashed_time)
  @trashing_user = args[:trashing_user] if args.key?(:trashing_user)
  @version = args[:version] if args.key?(:version)
  @video_media_metadata = args[:video_media_metadata] if args.key?(:video_media_metadata)
  @viewed_by_me = args[:viewed_by_me] if args.key?(:viewed_by_me)
  @viewed_by_me_time = args[:viewed_by_me_time] if args.key?(:viewed_by_me_time)
  @viewers_can_copy_content = args[:viewers_can_copy_content] if args.key?(:viewers_can_copy_content)
  @web_content_link = args[:web_content_link] if args.key?(:web_content_link)
  @web_view_link = args[:web_view_link] if args.key?(:web_view_link)
  @writers_can_share = args[:writers_can_share] if args.key?(:writers_can_share)
end