Class: Google::Apis::DriveV3::File::Capabilities
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::File::Capabilities
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Output only. Capabilities the current user has on this file. Each capability corresponds to a fine-grained action that a user may take. For more information, see Understand file capabilities.
Instance Attribute Summary collapse
-
#can_accept_ownership ⇒ Boolean
(also: #can_accept_ownership?)
Output only.
-
#can_access_via_gen_ai ⇒ Boolean
(also: #can_access_via_gen_ai?)
Whether the current user can access this file via Gen AI features.
-
#can_add_children ⇒ Boolean
(also: #can_add_children?)
Output only.
-
#can_add_folder_from_another_drive ⇒ Boolean
(also: #can_add_folder_from_another_drive?)
Output only.
-
#can_add_my_drive_parent ⇒ Boolean
(also: #can_add_my_drive_parent?)
Output only.
-
#can_change_copy_requires_writer_permission ⇒ Boolean
(also: #can_change_copy_requires_writer_permission?)
Output only.
-
#can_change_item_download_restriction ⇒ Boolean
(also: #can_change_item_download_restriction?)
Output only.
-
#can_change_security_update_enabled ⇒ Boolean
(also: #can_change_security_update_enabled?)
Output only.
-
#can_change_viewers_can_copy_content ⇒ Boolean
(also: #can_change_viewers_can_copy_content?)
Deprecated: Output only.
-
#can_comment ⇒ Boolean
(also: #can_comment?)
Output only.
-
#can_copy ⇒ Boolean
(also: #can_copy?)
Output only.
-
#can_delete ⇒ Boolean
(also: #can_delete?)
Output only.
-
#can_delete_children ⇒ Boolean
(also: #can_delete_children?)
Output only.
-
#can_disable_inherited_permissions ⇒ Boolean
(also: #can_disable_inherited_permissions?)
Whether a user can disable inherited permissions.
-
#can_download ⇒ Boolean
(also: #can_download?)
Output only.
-
#can_edit ⇒ Boolean
(also: #can_edit?)
Output only.
-
#can_enable_inherited_permissions ⇒ Boolean
(also: #can_enable_inherited_permissions?)
Whether a user can re-enable inherited permissions.
-
#can_list_children ⇒ Boolean
(also: #can_list_children?)
Output only.
-
#can_modify_content ⇒ Boolean
(also: #can_modify_content?)
Output only.
-
#can_modify_content_restriction ⇒ Boolean
(also: #can_modify_content_restriction?)
Deprecated: Output only.
-
#can_modify_editor_content_restriction ⇒ Boolean
(also: #can_modify_editor_content_restriction?)
Output only.
-
#can_modify_labels ⇒ Boolean
(also: #can_modify_labels?)
Output only.
-
#can_modify_owner_content_restriction ⇒ Boolean
(also: #can_modify_owner_content_restriction?)
Output only.
-
#can_move_children_out_of_drive ⇒ Boolean
(also: #can_move_children_out_of_drive?)
Output only.
-
#can_move_children_out_of_team_drive ⇒ Boolean
(also: #can_move_children_out_of_team_drive?)
Deprecated: Output only.
-
#can_move_children_within_drive ⇒ Boolean
(also: #can_move_children_within_drive?)
Output only.
-
#can_move_children_within_team_drive ⇒ Boolean
(also: #can_move_children_within_team_drive?)
Deprecated: Output only.
-
#can_move_item_into_team_drive ⇒ Boolean
(also: #can_move_item_into_team_drive?)
Deprecated: Output only.
-
#can_move_item_out_of_drive ⇒ Boolean
(also: #can_move_item_out_of_drive?)
Output only.
-
#can_move_item_out_of_team_drive ⇒ Boolean
(also: #can_move_item_out_of_team_drive?)
Deprecated: Output only.
-
#can_move_item_within_drive ⇒ Boolean
(also: #can_move_item_within_drive?)
Output only.
-
#can_move_item_within_team_drive ⇒ Boolean
(also: #can_move_item_within_team_drive?)
Deprecated: Output only.
-
#can_move_team_drive_item ⇒ Boolean
(also: #can_move_team_drive_item?)
Deprecated: Output only.
-
#can_read_drive ⇒ Boolean
(also: #can_read_drive?)
Output only.
-
#can_read_labels ⇒ Boolean
(also: #can_read_labels?)
Output only.
-
#can_read_revisions ⇒ Boolean
(also: #can_read_revisions?)
Output only.
-
#can_read_team_drive ⇒ Boolean
(also: #can_read_team_drive?)
Deprecated: Output only.
-
#can_remove_children ⇒ Boolean
(also: #can_remove_children?)
Output only.
-
#can_remove_content_restriction ⇒ Boolean
(also: #can_remove_content_restriction?)
Output only.
-
#can_remove_my_drive_parent ⇒ Boolean
(also: #can_remove_my_drive_parent?)
Output only.
-
#can_rename ⇒ Boolean
(also: #can_rename?)
Output only.
-
#can_share ⇒ Boolean
(also: #can_share?)
Output only.
-
#can_start_approval ⇒ Boolean
(also: #can_start_approval?)
Whether the current user can start an approval on the file.
-
#can_trash ⇒ Boolean
(also: #can_trash?)
Output only.
-
#can_trash_children ⇒ Boolean
(also: #can_trash_children?)
Output only.
-
#can_untrash ⇒ Boolean
(also: #can_untrash?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Capabilities
constructor
A new instance of Capabilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Capabilities
Returns a new instance of Capabilities.
2621 2622 2623 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_accept_ownership ⇒ Boolean Also known as: can_accept_ownership?
Output only. Whether the current user is the pending owner of the file. Not
populated for shared drive files.
Corresponds to the JSON property canAcceptOwnership
2307 2308 2309 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2307 def can_accept_ownership @can_accept_ownership end |
#can_access_via_gen_ai ⇒ Boolean Also known as: can_access_via_gen_ai?
Whether the current user can access this file via Gen AI features. For more
information, see Drive MCP file eligibility.
Corresponds to the JSON property canAccessViaGenAi
2315 2316 2317 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2315 def can_access_via_gen_ai @can_access_via_gen_ai end |
#can_add_children ⇒ Boolean Also known as: can_add_children?
Output only. Whether the current user can add children to this folder. This is
always false when the item isn't a folder.
Corresponds to the JSON property canAddChildren
2322 2323 2324 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2322 def can_add_children @can_add_children end |
#can_add_folder_from_another_drive ⇒ Boolean Also known as: can_add_folder_from_another_drive?
Output only. Whether the current user can add a folder from another drive (
different shared drive or My Drive) to this folder. This is false when the
item isn't a folder. Only populated for items in shared drives.
Corresponds to the JSON property canAddFolderFromAnotherDrive
2330 2331 2332 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2330 def can_add_folder_from_another_drive @can_add_folder_from_another_drive end |
#can_add_my_drive_parent ⇒ Boolean Also known as: can_add_my_drive_parent?
Output only. Whether the current user can add a parent for the item without
removing an existing parent in the same request. Not populated for shared
drive files.
Corresponds to the JSON property canAddMyDriveParent
2338 2339 2340 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2338 def can_add_my_drive_parent @can_add_my_drive_parent end |
#can_change_copy_requires_writer_permission ⇒ Boolean Also known as: can_change_copy_requires_writer_permission?
Output only. Whether the current user can change the
copyRequiresWriterPermission restriction of this file.
Corresponds to the JSON property canChangeCopyRequiresWriterPermission
2345 2346 2347 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2345 def @can_change_copy_requires_writer_permission end |
#can_change_item_download_restriction ⇒ Boolean Also known as: can_change_item_download_restriction?
Output only. Whether the current user can change the owner or organizer-
applied download restrictions of the file.
Corresponds to the JSON property canChangeItemDownloadRestriction
2352 2353 2354 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2352 def can_change_item_download_restriction @can_change_item_download_restriction end |
#can_change_security_update_enabled ⇒ Boolean Also known as: can_change_security_update_enabled?
Output only. Whether the current user can change the securityUpdateEnabled
field on link share metadata.
Corresponds to the JSON property canChangeSecurityUpdateEnabled
2359 2360 2361 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2359 def can_change_security_update_enabled @can_change_security_update_enabled end |
#can_change_viewers_can_copy_content ⇒ Boolean Also known as: can_change_viewers_can_copy_content?
Deprecated: Output only.
Corresponds to the JSON property canChangeViewersCanCopyContent
2365 2366 2367 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2365 def can_change_viewers_can_copy_content @can_change_viewers_can_copy_content end |
#can_comment ⇒ Boolean Also known as: can_comment?
Output only. Whether the current user can comment on this file.
Corresponds to the JSON property canComment
2371 2372 2373 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2371 def can_comment @can_comment end |
#can_copy ⇒ Boolean Also known as: can_copy?
Output only. Whether the current user can copy this file. For an item in a
shared drive, whether the current user can copy non-folder descendants of this
item, or this item if it's not a folder.
Corresponds to the JSON property canCopy
2379 2380 2381 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2379 def can_copy @can_copy end |
#can_delete ⇒ Boolean Also known as: can_delete?
Output only. Whether the current user can delete this file.
Corresponds to the JSON property canDelete
2385 2386 2387 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2385 def can_delete @can_delete end |
#can_delete_children ⇒ Boolean Also known as: can_delete_children?
Output only. Whether the current user can delete children of this folder. This
is false when the item isn't a folder. Only populated for items in shared
drives.
Corresponds to the JSON property canDeleteChildren
2393 2394 2395 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2393 def can_delete_children @can_delete_children end |
#can_disable_inherited_permissions ⇒ Boolean Also known as: can_disable_inherited_permissions?
Whether a user can disable inherited permissions.
Corresponds to the JSON property canDisableInheritedPermissions
2399 2400 2401 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2399 def @can_disable_inherited_permissions end |
#can_download ⇒ Boolean Also known as: can_download?
Output only. Whether the current user can download this file.
Corresponds to the JSON property canDownload
2405 2406 2407 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2405 def can_download @can_download end |
#can_edit ⇒ Boolean Also known as: can_edit?
Output only. Whether the current user can edit this file. Other factors may
limit the type of changes a user can make to a file. For example, see
canChangeCopyRequiresWriterPermission or canModifyContent.
Corresponds to the JSON property canEdit
2413 2414 2415 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2413 def can_edit @can_edit end |
#can_enable_inherited_permissions ⇒ Boolean Also known as: can_enable_inherited_permissions?
Whether a user can re-enable inherited permissions.
Corresponds to the JSON property canEnableInheritedPermissions
2419 2420 2421 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2419 def @can_enable_inherited_permissions end |
#can_list_children ⇒ Boolean Also known as: can_list_children?
Output only. Whether the current user can list the children of this folder.
This is always false when the item isn't a folder.
Corresponds to the JSON property canListChildren
2426 2427 2428 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2426 def can_list_children @can_list_children end |
#can_modify_content ⇒ Boolean Also known as: can_modify_content?
Output only. Whether the current user can modify the content of this file.
Corresponds to the JSON property canModifyContent
2432 2433 2434 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2432 def can_modify_content @can_modify_content end |
#can_modify_content_restriction ⇒ Boolean Also known as: can_modify_content_restriction?
Deprecated: Output only. Use one of canModifyEditorContentRestriction,
canModifyOwnerContentRestriction, or canRemoveContentRestriction.
Corresponds to the JSON property canModifyContentRestriction
2439 2440 2441 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2439 def can_modify_content_restriction @can_modify_content_restriction end |
#can_modify_editor_content_restriction ⇒ Boolean Also known as: can_modify_editor_content_restriction?
Output only. Whether the current user can add or modify content restrictions
on the file which are editor restricted.
Corresponds to the JSON property canModifyEditorContentRestriction
2446 2447 2448 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2446 def can_modify_editor_content_restriction @can_modify_editor_content_restriction end |
#can_modify_labels ⇒ Boolean Also known as: can_modify_labels?
Output only. Whether the current user can modify the labels on the file.
Corresponds to the JSON property canModifyLabels
2452 2453 2454 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2452 def can_modify_labels @can_modify_labels end |
#can_modify_owner_content_restriction ⇒ Boolean Also known as: can_modify_owner_content_restriction?
Output only. Whether the current user can add or modify content restrictions
which are owner restricted.
Corresponds to the JSON property canModifyOwnerContentRestriction
2459 2460 2461 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2459 def can_modify_owner_content_restriction @can_modify_owner_content_restriction end |
#can_move_children_out_of_drive ⇒ Boolean Also known as: can_move_children_out_of_drive?
Output only. Whether the current user can move children of this folder outside
of the shared drive. This is false when the item isn't a folder. Only
populated for items in shared drives.
Corresponds to the JSON property canMoveChildrenOutOfDrive
2467 2468 2469 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2467 def can_move_children_out_of_drive @can_move_children_out_of_drive end |
#can_move_children_out_of_team_drive ⇒ Boolean Also known as: can_move_children_out_of_team_drive?
Deprecated: Output only. Use canMoveChildrenOutOfDrive instead.
Corresponds to the JSON property canMoveChildrenOutOfTeamDrive
2473 2474 2475 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2473 def can_move_children_out_of_team_drive @can_move_children_out_of_team_drive end |
#can_move_children_within_drive ⇒ Boolean Also known as: can_move_children_within_drive?
Output only. Whether the current user can move children of this folder within
this drive. This is false when the item isn't a folder. Note that a request
to move the child may still fail depending on the current user's access to the
child and to the destination folder.
Corresponds to the JSON property canMoveChildrenWithinDrive
2482 2483 2484 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2482 def can_move_children_within_drive @can_move_children_within_drive end |
#can_move_children_within_team_drive ⇒ Boolean Also known as: can_move_children_within_team_drive?
Deprecated: Output only. Use canMoveChildrenWithinDrive instead.
Corresponds to the JSON property canMoveChildrenWithinTeamDrive
2488 2489 2490 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2488 def can_move_children_within_team_drive @can_move_children_within_team_drive end |
#can_move_item_into_team_drive ⇒ Boolean Also known as: can_move_item_into_team_drive?
Deprecated: Output only. Use canMoveItemOutOfDrive instead.
Corresponds to the JSON property canMoveItemIntoTeamDrive
2494 2495 2496 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2494 def can_move_item_into_team_drive @can_move_item_into_team_drive end |
#can_move_item_out_of_drive ⇒ Boolean Also known as: can_move_item_out_of_drive?
Output only. Whether the current user can move this item outside of this drive
by changing its parent. Note that a request to change the parent of the item
may still fail depending on the new parent that's being added.
Corresponds to the JSON property canMoveItemOutOfDrive
2502 2503 2504 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2502 def can_move_item_out_of_drive @can_move_item_out_of_drive end |
#can_move_item_out_of_team_drive ⇒ Boolean Also known as: can_move_item_out_of_team_drive?
Deprecated: Output only. Use canMoveItemOutOfDrive instead.
Corresponds to the JSON property canMoveItemOutOfTeamDrive
2508 2509 2510 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2508 def can_move_item_out_of_team_drive @can_move_item_out_of_team_drive end |
#can_move_item_within_drive ⇒ Boolean Also known as: can_move_item_within_drive?
Output only. Whether the current user can move this item within this drive.
Note that a request to change the parent of the item may still fail depending
on the new parent that's being added and the parent that is being removed.
Corresponds to the JSON property canMoveItemWithinDrive
2516 2517 2518 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2516 def can_move_item_within_drive @can_move_item_within_drive end |
#can_move_item_within_team_drive ⇒ Boolean Also known as: can_move_item_within_team_drive?
Deprecated: Output only. Use canMoveItemWithinDrive instead.
Corresponds to the JSON property canMoveItemWithinTeamDrive
2522 2523 2524 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2522 def can_move_item_within_team_drive @can_move_item_within_team_drive end |
#can_move_team_drive_item ⇒ Boolean Also known as: can_move_team_drive_item?
Deprecated: Output only. Use canMoveItemWithinDrive or
canMoveItemOutOfDrive instead.
Corresponds to the JSON property canMoveTeamDriveItem
2529 2530 2531 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2529 def can_move_team_drive_item @can_move_team_drive_item end |
#can_read_drive ⇒ Boolean Also known as: can_read_drive?
Output only. Whether the current user can read the shared drive to which this
file belongs. Only populated for items in shared drives.
Corresponds to the JSON property canReadDrive
2536 2537 2538 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2536 def can_read_drive @can_read_drive end |
#can_read_labels ⇒ Boolean Also known as: can_read_labels?
Output only. Whether the current user can read the labels on the file.
Corresponds to the JSON property canReadLabels
2542 2543 2544 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2542 def can_read_labels @can_read_labels end |
#can_read_revisions ⇒ Boolean Also known as: can_read_revisions?
Output only. Whether the current user can read the revisions resource of this
file. For a shared drive item, whether revisions of non-folder descendants of
this item, or this item if it's not a folder, can be read.
Corresponds to the JSON property canReadRevisions
2550 2551 2552 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2550 def can_read_revisions @can_read_revisions end |
#can_read_team_drive ⇒ Boolean Also known as: can_read_team_drive?
Deprecated: Output only. Use canReadDrive instead.
Corresponds to the JSON property canReadTeamDrive
2556 2557 2558 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2556 def can_read_team_drive @can_read_team_drive end |
#can_remove_children ⇒ Boolean Also known as: can_remove_children?
Output only. Whether the current user can remove children from this folder.
This is always false when the item isn't a folder. For a folder in a shared
drive, use canDeleteChildren or canTrashChildren instead.
Corresponds to the JSON property canRemoveChildren
2564 2565 2566 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2564 def can_remove_children @can_remove_children end |
#can_remove_content_restriction ⇒ Boolean Also known as: can_remove_content_restriction?
Output only. Whether there's a content restriction on the file that can be
removed by the current user.
Corresponds to the JSON property canRemoveContentRestriction
2571 2572 2573 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2571 def can_remove_content_restriction @can_remove_content_restriction end |
#can_remove_my_drive_parent ⇒ Boolean Also known as: can_remove_my_drive_parent?
Output only. Whether the current user can remove a parent from the item
without adding another parent in the same request. Not populated for shared
drive files.
Corresponds to the JSON property canRemoveMyDriveParent
2579 2580 2581 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2579 def can_remove_my_drive_parent @can_remove_my_drive_parent end |
#can_rename ⇒ Boolean Also known as: can_rename?
Output only. Whether the current user can rename this file.
Corresponds to the JSON property canRename
2585 2586 2587 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2585 def can_rename @can_rename end |
#can_share ⇒ Boolean Also known as:
Output only. Whether the current user can modify the sharing settings for this
file.
Corresponds to the JSON property canShare
2592 2593 2594 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2592 def can_share @can_share end |
#can_start_approval ⇒ Boolean Also known as: can_start_approval?
Whether the current user can start an approval on the file.
Corresponds to the JSON property canStartApproval
2598 2599 2600 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2598 def can_start_approval @can_start_approval end |
#can_trash ⇒ Boolean Also known as: can_trash?
Output only. Whether the current user can move this file to trash.
Corresponds to the JSON property canTrash
2604 2605 2606 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2604 def can_trash @can_trash end |
#can_trash_children ⇒ Boolean Also known as: can_trash_children?
Output only. Whether the current user can trash children of this folder. This
is false when the item isn't a folder. Only populated for items in shared
drives.
Corresponds to the JSON property canTrashChildren
2612 2613 2614 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2612 def can_trash_children @can_trash_children end |
#can_untrash ⇒ Boolean Also known as: can_untrash?
Output only. Whether the current user can restore this file from trash.
Corresponds to the JSON property canUntrash
2618 2619 2620 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2618 def can_untrash @can_untrash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2626 def update!(**args) @can_accept_ownership = args[:can_accept_ownership] if args.key?(:can_accept_ownership) @can_access_via_gen_ai = args[:can_access_via_gen_ai] if args.key?(:can_access_via_gen_ai) @can_add_children = args[:can_add_children] if args.key?(:can_add_children) @can_add_folder_from_another_drive = args[:can_add_folder_from_another_drive] if args.key?(:can_add_folder_from_another_drive) @can_add_my_drive_parent = args[:can_add_my_drive_parent] if args.key?(:can_add_my_drive_parent) @can_change_copy_requires_writer_permission = args[:can_change_copy_requires_writer_permission] if args.key?(:can_change_copy_requires_writer_permission) @can_change_item_download_restriction = args[:can_change_item_download_restriction] if args.key?(:can_change_item_download_restriction) @can_change_security_update_enabled = args[:can_change_security_update_enabled] if args.key?(:can_change_security_update_enabled) @can_change_viewers_can_copy_content = args[:can_change_viewers_can_copy_content] if args.key?(:can_change_viewers_can_copy_content) @can_comment = args[:can_comment] if args.key?(:can_comment) @can_copy = args[:can_copy] if args.key?(:can_copy) @can_delete = args[:can_delete] if args.key?(:can_delete) @can_delete_children = args[:can_delete_children] if args.key?(:can_delete_children) @can_disable_inherited_permissions = args[:can_disable_inherited_permissions] if args.key?(:can_disable_inherited_permissions) @can_download = args[:can_download] if args.key?(:can_download) @can_edit = args[:can_edit] if args.key?(:can_edit) @can_enable_inherited_permissions = args[:can_enable_inherited_permissions] if args.key?(:can_enable_inherited_permissions) @can_list_children = args[:can_list_children] if args.key?(:can_list_children) @can_modify_content = args[:can_modify_content] if args.key?(:can_modify_content) @can_modify_content_restriction = args[:can_modify_content_restriction] if args.key?(:can_modify_content_restriction) @can_modify_editor_content_restriction = args[:can_modify_editor_content_restriction] if args.key?(:can_modify_editor_content_restriction) @can_modify_labels = args[:can_modify_labels] if args.key?(:can_modify_labels) @can_modify_owner_content_restriction = args[:can_modify_owner_content_restriction] if args.key?(:can_modify_owner_content_restriction) @can_move_children_out_of_drive = args[:can_move_children_out_of_drive] if args.key?(:can_move_children_out_of_drive) @can_move_children_out_of_team_drive = args[:can_move_children_out_of_team_drive] if args.key?(:can_move_children_out_of_team_drive) @can_move_children_within_drive = args[:can_move_children_within_drive] if args.key?(:can_move_children_within_drive) @can_move_children_within_team_drive = args[:can_move_children_within_team_drive] if args.key?(:can_move_children_within_team_drive) @can_move_item_into_team_drive = args[:can_move_item_into_team_drive] if args.key?(:can_move_item_into_team_drive) @can_move_item_out_of_drive = args[:can_move_item_out_of_drive] if args.key?(:can_move_item_out_of_drive) @can_move_item_out_of_team_drive = args[:can_move_item_out_of_team_drive] if args.key?(:can_move_item_out_of_team_drive) @can_move_item_within_drive = args[:can_move_item_within_drive] if args.key?(:can_move_item_within_drive) @can_move_item_within_team_drive = args[:can_move_item_within_team_drive] if args.key?(:can_move_item_within_team_drive) @can_move_team_drive_item = args[:can_move_team_drive_item] if args.key?(:can_move_team_drive_item) @can_read_drive = args[:can_read_drive] if args.key?(:can_read_drive) @can_read_labels = args[:can_read_labels] if args.key?(:can_read_labels) @can_read_revisions = args[:can_read_revisions] if args.key?(:can_read_revisions) @can_read_team_drive = args[:can_read_team_drive] if args.key?(:can_read_team_drive) @can_remove_children = args[:can_remove_children] if args.key?(:can_remove_children) @can_remove_content_restriction = args[:can_remove_content_restriction] if args.key?(:can_remove_content_restriction) @can_remove_my_drive_parent = args[:can_remove_my_drive_parent] if args.key?(:can_remove_my_drive_parent) @can_rename = args[:can_rename] if args.key?(:can_rename) @can_share = args[:can_share] if args.key?(:can_share) @can_start_approval = args[:can_start_approval] if args.key?(:can_start_approval) @can_trash = args[:can_trash] if args.key?(:can_trash) @can_trash_children = args[:can_trash_children] if args.key?(:can_trash_children) @can_untrash = args[:can_untrash] if args.key?(:can_untrash) end |