Class: Google::Apis::DriveV3::File::ContentHints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Additional information about the content of the file. These fields are never populated in responses.

Defined Under Namespace

Classes: Thumbnail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentHints

Returns a new instance of ContentHints.



2691
2692
2693
# File 'lib/google/apis/drive_v3/classes.rb', line 2691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#indexable_textString

Text to be indexed for the file to improve fullText queries. This is limited to 128 KB in length and may contain HTML elements. Corresponds to the JSON property indexableText

Returns:

  • (String)


2683
2684
2685
# File 'lib/google/apis/drive_v3/classes.rb', line 2683

def indexable_text
  @indexable_text
end

#thumbnailGoogle::Apis::DriveV3::File::ContentHints::Thumbnail

A thumbnail for the file. This will only be used if Google Drive cannot generate a standard thumbnail. Corresponds to the JSON property thumbnail



2689
2690
2691
# File 'lib/google/apis/drive_v3/classes.rb', line 2689

def thumbnail
  @thumbnail
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2696
2697
2698
2699
# File 'lib/google/apis/drive_v3/classes.rb', line 2696

def update!(**args)
  @indexable_text = args[:indexable_text] if args.key?(:indexable_text)
  @thumbnail = args[:thumbnail] if args.key?(:thumbnail)
end