Class: Google::Apis::DriveV3::File::ImageMediaMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::File::ImageMediaMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Output only. Additional metadata about image media, if available.
Defined Under Namespace
Classes: Location
Instance Attribute Summary collapse
-
#aperture ⇒ Float
Output only.
-
#camera_make ⇒ String
Output only.
-
#camera_model ⇒ String
Output only.
-
#color_space ⇒ String
Output only.
-
#exposure_bias ⇒ Float
Output only.
-
#exposure_mode ⇒ String
Output only.
-
#exposure_time ⇒ Float
Output only.
-
#flash_used ⇒ Boolean
(also: #flash_used?)
Output only.
-
#focal_length ⇒ Float
Output only.
-
#height ⇒ Fixnum
Output only.
-
#iso_speed ⇒ Fixnum
Output only.
-
#lens ⇒ String
Output only.
-
#location ⇒ Google::Apis::DriveV3::File::ImageMediaMetadata::Location
Output only.
-
#max_aperture_value ⇒ Float
Output only.
-
#metering_mode ⇒ String
Output only.
-
#rotation ⇒ Fixnum
Output only.
-
#sensor ⇒ String
Output only.
-
#subject_distance ⇒ Fixnum
Output only.
-
#time ⇒ String
Output only.
-
#white_balance ⇒ String
Output only.
-
#width ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageMediaMetadata
constructor
A new instance of ImageMediaMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageMediaMetadata
Returns a new instance of ImageMediaMetadata.
2836 2837 2838 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2836 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aperture ⇒ Float
Output only. The aperture used to create the photo (f-number).
Corresponds to the JSON property aperture
2731 2732 2733 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2731 def aperture @aperture end |
#camera_make ⇒ String
Output only. The make of the camera used to create the photo.
Corresponds to the JSON property cameraMake
2736 2737 2738 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2736 def camera_make @camera_make end |
#camera_model ⇒ String
Output only. The model of the camera used to create the photo.
Corresponds to the JSON property cameraModel
2741 2742 2743 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2741 def camera_model @camera_model end |
#color_space ⇒ String
Output only. The color space of the photo.
Corresponds to the JSON property colorSpace
2746 2747 2748 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2746 def color_space @color_space end |
#exposure_bias ⇒ Float
Output only. The exposure bias of the photo (APEX value).
Corresponds to the JSON property exposureBias
2751 2752 2753 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2751 def exposure_bias @exposure_bias end |
#exposure_mode ⇒ String
Output only. The exposure mode used to create the photo.
Corresponds to the JSON property exposureMode
2756 2757 2758 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2756 def exposure_mode @exposure_mode end |
#exposure_time ⇒ Float
Output only. The length of the exposure, in seconds.
Corresponds to the JSON property exposureTime
2761 2762 2763 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2761 def exposure_time @exposure_time end |
#flash_used ⇒ Boolean Also known as: flash_used?
Output only. Whether a flash was used to create the photo.
Corresponds to the JSON property flashUsed
2766 2767 2768 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2766 def flash_used @flash_used end |
#focal_length ⇒ Float
Output only. The focal length used to create the photo, in millimeters.
Corresponds to the JSON property focalLength
2772 2773 2774 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2772 def focal_length @focal_length end |
#height ⇒ Fixnum
Output only. The height of the image in pixels.
Corresponds to the JSON property height
2777 2778 2779 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2777 def height @height end |
#iso_speed ⇒ Fixnum
Output only. The ISO speed used to create the photo.
Corresponds to the JSON property isoSpeed
2782 2783 2784 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2782 def iso_speed @iso_speed end |
#lens ⇒ String
Output only. The lens used to create the photo.
Corresponds to the JSON property lens
2787 2788 2789 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2787 def lens @lens end |
#location ⇒ Google::Apis::DriveV3::File::ImageMediaMetadata::Location
Output only. Geographic location information stored in the image.
Corresponds to the JSON property location
2792 2793 2794 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2792 def location @location end |
#max_aperture_value ⇒ Float
Output only. The smallest f-number of the lens at the focal length used to
create the photo (APEX value).
Corresponds to the JSON property maxApertureValue
2798 2799 2800 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2798 def max_aperture_value @max_aperture_value end |
#metering_mode ⇒ String
Output only. The metering mode used to create the photo.
Corresponds to the JSON property meteringMode
2803 2804 2805 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2803 def metering_mode @metering_mode end |
#rotation ⇒ Fixnum
Output only. The number of clockwise 90 degree rotations applied from the
image's original orientation.
Corresponds to the JSON property rotation
2809 2810 2811 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2809 def rotation @rotation end |
#sensor ⇒ String
Output only. The type of sensor used to create the photo.
Corresponds to the JSON property sensor
2814 2815 2816 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2814 def sensor @sensor end |
#subject_distance ⇒ Fixnum
Output only. The distance to the subject of the photo, in meters.
Corresponds to the JSON property subjectDistance
2819 2820 2821 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2819 def subject_distance @subject_distance end |
#time ⇒ String
Output only. The date and time the photo was taken (EXIF DateTime).
Corresponds to the JSON property time
2824 2825 2826 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2824 def time @time end |
#white_balance ⇒ String
Output only. The white balance mode used to create the photo.
Corresponds to the JSON property whiteBalance
2829 2830 2831 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2829 def white_balance @white_balance end |
#width ⇒ Fixnum
Output only. The width of the image in pixels.
Corresponds to the JSON property width
2834 2835 2836 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2834 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2841 def update!(**args) @aperture = args[:aperture] if args.key?(:aperture) @camera_make = args[:camera_make] if args.key?(:camera_make) @camera_model = args[:camera_model] if args.key?(:camera_model) @color_space = args[:color_space] if args.key?(:color_space) @exposure_bias = args[:exposure_bias] if args.key?(:exposure_bias) @exposure_mode = args[:exposure_mode] if args.key?(:exposure_mode) @exposure_time = args[:exposure_time] if args.key?(:exposure_time) @flash_used = args[:flash_used] if args.key?(:flash_used) @focal_length = args[:focal_length] if args.key?(:focal_length) @height = args[:height] if args.key?(:height) @iso_speed = args[:iso_speed] if args.key?(:iso_speed) @lens = args[:lens] if args.key?(:lens) @location = args[:location] if args.key?(:location) @max_aperture_value = args[:max_aperture_value] if args.key?(:max_aperture_value) @metering_mode = args[:metering_mode] if args.key?(:metering_mode) @rotation = args[:rotation] if args.key?(:rotation) @sensor = args[:sensor] if args.key?(:sensor) @subject_distance = args[:subject_distance] if args.key?(:subject_distance) @time = args[:time] if args.key?(:time) @white_balance = args[:white_balance] if args.key?(:white_balance) @width = args[:width] if args.key?(:width) end |