Class: Google::Apis::DriveV3::GeneratedIds

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A list of generated file IDs which can be provided in create requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeneratedIds

Returns a new instance of GeneratedIds.



3012
3013
3014
# File 'lib/google/apis/drive_v3/classes.rb', line 3012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idsArray<String>

The IDs generated for the requesting user in the specified space. Corresponds to the JSON property ids

Returns:

  • (Array<String>)


2999
3000
3001
# File 'lib/google/apis/drive_v3/classes.rb', line 2999

def ids
  @ids
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "drive# generatedIds". Corresponds to the JSON property kind

Returns:

  • (String)


3005
3006
3007
# File 'lib/google/apis/drive_v3/classes.rb', line 3005

def kind
  @kind
end

#spaceString

The type of file that can be created with these IDs. Corresponds to the JSON property space

Returns:

  • (String)


3010
3011
3012
# File 'lib/google/apis/drive_v3/classes.rb', line 3010

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3017
3018
3019
3020
3021
# File 'lib/google/apis/drive_v3/classes.rb', line 3017

def update!(**args)
  @ids = args[:ids] if args.key?(:ids)
  @kind = args[:kind] if args.key?(:kind)
  @space = args[:space] if args.key?(:space)
end