Class: Google::Apis::DriveV3::ListAccessProposalsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::ListAccessProposalsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
The response to an access proposal list request.
Instance Attribute Summary collapse
-
#access_proposals ⇒ Array<Google::Apis::DriveV3::AccessProposal>
The list of access proposals.
-
#next_page_token ⇒ String
The continuation token for the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAccessProposalsResponse
constructor
A new instance of ListAccessProposalsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAccessProposalsResponse
Returns a new instance of ListAccessProposalsResponse.
3400 3401 3402 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_proposals ⇒ Array<Google::Apis::DriveV3::AccessProposal>
The list of access proposals. This field is only populated in Drive API v3.
Corresponds to the JSON property accessProposals
3390 3391 3392 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3390 def access_proposals @access_proposals end |
#next_page_token ⇒ String
The continuation token for the next page of results. This will be absent if
the end of the results list has been reached. If the token is rejected for any
reason, it should be discarded, and pagination should be restarted from the
first page of results.
Corresponds to the JSON property nextPageToken
3398 3399 3400 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3398 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3405 3406 3407 3408 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3405 def update!(**args) @access_proposals = args[:access_proposals] if args.key?(:access_proposals) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |