Class: Google::Apis::DriveV3::ModifyLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A request to modify the set of labels on a file. This request may contain many modifications that will either all succeed or all fail atomically.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ModifyLabelsRequest

Returns a new instance of ModifyLabelsRequest.



3411
3412
3413
# File 'lib/google/apis/drive_v3/classes.rb', line 3411

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

This is always "drive#modifyLabelsRequest". Corresponds to the JSON property kind

Returns:

  • (String)


3404
3405
3406
# File 'lib/google/apis/drive_v3/classes.rb', line 3404

def kind
  @kind
end

#label_modificationsArray<Google::Apis::DriveV3::LabelModification>

The list of modifications to apply to the labels on the file. Corresponds to the JSON property labelModifications



3409
3410
3411
# File 'lib/google/apis/drive_v3/classes.rb', line 3409

def label_modifications
  @label_modifications
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3416
3417
3418
3419
# File 'lib/google/apis/drive_v3/classes.rb', line 3416

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @label_modifications = args[:label_modifications] if args.key?(:label_modifications)
end