Class: Google::Apis::DriveV3::ModifyLabelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Response to a ModifyLabels request. This contains only those labels which were added or updated by the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ModifyLabelsResponse

Returns a new instance of ModifyLabelsResponse.



3332
3333
3334
# File 'lib/google/apis/drive_v3/classes.rb', line 3332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

This is always "drive#modifyLabelsResponse". Corresponds to the JSON property kind

Returns:

  • (String)


3325
3326
3327
# File 'lib/google/apis/drive_v3/classes.rb', line 3325

def kind
  @kind
end

#modified_labelsArray<Google::Apis::DriveV3::Label>

The list of labels which were added or updated by the request. Corresponds to the JSON property modifiedLabels

Returns:



3330
3331
3332
# File 'lib/google/apis/drive_v3/classes.rb', line 3330

def modified_labels
  @modified_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3337
3338
3339
3340
# File 'lib/google/apis/drive_v3/classes.rb', line 3337

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @modified_labels = args[:modified_labels] if args.key?(:modified_labels)
end