Class: Google::Apis::DriveV3::Operation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

This resource represents a long-running operation that is the result of a network API call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



3511
3512
3513
# File 'lib/google/apis/drive_v3/classes.rb', line 3511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

If the value is false, it means the operation is still in progress. If true , the operation is completed, and either error or response is available. Corresponds to the JSON property done

Returns:

  • (Boolean)


3472
3473
3474
# File 'lib/google/apis/drive_v3/classes.rb', line 3472

def done
  @done
end

#errorGoogle::Apis::DriveV3::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3483
3484
3485
# File 'lib/google/apis/drive_v3/classes.rb', line 3483

def error
  @error
end

#metadataHash<String,Object>

Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


3491
3492
3493
# File 'lib/google/apis/drive_v3/classes.rb', line 3491

def 
  @metadata
end

#nameString

The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the name should be a resource name ending with operations/unique_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


3498
3499
3500
# File 'lib/google/apis/drive_v3/classes.rb', line 3498

def name
  @name
end

#responseHash<String,Object>

The normal, successful response of the operation. If the original method returns no data on success, such as Delete, the response is google.protobuf. Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse. Corresponds to the JSON property response

Returns:

  • (Hash<String,Object>)


3509
3510
3511
# File 'lib/google/apis/drive_v3/classes.rb', line 3509

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3516
3517
3518
3519
3520
3521
3522
# File 'lib/google/apis/drive_v3/classes.rb', line 3516

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @error = args[:error] if args.key?(:error)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @response = args[:response] if args.key?(:response)
end