Class: Google::Apis::DriveV3::ReassignApprovalRequest
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::ReassignApprovalRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Request for reassigning an approval. Reviewers can be added or replaced, but not removed.
Instance Attribute Summary collapse
-
#add_reviewers ⇒ Array<Google::Apis::DriveV3::AddReviewer>
Optional.
-
#message ⇒ String
Optional.
-
#replace_reviewers ⇒ Array<Google::Apis::DriveV3::ReplaceReviewer>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReassignApprovalRequest
constructor
A new instance of ReassignApprovalRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReassignApprovalRequest
Returns a new instance of ReassignApprovalRequest.
3819 3820 3821 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_reviewers ⇒ Array<Google::Apis::DriveV3::AddReviewer>
Optional. The list of reviewers to add.
Corresponds to the JSON property addReviewers
3806 3807 3808 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3806 def add_reviewers @add_reviewers end |
#message ⇒ String
Optional. A message to send to the new reviewers. This message is included in
notifications for the action and in the approval activity log.
Corresponds to the JSON property message
3812 3813 3814 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3812 def @message end |
#replace_reviewers ⇒ Array<Google::Apis::DriveV3::ReplaceReviewer>
Optional. The list of reviewer replacements.
Corresponds to the JSON property replaceReviewers
3817 3818 3819 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3817 def replace_reviewers @replace_reviewers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3824 3825 3826 3827 3828 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3824 def update!(**args) @add_reviewers = args[:add_reviewers] if args.key?(:add_reviewers) @message = args[:message] if args.key?(:message) @replace_reviewers = args[:replace_reviewers] if args.key?(:replace_reviewers) end |