Class: Google::Apis::DriveV3::Reply

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A reply to a comment on a file. Some resource methods (such as replies.update ) require a replyId. Use the replies.list method to retrieve the ID for a reply.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reply

Returns a new instance of Reply.



3923
3924
3925
# File 'lib/google/apis/drive_v3/classes.rb', line 3923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

The action the reply performed to the parent comment. The supported values are:

  • resolve * reopen Corresponds to the JSON property action

Returns:

  • (String)


3864
3865
3866
# File 'lib/google/apis/drive_v3/classes.rb', line 3864

def action
  @action
end

#assignee_email_addressString

Output only. The email address of the user assigned to this comment. If no user is assigned, the field is unset. Corresponds to the JSON property assigneeEmailAddress

Returns:

  • (String)


3870
3871
3872
# File 'lib/google/apis/drive_v3/classes.rb', line 3870

def assignee_email_address
  @assignee_email_address
end

#authorGoogle::Apis::DriveV3::User

Information about a Drive user. Corresponds to the JSON property author



3875
3876
3877
# File 'lib/google/apis/drive_v3/classes.rb', line 3875

def author
  @author
end

#contentString

The plain text content of the reply. This field is used for setting the content, while htmlContent should be displayed. This field is required by the create method if no action value is specified. Corresponds to the JSON property content

Returns:

  • (String)


3882
3883
3884
# File 'lib/google/apis/drive_v3/classes.rb', line 3882

def content
  @content
end

#created_timeDateTime

The time at which the reply was created (RFC 3339 date-time). Corresponds to the JSON property createdTime

Returns:

  • (DateTime)


3887
3888
3889
# File 'lib/google/apis/drive_v3/classes.rb', line 3887

def created_time
  @created_time
end

#deletedBoolean Also known as: deleted?

Output only. Whether the reply has been deleted. A deleted reply has no content. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


3893
3894
3895
# File 'lib/google/apis/drive_v3/classes.rb', line 3893

def deleted
  @deleted
end

#html_contentString

Output only. The content of the reply with HTML formatting. Corresponds to the JSON property htmlContent

Returns:

  • (String)


3899
3900
3901
# File 'lib/google/apis/drive_v3/classes.rb', line 3899

def html_content
  @html_content
end

#idString

Output only. The ID of the reply. Corresponds to the JSON property id

Returns:

  • (String)


3904
3905
3906
# File 'lib/google/apis/drive_v3/classes.rb', line 3904

def id
  @id
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "drive#reply". Corresponds to the JSON property kind

Returns:

  • (String)


3910
3911
3912
# File 'lib/google/apis/drive_v3/classes.rb', line 3910

def kind
  @kind
end

#mentioned_email_addressesArray<String>

Output only. A list of email addresses for users mentioned in this comment. If no users are mentioned, the list is empty. Corresponds to the JSON property mentionedEmailAddresses

Returns:

  • (Array<String>)


3916
3917
3918
# File 'lib/google/apis/drive_v3/classes.rb', line 3916

def mentioned_email_addresses
  @mentioned_email_addresses
end

#modified_timeDateTime

The last time the reply was modified (RFC 3339 date-time). Corresponds to the JSON property modifiedTime

Returns:

  • (DateTime)


3921
3922
3923
# File 'lib/google/apis/drive_v3/classes.rb', line 3921

def modified_time
  @modified_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3928
3929
3930
3931
3932
3933
3934
3935
3936
3937
3938
3939
3940
# File 'lib/google/apis/drive_v3/classes.rb', line 3928

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @assignee_email_address = args[:assignee_email_address] if args.key?(:assignee_email_address)
  @author = args[:author] if args.key?(:author)
  @content = args[:content] if args.key?(:content)
  @created_time = args[:created_time] if args.key?(:created_time)
  @deleted = args[:deleted] if args.key?(:deleted)
  @html_content = args[:html_content] if args.key?(:html_content)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @mentioned_email_addresses = args[:mentioned_email_addresses] if args.key?(:mentioned_email_addresses)
  @modified_time = args[:modified_time] if args.key?(:modified_time)
end