Class: Google::Apis::DriveV3::ReplyList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::ReplyList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of replies to a comment on a file.
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The page token for the next page of replies.
-
#replies ⇒ Array<Google::Apis::DriveV3::Reply>
The list of replies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplyList
constructor
A new instance of ReplyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplyList
Returns a new instance of ReplyList.
3970 3971 3972 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
replyList".
Corresponds to the JSON property kind
3953 3954 3955 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3953 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of replies. This will be absent if the end of
the replies list has been reached. If the token is rejected for any reason, it
should be discarded, and pagination should be restarted from the first page of
results. The page token is typically valid for several hours. However, if new
items are added or removed, your expected results might differ.
Corresponds to the JSON property nextPageToken
3962 3963 3964 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3962 def next_page_token @next_page_token end |
#replies ⇒ Array<Google::Apis::DriveV3::Reply>
The list of replies. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property replies
3968 3969 3970 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3968 def replies @replies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3975 3976 3977 3978 3979 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3975 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @replies = args[:replies] if args.key?(:replies) end |