Class: Google::Apis::DriveV3::ResolveAccessProposalRequest
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::ResolveAccessProposalRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Request message for resolving an AccessProposal on a file.
Instance Attribute Summary collapse
-
#action ⇒ String
Required.
-
#role ⇒ Array<String>
Optional.
-
#send_notification ⇒ Boolean
(also: #send_notification?)
Optional.
-
#view ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResolveAccessProposalRequest
constructor
A new instance of ResolveAccessProposalRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResolveAccessProposalRequest
Returns a new instance of ResolveAccessProposalRequest.
4010 4011 4012 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Required. The action to take on the access proposal.
Corresponds to the JSON property action
3987 3988 3989 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3987 def action @action end |
#role ⇒ Array<String>
Optional. The roles that the approver has allowed, if any. For more
information, see Roles and permissions. Note: This field is required for the
ACCEPT action.
Corresponds to the JSON property role
3995 3996 3997 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3995 def role @role end |
#send_notification ⇒ Boolean Also known as: send_notification?
Optional. Whether to send an email to the requester when the access proposal
is denied or accepted.
Corresponds to the JSON property sendNotification
4001 4002 4003 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4001 def send_notification @send_notification end |
#view ⇒ String
Optional. Indicates the view for this access proposal. This should only be set
when the proposal belongs to a view. Only published is supported.
Corresponds to the JSON property view
4008 4009 4010 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4008 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4015 4016 4017 4018 4019 4020 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4015 def update!(**args) @action = args[:action] if args.key?(:action) @role = args[:role] if args.key?(:role) @send_notification = args[:send_notification] if args.key?(:send_notification) @view = args[:view] if args.key?(:view) end |