Class: Google::Apis::DriveV3::ApprovalList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

The response of an approvals list request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApprovalList

Returns a new instance of ApprovalList.



681
682
683
# File 'lib/google/apis/drive_v3/classes.rb', line 681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::DriveV3::Approval>

The list of approvals. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property items



666
667
668
# File 'lib/google/apis/drive_v3/classes.rb', line 666

def items
  @items
end

#kindString

This is always drive#approvalList Corresponds to the JSON property kind

Returns:

  • (String)


671
672
673
# File 'lib/google/apis/drive_v3/classes.rb', line 671

def kind
  @kind
end

#next_page_tokenString

The page token for the next page of approvals. This is absent if the end of the approvals list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


679
680
681
# File 'lib/google/apis/drive_v3/classes.rb', line 679

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



686
687
688
689
690
# File 'lib/google/apis/drive_v3/classes.rb', line 686

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end