Class: Google::Apis::DriveV3::ApprovalList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::ApprovalList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
The response of an Approvals list request.
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::DriveV3::Approval>
The list of Approvals.
-
#kind ⇒ String
This is always drive#approvalList Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
The page token for the next page of Approvals.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApprovalList
constructor
A new instance of ApprovalList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApprovalList
Returns a new instance of ApprovalList.
662 663 664 |
# File 'lib/google/apis/drive_v3/classes.rb', line 662 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::DriveV3::Approval>
The list of Approvals. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property items
647 648 649 |
# File 'lib/google/apis/drive_v3/classes.rb', line 647 def items @items end |
#kind ⇒ String
This is always drive#approvalList
Corresponds to the JSON property kind
652 653 654 |
# File 'lib/google/apis/drive_v3/classes.rb', line 652 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of Approvals. This will be absent if the end
of the Approvals list has been reached. If the token is rejected for any
reason, it should be discarded, and pagination should be restarted from the
first page of results.
Corresponds to the JSON property nextPageToken
660 661 662 |
# File 'lib/google/apis/drive_v3/classes.rb', line 660 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
667 668 669 670 671 |
# File 'lib/google/apis/drive_v3/classes.rb', line 667 def update!(**args) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |