Class: Google::Apis::DriveV3::ApproveApprovalRequest
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::ApproveApprovalRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Request for approving an approval as a reviewer.
Instance Attribute Summary collapse
-
#message ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApproveApprovalRequest
constructor
A new instance of ApproveApprovalRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApproveApprovalRequest
Returns a new instance of ApproveApprovalRequest.
704 705 706 |
# File 'lib/google/apis/drive_v3/classes.rb', line 704 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ String
Optional. A message to accompany the reviewer response on the approval. This
message is included in notifications for the action and in the approval
activity log.
Corresponds to the JSON property message
702 703 704 |
# File 'lib/google/apis/drive_v3/classes.rb', line 702 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
709 710 711 |
# File 'lib/google/apis/drive_v3/classes.rb', line 709 def update!(**args) @message = args[:message] if args.key?(:message) end |