Class: Google::Apis::DriveV3::CancelApprovalRequest
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::CancelApprovalRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Request for cancelling an approval as an initiator.
Instance Attribute Summary collapse
-
#message ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CancelApprovalRequest
constructor
A new instance of CancelApprovalRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CancelApprovalRequest
Returns a new instance of CancelApprovalRequest.
725 726 727 |
# File 'lib/google/apis/drive_v3/classes.rb', line 725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ String
Optional. A message to accompany the cancellation of the approval. This
message is included in notifications for the action and in the approval
activity log.
Corresponds to the JSON property message
723 724 725 |
# File 'lib/google/apis/drive_v3/classes.rb', line 723 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
730 731 732 |
# File 'lib/google/apis/drive_v3/classes.rb', line 730 def update!(**args) @message = args[:message] if args.key?(:message) end |