Class: Google::Apis::DriveV3::ChangeList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::ChangeList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of changes for a user.
Instance Attribute Summary collapse
-
#changes ⇒ Array<Google::Apis::DriveV3::Change>
The list of changes.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#new_start_page_token ⇒ String
The starting page token for future changes.
-
#next_page_token ⇒ String
The page token for the next page of changes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChangeList
constructor
A new instance of ChangeList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChangeList
Returns a new instance of ChangeList.
849 850 851 |
# File 'lib/google/apis/drive_v3/classes.rb', line 849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#changes ⇒ Array<Google::Apis::DriveV3::Change>
The list of changes. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property changes
828 829 830 |
# File 'lib/google/apis/drive_v3/classes.rb', line 828 def changes @changes end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
changeList".
Corresponds to the JSON property kind
834 835 836 |
# File 'lib/google/apis/drive_v3/classes.rb', line 834 def kind @kind end |
#new_start_page_token ⇒ String
The starting page token for future changes. This will be present only if the
end of the current changes list has been reached. The page token doesn't
expire.
Corresponds to the JSON property newStartPageToken
841 842 843 |
# File 'lib/google/apis/drive_v3/classes.rb', line 841 def new_start_page_token @new_start_page_token end |
#next_page_token ⇒ String
The page token for the next page of changes. This will be absent if the end of
the changes list has been reached. The page token doesn't expire.
Corresponds to the JSON property nextPageToken
847 848 849 |
# File 'lib/google/apis/drive_v3/classes.rb', line 847 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
854 855 856 857 858 859 |
# File 'lib/google/apis/drive_v3/classes.rb', line 854 def update!(**args) @changes = args[:changes] if args.key?(:changes) @kind = args[:kind] if args.key?(:kind) @new_start_page_token = args[:new_start_page_token] if args.key?(:new_start_page_token) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |