Class: Google::Apis::DriveV3::Comment
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::Comment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A comment on a file. Some resource methods (such as comments.update) require
a commentId. Use the comments.list method to retrieve the ID for a comment
in a file.
Defined Under Namespace
Classes: QuotedFileContent
Instance Attribute Summary collapse
-
#anchor ⇒ String
A region of the document represented as a JSON string.
-
#assignee_email_address ⇒ String
Output only.
-
#author ⇒ Google::Apis::DriveV3::User
Information about a Drive user.
-
#content ⇒ String
The plain text content of the comment.
-
#created_time ⇒ DateTime
The time at which the comment was created (RFC 3339 date-time).
-
#deleted ⇒ Boolean
(also: #deleted?)
Output only.
-
#html_content ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#kind ⇒ String
Output only.
-
#mentioned_email_addresses ⇒ Array<String>
Output only.
-
#modified_time ⇒ DateTime
The last time the comment or any of its replies was modified (RFC 3339 date- time).
-
#quoted_file_content ⇒ Google::Apis::DriveV3::Comment::QuotedFileContent
The file content to which the comment refers, typically within the anchor region.
-
#replies ⇒ Array<Google::Apis::DriveV3::Reply>
Output only.
-
#resolved ⇒ Boolean
(also: #resolved?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Comment
constructor
A new instance of Comment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Comment
Returns a new instance of Comment.
1055 1056 1057 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#anchor ⇒ String
A region of the document represented as a JSON string. For details on defining
anchor properties, refer to Manage comments and replies.
Corresponds to the JSON property anchor
978 979 980 |
# File 'lib/google/apis/drive_v3/classes.rb', line 978 def anchor @anchor end |
#assignee_email_address ⇒ String
Output only. The email address of the user assigned to this comment. If no
user is assigned, the field is unset.
Corresponds to the JSON property assigneeEmailAddress
984 985 986 |
# File 'lib/google/apis/drive_v3/classes.rb', line 984 def assignee_email_address @assignee_email_address end |
#author ⇒ Google::Apis::DriveV3::User
Information about a Drive user.
Corresponds to the JSON property author
989 990 991 |
# File 'lib/google/apis/drive_v3/classes.rb', line 989 def @author end |
#content ⇒ String
The plain text content of the comment. This field is used for setting the
content, while htmlContent should be displayed.
Corresponds to the JSON property content
995 996 997 |
# File 'lib/google/apis/drive_v3/classes.rb', line 995 def content @content end |
#created_time ⇒ DateTime
The time at which the comment was created (RFC 3339 date-time).
Corresponds to the JSON property createdTime
1000 1001 1002 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1000 def created_time @created_time end |
#deleted ⇒ Boolean Also known as: deleted?
Output only. Whether the comment has been deleted. A deleted comment has no
content.
Corresponds to the JSON property deleted
1006 1007 1008 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1006 def deleted @deleted end |
#html_content ⇒ String
Output only. The content of the comment with HTML formatting.
Corresponds to the JSON property htmlContent
1012 1013 1014 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1012 def html_content @html_content end |
#id ⇒ String
Output only. The ID of the comment.
Corresponds to the JSON property id
1017 1018 1019 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1017 def id @id end |
#kind ⇒ String
Output only. Identifies what kind of resource this is. Value: the fixed string
"drive#comment".
Corresponds to the JSON property kind
1023 1024 1025 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1023 def kind @kind end |
#mentioned_email_addresses ⇒ Array<String>
Output only. A list of email addresses for users mentioned in this comment. If
no users are mentioned, the list is empty.
Corresponds to the JSON property mentionedEmailAddresses
1029 1030 1031 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1029 def mentioned_email_addresses @mentioned_email_addresses end |
#modified_time ⇒ DateTime
The last time the comment or any of its replies was modified (RFC 3339 date-
time).
Corresponds to the JSON property modifiedTime
1035 1036 1037 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1035 def modified_time @modified_time end |
#quoted_file_content ⇒ Google::Apis::DriveV3::Comment::QuotedFileContent
The file content to which the comment refers, typically within the anchor
region. For a text file, for example, this would be the text at the location
of the comment.
Corresponds to the JSON property quotedFileContent
1042 1043 1044 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1042 def quoted_file_content @quoted_file_content end |
#replies ⇒ Array<Google::Apis::DriveV3::Reply>
Output only. The full list of replies to the comment in chronological order.
Corresponds to the JSON property replies
1047 1048 1049 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1047 def replies @replies end |
#resolved ⇒ Boolean Also known as: resolved?
Output only. Whether the comment has been resolved by one of its replies.
Corresponds to the JSON property resolved
1052 1053 1054 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1052 def resolved @resolved end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1060 def update!(**args) @anchor = args[:anchor] if args.key?(:anchor) @assignee_email_address = args[:assignee_email_address] if args.key?(:assignee_email_address) @author = args[:author] if args.key?(:author) @content = args[:content] if args.key?(:content) @created_time = args[:created_time] if args.key?(:created_time) @deleted = args[:deleted] if args.key?(:deleted) @html_content = args[:html_content] if args.key?(:html_content) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @mentioned_email_addresses = args[:mentioned_email_addresses] if args.key?(:mentioned_email_addresses) @modified_time = args[:modified_time] if args.key?(:modified_time) @quoted_file_content = args[:quoted_file_content] if args.key?(:quoted_file_content) @replies = args[:replies] if args.key?(:replies) @resolved = args[:resolved] if args.key?(:resolved) end |