Class: Google::Apis::DriveV3::Comment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A comment on a file. Some resource methods (such as comments.update) require a commentId. Use the comments.list method to retrieve the ID for a comment in a file.

Defined Under Namespace

Classes: QuotedFileContent

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Comment

Returns a new instance of Comment.



994
995
996
# File 'lib/google/apis/drive_v3/classes.rb', line 994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anchorString

A region of the document represented as a JSON string. For details on defining anchor properties, refer to Manage comments and replies. Corresponds to the JSON property anchor

Returns:

  • (String)


917
918
919
# File 'lib/google/apis/drive_v3/classes.rb', line 917

def anchor
  @anchor
end

#assignee_email_addressString

Output only. The email address of the user assigned to this comment. If no user is assigned, the field is unset. Corresponds to the JSON property assigneeEmailAddress

Returns:

  • (String)


923
924
925
# File 'lib/google/apis/drive_v3/classes.rb', line 923

def assignee_email_address
  @assignee_email_address
end

#authorGoogle::Apis::DriveV3::User

Information about a Drive user. Corresponds to the JSON property author



928
929
930
# File 'lib/google/apis/drive_v3/classes.rb', line 928

def author
  @author
end

#contentString

The plain text content of the comment. This field is used for setting the content, while htmlContent should be displayed. Corresponds to the JSON property content

Returns:

  • (String)


934
935
936
# File 'lib/google/apis/drive_v3/classes.rb', line 934

def content
  @content
end

#created_timeDateTime

The time at which the comment was created (RFC 3339 date-time). Corresponds to the JSON property createdTime

Returns:

  • (DateTime)


939
940
941
# File 'lib/google/apis/drive_v3/classes.rb', line 939

def created_time
  @created_time
end

#deletedBoolean Also known as: deleted?

Output only. Whether the comment has been deleted. A deleted comment has no content. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


945
946
947
# File 'lib/google/apis/drive_v3/classes.rb', line 945

def deleted
  @deleted
end

#html_contentString

Output only. The content of the comment with HTML formatting. Corresponds to the JSON property htmlContent

Returns:

  • (String)


951
952
953
# File 'lib/google/apis/drive_v3/classes.rb', line 951

def html_content
  @html_content
end

#idString

Output only. The ID of the comment. Corresponds to the JSON property id

Returns:

  • (String)


956
957
958
# File 'lib/google/apis/drive_v3/classes.rb', line 956

def id
  @id
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "drive#comment". Corresponds to the JSON property kind

Returns:

  • (String)


962
963
964
# File 'lib/google/apis/drive_v3/classes.rb', line 962

def kind
  @kind
end

#mentioned_email_addressesArray<String>

Output only. A list of email addresses for users mentioned in this comment. If no users are mentioned, the list is empty. Corresponds to the JSON property mentionedEmailAddresses

Returns:

  • (Array<String>)


968
969
970
# File 'lib/google/apis/drive_v3/classes.rb', line 968

def mentioned_email_addresses
  @mentioned_email_addresses
end

#modified_timeDateTime

The last time the comment or any of its replies was modified (RFC 3339 date- time). Corresponds to the JSON property modifiedTime

Returns:

  • (DateTime)


974
975
976
# File 'lib/google/apis/drive_v3/classes.rb', line 974

def modified_time
  @modified_time
end

#quoted_file_contentGoogle::Apis::DriveV3::Comment::QuotedFileContent

The file content to which the comment refers, typically within the anchor region. For a text file, for example, this would be the text at the location of the comment. Corresponds to the JSON property quotedFileContent



981
982
983
# File 'lib/google/apis/drive_v3/classes.rb', line 981

def quoted_file_content
  @quoted_file_content
end

#repliesArray<Google::Apis::DriveV3::Reply>

Output only. The full list of replies to the comment in chronological order. Corresponds to the JSON property replies

Returns:



986
987
988
# File 'lib/google/apis/drive_v3/classes.rb', line 986

def replies
  @replies
end

#resolvedBoolean Also known as: resolved?

Output only. Whether the comment has been resolved by one of its replies. Corresponds to the JSON property resolved

Returns:

  • (Boolean)


991
992
993
# File 'lib/google/apis/drive_v3/classes.rb', line 991

def resolved
  @resolved
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
# File 'lib/google/apis/drive_v3/classes.rb', line 999

def update!(**args)
  @anchor = args[:anchor] if args.key?(:anchor)
  @assignee_email_address = args[:assignee_email_address] if args.key?(:assignee_email_address)
  @author = args[:author] if args.key?(:author)
  @content = args[:content] if args.key?(:content)
  @created_time = args[:created_time] if args.key?(:created_time)
  @deleted = args[:deleted] if args.key?(:deleted)
  @html_content = args[:html_content] if args.key?(:html_content)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @mentioned_email_addresses = args[:mentioned_email_addresses] if args.key?(:mentioned_email_addresses)
  @modified_time = args[:modified_time] if args.key?(:modified_time)
  @quoted_file_content = args[:quoted_file_content] if args.key?(:quoted_file_content)
  @replies = args[:replies] if args.key?(:replies)
  @resolved = args[:resolved] if args.key?(:resolved)
end