Class: Google::Apis::DriveV3::DeclineApprovalRequest
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::DeclineApprovalRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Request for declining an approval as a reviewer.
Instance Attribute Summary collapse
-
#message ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeclineApprovalRequest
constructor
A new instance of DeclineApprovalRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeclineApprovalRequest
Returns a new instance of DeclineApprovalRequest.
1241 1242 1243 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ String
Optional. A message to accompany the reviewer response on the approval. This
message is included in notifications for the action and in the approval
activity log.
Corresponds to the JSON property message
1239 1240 1241 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1239 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1246 1247 1248 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1246 def update!(**args) @message = args[:message] if args.key?(:message) end |