Class: Google::Apis::DriveV3::DecryptionMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Representation of the CSE DecryptionMetadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DecryptionMetadata

Returns a new instance of DecryptionMetadata.



1296
1297
1298
# File 'lib/google/apis/drive_v3/classes.rb', line 1296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aes256_gcm_chunk_sizeString

Chunk size used if content was encrypted with the AES 256 GCM Cipher. Possible values are: - default - small Corresponds to the JSON property aes256GcmChunkSize

Returns:

  • (String)


1259
1260
1261
# File 'lib/google/apis/drive_v3/classes.rb', line 1259

def aes256_gcm_chunk_size
  @aes256_gcm_chunk_size
end

#encryption_resource_key_hashString

The URL-safe Base64 encoded HMAC-SHA256 digest of the resource metadata with its DEK (Data Encryption Key); see https://developers.google.com/workspace/cse/ reference Corresponds to the JSON property encryptionResourceKeyHash

Returns:

  • (String)


1266
1267
1268
# File 'lib/google/apis/drive_v3/classes.rb', line 1266

def encryption_resource_key_hash
  @encryption_resource_key_hash
end

#jwtString

The signed JSON Web Token (JWT) which can be used to authorize the requesting user with the Key ACL Service (KACLS). The JWT asserts that the requesting user has at least read permissions on the file. Corresponds to the JSON property jwt

Returns:

  • (String)


1273
1274
1275
# File 'lib/google/apis/drive_v3/classes.rb', line 1273

def jwt
  @jwt
end

#kacls_idFixnum

The ID of the KACLS (Key ACL Service) used to encrypt the file. Corresponds to the JSON property kaclsId

Returns:

  • (Fixnum)


1278
1279
1280
# File 'lib/google/apis/drive_v3/classes.rb', line 1278

def kacls_id
  @kacls_id
end

#kacls_nameString

The name of the KACLS (Key ACL Service) used to encrypt the file. Corresponds to the JSON property kaclsName

Returns:

  • (String)


1283
1284
1285
# File 'lib/google/apis/drive_v3/classes.rb', line 1283

def kacls_name
  @kacls_name
end

#key_formatString

Key format for the unwrapped key. Must be tinkAesGcmKey. Corresponds to the JSON property keyFormat

Returns:

  • (String)


1288
1289
1290
# File 'lib/google/apis/drive_v3/classes.rb', line 1288

def key_format
  @key_format
end

#wrapped_keyString

The URL-safe Base64 encoded wrapped key used to encrypt the contents of the file. Corresponds to the JSON property wrappedKey

Returns:

  • (String)


1294
1295
1296
# File 'lib/google/apis/drive_v3/classes.rb', line 1294

def wrapped_key
  @wrapped_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1301
1302
1303
1304
1305
1306
1307
1308
1309
# File 'lib/google/apis/drive_v3/classes.rb', line 1301

def update!(**args)
  @aes256_gcm_chunk_size = args[:aes256_gcm_chunk_size] if args.key?(:aes256_gcm_chunk_size)
  @encryption_resource_key_hash = args[:encryption_resource_key_hash] if args.key?(:encryption_resource_key_hash)
  @jwt = args[:jwt] if args.key?(:jwt)
  @kacls_id = args[:kacls_id] if args.key?(:kacls_id)
  @kacls_name = args[:kacls_name] if args.key?(:kacls_name)
  @key_format = args[:key_format] if args.key?(:key_format)
  @wrapped_key = args[:wrapped_key] if args.key?(:wrapped_key)
end