Class: Google::Apis::DriveV3::DownloadRestrictionsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::DownloadRestrictionsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Download restrictions applied to the file.
Instance Attribute Summary collapse
-
#effective_download_restriction_with_context ⇒ Google::Apis::DriveV3::DownloadRestriction
A restriction for copy and download of the file.
-
#item_download_restriction ⇒ Google::Apis::DriveV3::DownloadRestriction
A restriction for copy and download of the file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DownloadRestrictionsMetadata
constructor
A new instance of DownloadRestrictionsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DownloadRestrictionsMetadata
Returns a new instance of DownloadRestrictionsMetadata.
1360 1361 1362 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1360 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_download_restriction_with_context ⇒ Google::Apis::DriveV3::DownloadRestriction
A restriction for copy and download of the file.
Corresponds to the JSON property effectiveDownloadRestrictionWithContext
1353 1354 1355 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1353 def effective_download_restriction_with_context @effective_download_restriction_with_context end |
#item_download_restriction ⇒ Google::Apis::DriveV3::DownloadRestriction
A restriction for copy and download of the file.
Corresponds to the JSON property itemDownloadRestriction
1358 1359 1360 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1358 def item_download_restriction @item_download_restriction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1365 1366 1367 1368 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1365 def update!(**args) @effective_download_restriction_with_context = args[:effective_download_restriction_with_context] if args.key?(:effective_download_restriction_with_context) @item_download_restriction = args[:item_download_restriction] if args.key?(:item_download_restriction) end |