Class: Google::Apis::DriveV3::DownloadRestrictionsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Download restrictions applied to the file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DownloadRestrictionsMetadata

Returns a new instance of DownloadRestrictionsMetadata.



1252
1253
1254
# File 'lib/google/apis/drive_v3/classes.rb', line 1252

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_download_restriction_with_contextGoogle::Apis::DriveV3::DownloadRestriction

A restriction for copy and download of the file. Corresponds to the JSON property effectiveDownloadRestrictionWithContext



1245
1246
1247
# File 'lib/google/apis/drive_v3/classes.rb', line 1245

def effective_download_restriction_with_context
  @effective_download_restriction_with_context
end

#item_download_restrictionGoogle::Apis::DriveV3::DownloadRestriction

A restriction for copy and download of the file. Corresponds to the JSON property itemDownloadRestriction



1250
1251
1252
# File 'lib/google/apis/drive_v3/classes.rb', line 1250

def item_download_restriction
  @item_download_restriction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1257
1258
1259
1260
# File 'lib/google/apis/drive_v3/classes.rb', line 1257

def update!(**args)
  @effective_download_restriction_with_context = args[:effective_download_restriction_with_context] if args.key?(:effective_download_restriction_with_context)
  @item_download_restriction = args[:item_download_restriction] if args.key?(:item_download_restriction)
end