Class: Google::Apis::DriveV3::Drive

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Representation of a shared drive. Some resource methods (such as drives. update) require a driveId. Use the drives.list method to retrieve the ID for a shared drive.

Defined Under Namespace

Classes: BackgroundImageFile, Capabilities, Restrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Drive

Returns a new instance of Drive.



1448
1449
1450
# File 'lib/google/apis/drive_v3/classes.rb', line 1448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_image_fileGoogle::Apis::DriveV3::Drive::BackgroundImageFile

An image file and cropping parameters from which a background image for this shared drive is set. This is a write only field; it can only be set on drive. drives.update requests that don't set themeId. When specified, all fields of the backgroundImageFile must be set. Corresponds to the JSON property backgroundImageFile



1377
1378
1379
# File 'lib/google/apis/drive_v3/classes.rb', line 1377

def background_image_file
  @background_image_file
end

Output only. A short-lived link to this shared drive's background image. Corresponds to the JSON property backgroundImageLink

Returns:

  • (String)


1382
1383
1384
# File 'lib/google/apis/drive_v3/classes.rb', line 1382

def background_image_link
  @background_image_link
end

#capabilitiesGoogle::Apis::DriveV3::Drive::Capabilities

Output only. Capabilities the current user has on this shared drive. Corresponds to the JSON property capabilities



1387
1388
1389
# File 'lib/google/apis/drive_v3/classes.rb', line 1387

def capabilities
  @capabilities
end

#color_rgbString

The color of this shared drive as an RGB hex string. It can only be set on a drive.drives.update request that does not set themeId. Corresponds to the JSON property colorRgb

Returns:

  • (String)


1393
1394
1395
# File 'lib/google/apis/drive_v3/classes.rb', line 1393

def color_rgb
  @color_rgb
end

#created_timeDateTime

The time at which the shared drive was created (RFC 3339 date-time). Corresponds to the JSON property createdTime

Returns:

  • (DateTime)


1398
1399
1400
# File 'lib/google/apis/drive_v3/classes.rb', line 1398

def created_time
  @created_time
end

#hiddenBoolean Also known as: hidden?

Whether the shared drive is hidden from default view. Corresponds to the JSON property hidden

Returns:

  • (Boolean)


1403
1404
1405
# File 'lib/google/apis/drive_v3/classes.rb', line 1403

def hidden
  @hidden
end

#idString

Output only. The ID of this shared drive which is also the ID of the top level folder of this shared drive. Corresponds to the JSON property id

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/drive_v3/classes.rb', line 1410

def id
  @id
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "drive#drive". Corresponds to the JSON property kind

Returns:

  • (String)


1416
1417
1418
# File 'lib/google/apis/drive_v3/classes.rb', line 1416

def kind
  @kind
end

#nameString

The name of this shared drive. Corresponds to the JSON property name

Returns:

  • (String)


1421
1422
1423
# File 'lib/google/apis/drive_v3/classes.rb', line 1421

def name
  @name
end

#org_unit_idString

Output only. The organizational unit of this shared drive. This field is only populated on drives.list responses when the useDomainAdminAccess parameter is set to true. Corresponds to the JSON property orgUnitId

Returns:

  • (String)


1428
1429
1430
# File 'lib/google/apis/drive_v3/classes.rb', line 1428

def org_unit_id
  @org_unit_id
end

#restrictionsGoogle::Apis::DriveV3::Drive::Restrictions

A set of restrictions that apply to this shared drive or items inside this shared drive. Note that restrictions can't be set when creating a shared drive. To add a restriction, first create a shared drive and then use drives.update to add restrictions. Corresponds to the JSON property restrictions



1436
1437
1438
# File 'lib/google/apis/drive_v3/classes.rb', line 1436

def restrictions
  @restrictions
end

#theme_idString

The ID of the theme from which the background image and color will be set. The set of possible driveThemes can be retrieved from a drive.about.get response. When not specified on a drive.drives.create request, a random theme is chosen from which the background image and color are set. This is a write-only field; it can only be set on requests that don't set colorRgb or backgroundImageFile. Corresponds to the JSON property themeId

Returns:

  • (String)


1446
1447
1448
# File 'lib/google/apis/drive_v3/classes.rb', line 1446

def theme_id
  @theme_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
# File 'lib/google/apis/drive_v3/classes.rb', line 1453

def update!(**args)
  @background_image_file = args[:background_image_file] if args.key?(:background_image_file)
  @background_image_link = args[:background_image_link] if args.key?(:background_image_link)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @color_rgb = args[:color_rgb] if args.key?(:color_rgb)
  @created_time = args[:created_time] if args.key?(:created_time)
  @hidden = args[:hidden] if args.key?(:hidden)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id)
  @restrictions = args[:restrictions] if args.key?(:restrictions)
  @theme_id = args[:theme_id] if args.key?(:theme_id)
end