Class: Google::Apis::DriveV3::Drive

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Representation of a shared drive. Some resource methods (such as drives. update) require a driveId. Use the drives.list method to retrieve the ID for a shared drive.

Defined Under Namespace

Classes: BackgroundImageFile, Capabilities, Restrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Drive

Returns a new instance of Drive.



1346
1347
1348
# File 'lib/google/apis/drive_v3/classes.rb', line 1346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_image_fileGoogle::Apis::DriveV3::Drive::BackgroundImageFile

An image file and cropping parameters from which a background image for this shared drive is set. This is a write only field; it can only be set on drive. drives.update requests that don't set themeId. When specified, all fields of the backgroundImageFile must be set. Corresponds to the JSON property backgroundImageFile



1275
1276
1277
# File 'lib/google/apis/drive_v3/classes.rb', line 1275

def background_image_file
  @background_image_file
end

Output only. A short-lived link to this shared drive's background image. Corresponds to the JSON property backgroundImageLink

Returns:

  • (String)


1280
1281
1282
# File 'lib/google/apis/drive_v3/classes.rb', line 1280

def background_image_link
  @background_image_link
end

#capabilitiesGoogle::Apis::DriveV3::Drive::Capabilities

Output only. Capabilities the current user has on this shared drive. Corresponds to the JSON property capabilities



1285
1286
1287
# File 'lib/google/apis/drive_v3/classes.rb', line 1285

def capabilities
  @capabilities
end

#color_rgbString

The color of this shared drive as an RGB hex string. It can only be set on a drive.drives.update request that does not set themeId. Corresponds to the JSON property colorRgb

Returns:

  • (String)


1291
1292
1293
# File 'lib/google/apis/drive_v3/classes.rb', line 1291

def color_rgb
  @color_rgb
end

#created_timeDateTime

The time at which the shared drive was created (RFC 3339 date-time). Corresponds to the JSON property createdTime

Returns:

  • (DateTime)


1296
1297
1298
# File 'lib/google/apis/drive_v3/classes.rb', line 1296

def created_time
  @created_time
end

#hiddenBoolean Also known as: hidden?

Whether the shared drive is hidden from default view. Corresponds to the JSON property hidden

Returns:

  • (Boolean)


1301
1302
1303
# File 'lib/google/apis/drive_v3/classes.rb', line 1301

def hidden
  @hidden
end

#idString

Output only. The ID of this shared drive which is also the ID of the top level folder of this shared drive. Corresponds to the JSON property id

Returns:

  • (String)


1308
1309
1310
# File 'lib/google/apis/drive_v3/classes.rb', line 1308

def id
  @id
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "drive#drive". Corresponds to the JSON property kind

Returns:

  • (String)


1314
1315
1316
# File 'lib/google/apis/drive_v3/classes.rb', line 1314

def kind
  @kind
end

#nameString

The name of this shared drive. Corresponds to the JSON property name

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/drive_v3/classes.rb', line 1319

def name
  @name
end

#org_unit_idString

Output only. The organizational unit of this shared drive. This field is only populated on drives.list responses when the useDomainAdminAccess parameter is set to true. Corresponds to the JSON property orgUnitId

Returns:

  • (String)


1326
1327
1328
# File 'lib/google/apis/drive_v3/classes.rb', line 1326

def org_unit_id
  @org_unit_id
end

#restrictionsGoogle::Apis::DriveV3::Drive::Restrictions

A set of restrictions that apply to this shared drive or items inside this shared drive. Note that restrictions can't be set when creating a shared drive. To add a restriction, first create a shared drive and then use drives.update to add restrictions. Corresponds to the JSON property restrictions



1334
1335
1336
# File 'lib/google/apis/drive_v3/classes.rb', line 1334

def restrictions
  @restrictions
end

#theme_idString

The ID of the theme from which the background image and color will be set. The set of possible driveThemes can be retrieved from a drive.about.get response. When not specified on a drive.drives.create request, a random theme is chosen from which the background image and color are set. This is a write-only field; it can only be set on requests that don't set colorRgb or backgroundImageFile. Corresponds to the JSON property themeId

Returns:

  • (String)


1344
1345
1346
# File 'lib/google/apis/drive_v3/classes.rb', line 1344

def theme_id
  @theme_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/google/apis/drive_v3/classes.rb', line 1351

def update!(**args)
  @background_image_file = args[:background_image_file] if args.key?(:background_image_file)
  @background_image_link = args[:background_image_link] if args.key?(:background_image_link)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @color_rgb = args[:color_rgb] if args.key?(:color_rgb)
  @created_time = args[:created_time] if args.key?(:created_time)
  @hidden = args[:hidden] if args.key?(:hidden)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id)
  @restrictions = args[:restrictions] if args.key?(:restrictions)
  @theme_id = args[:theme_id] if args.key?(:theme_id)
end