Class: Google::Apis::DriveV3::Drive
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::Drive
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Representation of a shared drive. Some resource methods (such as drives.
update) require a driveId. Use the drives.list method to retrieve the ID
for a shared drive.
Defined Under Namespace
Classes: BackgroundImageFile, Capabilities, Restrictions
Instance Attribute Summary collapse
-
#background_image_file ⇒ Google::Apis::DriveV3::Drive::BackgroundImageFile
An image file and cropping parameters from which a background image for this shared drive is set.
-
#background_image_link ⇒ String
Output only.
-
#capabilities ⇒ Google::Apis::DriveV3::Drive::Capabilities
Output only.
-
#color_rgb ⇒ String
The color of this shared drive as an RGB hex string.
-
#created_time ⇒ DateTime
The time at which the shared drive was created (RFC 3339 date-time).
-
#hidden ⇒ Boolean
(also: #hidden?)
Whether the shared drive is hidden from default view.
-
#id ⇒ String
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of this shared drive.
-
#org_unit_id ⇒ String
Output only.
-
#restrictions ⇒ Google::Apis::DriveV3::Drive::Restrictions
A set of restrictions that apply to this shared drive or items inside this shared drive.
-
#theme_id ⇒ String
The ID of the theme from which the background image and color will be set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Drive
constructor
A new instance of Drive.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Drive
Returns a new instance of Drive.
1346 1347 1348 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_image_file ⇒ Google::Apis::DriveV3::Drive::BackgroundImageFile
An image file and cropping parameters from which a background image for this
shared drive is set. This is a write only field; it can only be set on drive.
drives.update requests that don't set themeId. When specified, all fields
of the backgroundImageFile must be set.
Corresponds to the JSON property backgroundImageFile
1275 1276 1277 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1275 def background_image_file @background_image_file end |
#background_image_link ⇒ String
Output only. A short-lived link to this shared drive's background image.
Corresponds to the JSON property backgroundImageLink
1280 1281 1282 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1280 def background_image_link @background_image_link end |
#capabilities ⇒ Google::Apis::DriveV3::Drive::Capabilities
Output only. Capabilities the current user has on this shared drive.
Corresponds to the JSON property capabilities
1285 1286 1287 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1285 def capabilities @capabilities end |
#color_rgb ⇒ String
The color of this shared drive as an RGB hex string. It can only be set on a
drive.drives.update request that does not set themeId.
Corresponds to the JSON property colorRgb
1291 1292 1293 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1291 def color_rgb @color_rgb end |
#created_time ⇒ DateTime
The time at which the shared drive was created (RFC 3339 date-time).
Corresponds to the JSON property createdTime
1296 1297 1298 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1296 def created_time @created_time end |
#hidden ⇒ Boolean Also known as:
Whether the shared drive is hidden from default view.
Corresponds to the JSON property hidden
1301 1302 1303 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1301 def hidden @hidden end |
#id ⇒ String
Output only. The ID of this shared drive which is also the ID of the top level
folder of this shared drive.
Corresponds to the JSON property id
1308 1309 1310 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1308 def id @id end |
#kind ⇒ String
Output only. Identifies what kind of resource this is. Value: the fixed string
"drive#drive".
Corresponds to the JSON property kind
1314 1315 1316 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1314 def kind @kind end |
#name ⇒ String
The name of this shared drive.
Corresponds to the JSON property name
1319 1320 1321 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1319 def name @name end |
#org_unit_id ⇒ String
Output only. The organizational unit of this shared drive. This field is only
populated on drives.list responses when the useDomainAdminAccess parameter
is set to true.
Corresponds to the JSON property orgUnitId
1326 1327 1328 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1326 def org_unit_id @org_unit_id end |
#restrictions ⇒ Google::Apis::DriveV3::Drive::Restrictions
A set of restrictions that apply to this shared drive or items inside this
shared drive. Note that restrictions can't be set when creating a shared drive.
To add a restriction, first create a shared drive and then use drives.update
to add restrictions.
Corresponds to the JSON property restrictions
1334 1335 1336 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1334 def restrictions @restrictions end |
#theme_id ⇒ String
The ID of the theme from which the background image and color will be set. The
set of possible driveThemes can be retrieved from a drive.about.get
response. When not specified on a drive.drives.create request, a random
theme is chosen from which the background image and color are set. This is a
write-only field; it can only be set on requests that don't set colorRgb or
backgroundImageFile.
Corresponds to the JSON property themeId
1344 1345 1346 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1344 def theme_id @theme_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1351 def update!(**args) @background_image_file = args[:background_image_file] if args.key?(:background_image_file) @background_image_link = args[:background_image_link] if args.key?(:background_image_link) @capabilities = args[:capabilities] if args.key?(:capabilities) @color_rgb = args[:color_rgb] if args.key?(:color_rgb) @created_time = args[:created_time] if args.key?(:created_time) @hidden = args[:hidden] if args.key?(:hidden) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) @restrictions = args[:restrictions] if args.key?(:restrictions) @theme_id = args[:theme_id] if args.key?(:theme_id) end |