Class: Google::Apis::DriveV3::Drive::Capabilities
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::Drive::Capabilities
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Output only. Capabilities the current user has on this shared drive.
Instance Attribute Summary collapse
-
#can_add_children ⇒ Boolean
(also: #can_add_children?)
Output only.
-
#can_change_copy_requires_writer_permission_restriction ⇒ Boolean
(also: #can_change_copy_requires_writer_permission_restriction?)
Output only.
-
#can_change_domain_users_only_restriction ⇒ Boolean
(also: #can_change_domain_users_only_restriction?)
Output only.
-
#can_change_download_restriction ⇒ Boolean
(also: #can_change_download_restriction?)
Output only.
-
#can_change_drive_background ⇒ Boolean
(also: #can_change_drive_background?)
Output only.
-
#can_change_drive_members_only_restriction ⇒ Boolean
(also: #can_change_drive_members_only_restriction?)
Output only.
-
#can_change_sharing_folders_requires_organizer_permission_restriction ⇒ Boolean
(also: #can_change_sharing_folders_requires_organizer_permission_restriction?)
Output only.
-
#can_comment ⇒ Boolean
(also: #can_comment?)
Output only.
-
#can_copy ⇒ Boolean
(also: #can_copy?)
Output only.
-
#can_delete_children ⇒ Boolean
(also: #can_delete_children?)
Output only.
-
#can_delete_drive ⇒ Boolean
(also: #can_delete_drive?)
Output only.
-
#can_download ⇒ Boolean
(also: #can_download?)
Output only.
-
#can_edit ⇒ Boolean
(also: #can_edit?)
Output only.
-
#can_list_children ⇒ Boolean
(also: #can_list_children?)
Output only.
-
#can_manage_members ⇒ Boolean
(also: #can_manage_members?)
Output only.
-
#can_read_revisions ⇒ Boolean
(also: #can_read_revisions?)
Output only.
-
#can_rename ⇒ Boolean
(also: #can_rename?)
Output only.
-
#can_rename_drive ⇒ Boolean
(also: #can_rename_drive?)
Output only.
-
#can_reset_drive_restrictions ⇒ Boolean
(also: #can_reset_drive_restrictions?)
Output only.
-
#can_share ⇒ Boolean
(also: #can_share?)
Output only.
-
#can_trash_children ⇒ Boolean
(also: #can_trash_children?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Capabilities
constructor
A new instance of Capabilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Capabilities
Returns a new instance of Capabilities.
1672 1673 1674 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_add_children ⇒ Boolean Also known as: can_add_children?
Output only. Whether the current user can add children to folders in this
shared drive.
Corresponds to the JSON property canAddChildren
1532 1533 1534 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1532 def can_add_children @can_add_children end |
#can_change_copy_requires_writer_permission_restriction ⇒ Boolean Also known as: can_change_copy_requires_writer_permission_restriction?
Output only. Whether the current user can change the
copyRequiresWriterPermission restriction of this shared drive.
Corresponds to the JSON property canChangeCopyRequiresWriterPermissionRestriction
1539 1540 1541 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1539 def @can_change_copy_requires_writer_permission_restriction end |
#can_change_domain_users_only_restriction ⇒ Boolean Also known as: can_change_domain_users_only_restriction?
Output only. Whether the current user can change the domainUsersOnly
restriction of this shared drive.
Corresponds to the JSON property canChangeDomainUsersOnlyRestriction
1546 1547 1548 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1546 def can_change_domain_users_only_restriction @can_change_domain_users_only_restriction end |
#can_change_download_restriction ⇒ Boolean Also known as: can_change_download_restriction?
Output only. Whether the current user can change organizer-applied download
restrictions of this shared drive.
Corresponds to the JSON property canChangeDownloadRestriction
1553 1554 1555 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1553 def can_change_download_restriction @can_change_download_restriction end |
#can_change_drive_background ⇒ Boolean Also known as: can_change_drive_background?
Output only. Whether the current user can change the background of this shared
drive.
Corresponds to the JSON property canChangeDriveBackground
1560 1561 1562 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1560 def can_change_drive_background @can_change_drive_background end |
#can_change_drive_members_only_restriction ⇒ Boolean Also known as: can_change_drive_members_only_restriction?
Output only. Whether the current user can change the driveMembersOnly
restriction of this shared drive.
Corresponds to the JSON property canChangeDriveMembersOnlyRestriction
1567 1568 1569 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1567 def can_change_drive_members_only_restriction @can_change_drive_members_only_restriction end |
#can_change_sharing_folders_requires_organizer_permission_restriction ⇒ Boolean Also known as: can_change_sharing_folders_requires_organizer_permission_restriction?
Output only. Whether the current user can change the
sharingFoldersRequiresOrganizerPermission restriction of this shared drive.
Corresponds to the JSON property canChangeSharingFoldersRequiresOrganizerPermissionRestriction
1574 1575 1576 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1574 def @can_change_sharing_folders_requires_organizer_permission_restriction end |
#can_comment ⇒ Boolean Also known as: can_comment?
Output only. Whether the current user can comment on files in this shared
drive.
Corresponds to the JSON property canComment
1581 1582 1583 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1581 def can_comment @can_comment end |
#can_copy ⇒ Boolean Also known as: can_copy?
Output only. Whether the current user can copy files in this shared drive.
Corresponds to the JSON property canCopy
1587 1588 1589 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1587 def can_copy @can_copy end |
#can_delete_children ⇒ Boolean Also known as: can_delete_children?
Output only. Whether the current user can delete children from folders in this
shared drive.
Corresponds to the JSON property canDeleteChildren
1594 1595 1596 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1594 def can_delete_children @can_delete_children end |
#can_delete_drive ⇒ Boolean Also known as: can_delete_drive?
Output only. Whether the current user can delete this shared drive. Attempting
to delete the shared drive may still fail if there are untrashed items inside
the shared drive.
Corresponds to the JSON property canDeleteDrive
1602 1603 1604 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1602 def can_delete_drive @can_delete_drive end |
#can_download ⇒ Boolean Also known as: can_download?
Output only. Whether the current user can download files in this shared drive.
Corresponds to the JSON property canDownload
1608 1609 1610 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1608 def can_download @can_download end |
#can_edit ⇒ Boolean Also known as: can_edit?
Output only. Whether the current user can edit files in this shared drive
Corresponds to the JSON property canEdit
1614 1615 1616 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1614 def can_edit @can_edit end |
#can_list_children ⇒ Boolean Also known as: can_list_children?
Output only. Whether the current user can list the children of folders in this
shared drive.
Corresponds to the JSON property canListChildren
1621 1622 1623 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1621 def can_list_children @can_list_children end |
#can_manage_members ⇒ Boolean Also known as: can_manage_members?
Output only. Whether the current user can add members to this shared drive or
remove them or change their role.
Corresponds to the JSON property canManageMembers
1628 1629 1630 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1628 def can_manage_members @can_manage_members end |
#can_read_revisions ⇒ Boolean Also known as: can_read_revisions?
Output only. Whether the current user can read the revisions resource of files
in this shared drive.
Corresponds to the JSON property canReadRevisions
1635 1636 1637 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1635 def can_read_revisions @can_read_revisions end |
#can_rename ⇒ Boolean Also known as: can_rename?
Output only. Whether the current user can rename files or folders in this
shared drive.
Corresponds to the JSON property canRename
1642 1643 1644 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1642 def can_rename @can_rename end |
#can_rename_drive ⇒ Boolean Also known as: can_rename_drive?
Output only. Whether the current user can rename this shared drive.
Corresponds to the JSON property canRenameDrive
1648 1649 1650 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1648 def can_rename_drive @can_rename_drive end |
#can_reset_drive_restrictions ⇒ Boolean Also known as: can_reset_drive_restrictions?
Output only. Whether the current user can reset the shared drive restrictions
to defaults.
Corresponds to the JSON property canResetDriveRestrictions
1655 1656 1657 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1655 def can_reset_drive_restrictions @can_reset_drive_restrictions end |
#can_share ⇒ Boolean Also known as:
Output only. Whether the current user can share files or folders in this
shared drive.
Corresponds to the JSON property canShare
1662 1663 1664 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1662 def can_share @can_share end |
#can_trash_children ⇒ Boolean Also known as: can_trash_children?
Output only. Whether the current user can trash children from folders in this
shared drive.
Corresponds to the JSON property canTrashChildren
1669 1670 1671 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1669 def can_trash_children @can_trash_children end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1677 def update!(**args) @can_add_children = args[:can_add_children] if args.key?(:can_add_children) @can_change_copy_requires_writer_permission_restriction = args[:can_change_copy_requires_writer_permission_restriction] if args.key?(:can_change_copy_requires_writer_permission_restriction) @can_change_domain_users_only_restriction = args[:can_change_domain_users_only_restriction] if args.key?(:can_change_domain_users_only_restriction) @can_change_download_restriction = args[:can_change_download_restriction] if args.key?(:can_change_download_restriction) @can_change_drive_background = args[:can_change_drive_background] if args.key?(:can_change_drive_background) @can_change_drive_members_only_restriction = args[:can_change_drive_members_only_restriction] if args.key?(:can_change_drive_members_only_restriction) @can_change_sharing_folders_requires_organizer_permission_restriction = args[:can_change_sharing_folders_requires_organizer_permission_restriction] if args.key?(:can_change_sharing_folders_requires_organizer_permission_restriction) @can_comment = args[:can_comment] if args.key?(:can_comment) @can_copy = args[:can_copy] if args.key?(:can_copy) @can_delete_children = args[:can_delete_children] if args.key?(:can_delete_children) @can_delete_drive = args[:can_delete_drive] if args.key?(:can_delete_drive) @can_download = args[:can_download] if args.key?(:can_download) @can_edit = args[:can_edit] if args.key?(:can_edit) @can_list_children = args[:can_list_children] if args.key?(:can_list_children) @can_manage_members = args[:can_manage_members] if args.key?(:can_manage_members) @can_read_revisions = args[:can_read_revisions] if args.key?(:can_read_revisions) @can_rename = args[:can_rename] if args.key?(:can_rename) @can_rename_drive = args[:can_rename_drive] if args.key?(:can_rename_drive) @can_reset_drive_restrictions = args[:can_reset_drive_restrictions] if args.key?(:can_reset_drive_restrictions) @can_share = args[:can_share] if args.key?(:can_share) @can_trash_children = args[:can_trash_children] if args.key?(:can_trash_children) end |