Class: Google::Apis::DriveV3::Drive::Capabilities

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Output only. Capabilities the current user has on this shared drive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Capabilities

Returns a new instance of Capabilities.



1564
1565
1566
# File 'lib/google/apis/drive_v3/classes.rb', line 1564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_add_childrenBoolean Also known as: can_add_children?

Output only. Whether the current user can add children to folders in this shared drive. Corresponds to the JSON property canAddChildren

Returns:

  • (Boolean)


1424
1425
1426
# File 'lib/google/apis/drive_v3/classes.rb', line 1424

def can_add_children
  @can_add_children
end

#can_change_copy_requires_writer_permission_restrictionBoolean Also known as: can_change_copy_requires_writer_permission_restriction?

Output only. Whether the current user can change the copyRequiresWriterPermission restriction of this shared drive. Corresponds to the JSON property canChangeCopyRequiresWriterPermissionRestriction

Returns:

  • (Boolean)


1431
1432
1433
# File 'lib/google/apis/drive_v3/classes.rb', line 1431

def can_change_copy_requires_writer_permission_restriction
  @can_change_copy_requires_writer_permission_restriction
end

#can_change_domain_users_only_restrictionBoolean Also known as: can_change_domain_users_only_restriction?

Output only. Whether the current user can change the domainUsersOnly restriction of this shared drive. Corresponds to the JSON property canChangeDomainUsersOnlyRestriction

Returns:

  • (Boolean)


1438
1439
1440
# File 'lib/google/apis/drive_v3/classes.rb', line 1438

def can_change_domain_users_only_restriction
  @can_change_domain_users_only_restriction
end

#can_change_download_restrictionBoolean Also known as: can_change_download_restriction?

Output only. Whether the current user can change organizer-applied download restrictions of this shared drive. Corresponds to the JSON property canChangeDownloadRestriction

Returns:

  • (Boolean)


1445
1446
1447
# File 'lib/google/apis/drive_v3/classes.rb', line 1445

def can_change_download_restriction
  @can_change_download_restriction
end

#can_change_drive_backgroundBoolean Also known as: can_change_drive_background?

Output only. Whether the current user can change the background of this shared drive. Corresponds to the JSON property canChangeDriveBackground

Returns:

  • (Boolean)


1452
1453
1454
# File 'lib/google/apis/drive_v3/classes.rb', line 1452

def can_change_drive_background
  @can_change_drive_background
end

#can_change_drive_members_only_restrictionBoolean Also known as: can_change_drive_members_only_restriction?

Output only. Whether the current user can change the driveMembersOnly restriction of this shared drive. Corresponds to the JSON property canChangeDriveMembersOnlyRestriction

Returns:

  • (Boolean)


1459
1460
1461
# File 'lib/google/apis/drive_v3/classes.rb', line 1459

def can_change_drive_members_only_restriction
  @can_change_drive_members_only_restriction
end

#can_change_sharing_folders_requires_organizer_permission_restrictionBoolean Also known as: can_change_sharing_folders_requires_organizer_permission_restriction?

Output only. Whether the current user can change the sharingFoldersRequiresOrganizerPermission restriction of this shared drive. Corresponds to the JSON property canChangeSharingFoldersRequiresOrganizerPermissionRestriction

Returns:

  • (Boolean)


1466
1467
1468
# File 'lib/google/apis/drive_v3/classes.rb', line 1466

def can_change_sharing_folders_requires_organizer_permission_restriction
  @can_change_sharing_folders_requires_organizer_permission_restriction
end

#can_commentBoolean Also known as: can_comment?

Output only. Whether the current user can comment on files in this shared drive. Corresponds to the JSON property canComment

Returns:

  • (Boolean)


1473
1474
1475
# File 'lib/google/apis/drive_v3/classes.rb', line 1473

def can_comment
  @can_comment
end

#can_copyBoolean Also known as: can_copy?

Output only. Whether the current user can copy files in this shared drive. Corresponds to the JSON property canCopy

Returns:

  • (Boolean)


1479
1480
1481
# File 'lib/google/apis/drive_v3/classes.rb', line 1479

def can_copy
  @can_copy
end

#can_delete_childrenBoolean Also known as: can_delete_children?

Output only. Whether the current user can delete children from folders in this shared drive. Corresponds to the JSON property canDeleteChildren

Returns:

  • (Boolean)


1486
1487
1488
# File 'lib/google/apis/drive_v3/classes.rb', line 1486

def can_delete_children
  @can_delete_children
end

#can_delete_driveBoolean Also known as: can_delete_drive?

Output only. Whether the current user can delete this shared drive. Attempting to delete the shared drive may still fail if there are untrashed items inside the shared drive. Corresponds to the JSON property canDeleteDrive

Returns:

  • (Boolean)


1494
1495
1496
# File 'lib/google/apis/drive_v3/classes.rb', line 1494

def can_delete_drive
  @can_delete_drive
end

#can_downloadBoolean Also known as: can_download?

Output only. Whether the current user can download files in this shared drive. Corresponds to the JSON property canDownload

Returns:

  • (Boolean)


1500
1501
1502
# File 'lib/google/apis/drive_v3/classes.rb', line 1500

def can_download
  @can_download
end

#can_editBoolean Also known as: can_edit?

Output only. Whether the current user can edit files in this shared drive Corresponds to the JSON property canEdit

Returns:

  • (Boolean)


1506
1507
1508
# File 'lib/google/apis/drive_v3/classes.rb', line 1506

def can_edit
  @can_edit
end

#can_list_childrenBoolean Also known as: can_list_children?

Output only. Whether the current user can list the children of folders in this shared drive. Corresponds to the JSON property canListChildren

Returns:

  • (Boolean)


1513
1514
1515
# File 'lib/google/apis/drive_v3/classes.rb', line 1513

def can_list_children
  @can_list_children
end

#can_manage_membersBoolean Also known as: can_manage_members?

Output only. Whether the current user can add members to this shared drive or remove them or change their role. Corresponds to the JSON property canManageMembers

Returns:

  • (Boolean)


1520
1521
1522
# File 'lib/google/apis/drive_v3/classes.rb', line 1520

def can_manage_members
  @can_manage_members
end

#can_read_revisionsBoolean Also known as: can_read_revisions?

Output only. Whether the current user can read the revisions resource of files in this shared drive. Corresponds to the JSON property canReadRevisions

Returns:

  • (Boolean)


1527
1528
1529
# File 'lib/google/apis/drive_v3/classes.rb', line 1527

def can_read_revisions
  @can_read_revisions
end

#can_renameBoolean Also known as: can_rename?

Output only. Whether the current user can rename files or folders in this shared drive. Corresponds to the JSON property canRename

Returns:

  • (Boolean)


1534
1535
1536
# File 'lib/google/apis/drive_v3/classes.rb', line 1534

def can_rename
  @can_rename
end

#can_rename_driveBoolean Also known as: can_rename_drive?

Output only. Whether the current user can rename this shared drive. Corresponds to the JSON property canRenameDrive

Returns:

  • (Boolean)


1540
1541
1542
# File 'lib/google/apis/drive_v3/classes.rb', line 1540

def can_rename_drive
  @can_rename_drive
end

#can_reset_drive_restrictionsBoolean Also known as: can_reset_drive_restrictions?

Output only. Whether the current user can reset the shared drive restrictions to defaults. Corresponds to the JSON property canResetDriveRestrictions

Returns:

  • (Boolean)


1547
1548
1549
# File 'lib/google/apis/drive_v3/classes.rb', line 1547

def can_reset_drive_restrictions
  @can_reset_drive_restrictions
end

#can_shareBoolean Also known as: can_share?

Output only. Whether the current user can share files or folders in this shared drive. Corresponds to the JSON property canShare

Returns:

  • (Boolean)


1554
1555
1556
# File 'lib/google/apis/drive_v3/classes.rb', line 1554

def can_share
  @can_share
end

#can_trash_childrenBoolean Also known as: can_trash_children?

Output only. Whether the current user can trash children from folders in this shared drive. Corresponds to the JSON property canTrashChildren

Returns:

  • (Boolean)


1561
1562
1563
# File 'lib/google/apis/drive_v3/classes.rb', line 1561

def can_trash_children
  @can_trash_children
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
# File 'lib/google/apis/drive_v3/classes.rb', line 1569

def update!(**args)
  @can_add_children = args[:can_add_children] if args.key?(:can_add_children)
  @can_change_copy_requires_writer_permission_restriction = args[:can_change_copy_requires_writer_permission_restriction] if args.key?(:can_change_copy_requires_writer_permission_restriction)
  @can_change_domain_users_only_restriction = args[:can_change_domain_users_only_restriction] if args.key?(:can_change_domain_users_only_restriction)
  @can_change_download_restriction = args[:can_change_download_restriction] if args.key?(:can_change_download_restriction)
  @can_change_drive_background = args[:can_change_drive_background] if args.key?(:can_change_drive_background)
  @can_change_drive_members_only_restriction = args[:can_change_drive_members_only_restriction] if args.key?(:can_change_drive_members_only_restriction)
  @can_change_sharing_folders_requires_organizer_permission_restriction = args[:can_change_sharing_folders_requires_organizer_permission_restriction] if args.key?(:can_change_sharing_folders_requires_organizer_permission_restriction)
  @can_comment = args[:can_comment] if args.key?(:can_comment)
  @can_copy = args[:can_copy] if args.key?(:can_copy)
  @can_delete_children = args[:can_delete_children] if args.key?(:can_delete_children)
  @can_delete_drive = args[:can_delete_drive] if args.key?(:can_delete_drive)
  @can_download = args[:can_download] if args.key?(:can_download)
  @can_edit = args[:can_edit] if args.key?(:can_edit)
  @can_list_children = args[:can_list_children] if args.key?(:can_list_children)
  @can_manage_members = args[:can_manage_members] if args.key?(:can_manage_members)
  @can_read_revisions = args[:can_read_revisions] if args.key?(:can_read_revisions)
  @can_rename = args[:can_rename] if args.key?(:can_rename)
  @can_rename_drive = args[:can_rename_drive] if args.key?(:can_rename_drive)
  @can_reset_drive_restrictions = args[:can_reset_drive_restrictions] if args.key?(:can_reset_drive_restrictions)
  @can_share = args[:can_share] if args.key?(:can_share)
  @can_trash_children = args[:can_trash_children] if args.key?(:can_trash_children)
end