Class: Google::Apis::DriveV3::Drive::Restrictions
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::Drive::Restrictions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A set of restrictions that apply to this shared drive or items inside this
shared drive. Note that restrictions can't be set when creating a shared drive.
To add a restriction, first create a shared drive and then use drives.update
to add restrictions.
Instance Attribute Summary collapse
-
#admin_managed_restrictions ⇒ Boolean
(also: #admin_managed_restrictions?)
Whether administrative privileges on this shared drive are required to modify restrictions.
-
#copy_requires_writer_permission ⇒ Boolean
(also: #copy_requires_writer_permission?)
Whether the options to copy, print, or download files inside this shared drive, should be disabled for readers and commenters.
-
#domain_users_only ⇒ Boolean
(also: #domain_users_only?)
Whether access to this shared drive and items inside this shared drive is restricted to users of the domain to which this shared drive belongs.
-
#download_restriction ⇒ Google::Apis::DriveV3::DownloadRestriction
A restriction for copy and download of the file.
-
#drive_members_only ⇒ Boolean
(also: #drive_members_only?)
Whether access to items inside this shared drive is restricted to its members.
-
#sharing_folders_requires_organizer_permission ⇒ Boolean
(also: #sharing_folders_requires_organizer_permission?)
If true, only users with the organizer role can share folders.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Restrictions
constructor
A new instance of Restrictions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Restrictions
Returns a new instance of Restrictions.
1752 1753 1754 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_managed_restrictions ⇒ Boolean Also known as: admin_managed_restrictions?
Whether administrative privileges on this shared drive are required to modify
restrictions.
Corresponds to the JSON property adminManagedRestrictions
1713 1714 1715 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1713 def admin_managed_restrictions @admin_managed_restrictions end |
#copy_requires_writer_permission ⇒ Boolean Also known as: copy_requires_writer_permission?
Whether the options to copy, print, or download files inside this shared drive,
should be disabled for readers and commenters. When this restriction is set
to true, it will override the similarly named field to true for any file
inside this shared drive.
Corresponds to the JSON property copyRequiresWriterPermission
1722 1723 1724 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1722 def @copy_requires_writer_permission end |
#domain_users_only ⇒ Boolean Also known as: domain_users_only?
Whether access to this shared drive and items inside this shared drive is
restricted to users of the domain to which this shared drive belongs. This
restriction may be overridden by other sharing policies controlled outside of
this shared drive.
Corresponds to the JSON property domainUsersOnly
1731 1732 1733 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1731 def domain_users_only @domain_users_only end |
#download_restriction ⇒ Google::Apis::DriveV3::DownloadRestriction
A restriction for copy and download of the file.
Corresponds to the JSON property downloadRestriction
1737 1738 1739 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1737 def download_restriction @download_restriction end |
#drive_members_only ⇒ Boolean Also known as: drive_members_only?
Whether access to items inside this shared drive is restricted to its members.
Corresponds to the JSON property driveMembersOnly
1742 1743 1744 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1742 def drive_members_only @drive_members_only end |
#sharing_folders_requires_organizer_permission ⇒ Boolean Also known as:
If true, only users with the organizer role can share folders. If false, users
with either the organizer role or the file organizer role can share folders.
Corresponds to the JSON property sharingFoldersRequiresOrganizerPermission
1749 1750 1751 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1749 def @sharing_folders_requires_organizer_permission end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1757 1758 1759 1760 1761 1762 1763 1764 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1757 def update!(**args) @admin_managed_restrictions = args[:admin_managed_restrictions] if args.key?(:admin_managed_restrictions) @copy_requires_writer_permission = args[:copy_requires_writer_permission] if args.key?(:copy_requires_writer_permission) @domain_users_only = args[:domain_users_only] if args.key?(:domain_users_only) @download_restriction = args[:download_restriction] if args.key?(:download_restriction) @drive_members_only = args[:drive_members_only] if args.key?(:drive_members_only) @sharing_folders_requires_organizer_permission = args[:sharing_folders_requires_organizer_permission] if args.key?(:sharing_folders_requires_organizer_permission) end |