Class: Google::Apis::DriveV3::DriveList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::DriveList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of shared drives.
Instance Attribute Summary collapse
-
#drives ⇒ Array<Google::Apis::DriveV3::Drive>
The list of shared drives.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The page token for the next page of shared drives.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DriveList
constructor
A new instance of DriveList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DriveList
Returns a new instance of DriveList.
1787 1788 1789 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drives ⇒ Array<Google::Apis::DriveV3::Drive>
The list of shared drives. If nextPageToken is populated, then this list may
be incomplete and an additional page of results should be fetched.
Corresponds to the JSON property drives
1770 1771 1772 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1770 def drives @drives end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
driveList".
Corresponds to the JSON property kind
1776 1777 1778 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1776 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of shared drives. This will be absent if the
end of the list has been reached. If the token is rejected for any reason, it
should be discarded, and pagination should be restarted from the first page of
results. The page token is typically valid for several hours. However, if new
items are added or removed, your expected results might differ.
Corresponds to the JSON property nextPageToken
1785 1786 1787 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1785 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1792 1793 1794 1795 1796 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1792 def update!(**args) @drives = args[:drives] if args.key?(:drives) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |