Class: Google::Apis::DriveV3::DriveList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::DriveList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of shared drives.
Instance Attribute Summary collapse
-
#drives ⇒ Array<Google::Apis::DriveV3::Drive>
The list of shared drives.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The page token for the next page of shared drives.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DriveList
constructor
A new instance of DriveList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DriveList
Returns a new instance of DriveList.
1685 1686 1687 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1685 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drives ⇒ Array<Google::Apis::DriveV3::Drive>
The list of shared drives. If nextPageToken is populated, then this list may
be incomplete and an additional page of results should be fetched.
Corresponds to the JSON property drives
1668 1669 1670 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1668 def drives @drives end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
driveList".
Corresponds to the JSON property kind
1674 1675 1676 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1674 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of shared drives. This will be absent if the
end of the list has been reached. If the token is rejected for any reason, it
should be discarded, and pagination should be restarted from the first page of
results. The page token is typically valid for several hours. However, if new
items are added or removed, your expected results might differ.
Corresponds to the JSON property nextPageToken
1683 1684 1685 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1683 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1690 1691 1692 1693 1694 |
# File 'lib/google/apis/drive_v3/classes.rb', line 1690 def update!(**args) @drives = args[:drives] if args.key?(:drives) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |