Class: Google::Apis::DriveV3::File::Capabilities

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Output only. Capabilities the current user has on this file. Each capability corresponds to a fine-grained action that a user may take. For more information, see Understand file capabilities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Capabilities

Returns a new instance of Capabilities.



2501
2502
2503
# File 'lib/google/apis/drive_v3/classes.rb', line 2501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_accept_ownershipBoolean Also known as: can_accept_ownership?

Output only. Whether the current user is the pending owner of the file. Not populated for shared drive files. Corresponds to the JSON property canAcceptOwnership

Returns:

  • (Boolean)


2201
2202
2203
# File 'lib/google/apis/drive_v3/classes.rb', line 2201

def can_accept_ownership
  @can_accept_ownership
end

#can_add_childrenBoolean Also known as: can_add_children?

Output only. Whether the current user can add children to this folder. This is always false when the item isn't a folder. Corresponds to the JSON property canAddChildren

Returns:

  • (Boolean)


2208
2209
2210
# File 'lib/google/apis/drive_v3/classes.rb', line 2208

def can_add_children
  @can_add_children
end

#can_add_folder_from_another_driveBoolean Also known as: can_add_folder_from_another_drive?

Output only. Whether the current user can add a folder from another drive ( different shared drive or My Drive) to this folder. This is false when the item isn't a folder. Only populated for items in shared drives. Corresponds to the JSON property canAddFolderFromAnotherDrive

Returns:

  • (Boolean)


2216
2217
2218
# File 'lib/google/apis/drive_v3/classes.rb', line 2216

def can_add_folder_from_another_drive
  @can_add_folder_from_another_drive
end

#can_add_my_drive_parentBoolean Also known as: can_add_my_drive_parent?

Output only. Whether the current user can add a parent for the item without removing an existing parent in the same request. Not populated for shared drive files. Corresponds to the JSON property canAddMyDriveParent

Returns:

  • (Boolean)


2224
2225
2226
# File 'lib/google/apis/drive_v3/classes.rb', line 2224

def can_add_my_drive_parent
  @can_add_my_drive_parent
end

#can_change_copy_requires_writer_permissionBoolean Also known as: can_change_copy_requires_writer_permission?

Output only. Whether the current user can change the copyRequiresWriterPermission restriction of this file. Corresponds to the JSON property canChangeCopyRequiresWriterPermission

Returns:

  • (Boolean)


2231
2232
2233
# File 'lib/google/apis/drive_v3/classes.rb', line 2231

def can_change_copy_requires_writer_permission
  @can_change_copy_requires_writer_permission
end

#can_change_item_download_restrictionBoolean Also known as: can_change_item_download_restriction?

Output only. Whether the current user can change the owner or organizer- applied download restrictions of the file. Corresponds to the JSON property canChangeItemDownloadRestriction

Returns:

  • (Boolean)


2238
2239
2240
# File 'lib/google/apis/drive_v3/classes.rb', line 2238

def can_change_item_download_restriction
  @can_change_item_download_restriction
end

#can_change_security_update_enabledBoolean Also known as: can_change_security_update_enabled?

Output only. Whether the current user can change the securityUpdateEnabled field on link share metadata. Corresponds to the JSON property canChangeSecurityUpdateEnabled

Returns:

  • (Boolean)


2245
2246
2247
# File 'lib/google/apis/drive_v3/classes.rb', line 2245

def can_change_security_update_enabled
  @can_change_security_update_enabled
end

#can_change_viewers_can_copy_contentBoolean Also known as: can_change_viewers_can_copy_content?

Deprecated: Output only. Corresponds to the JSON property canChangeViewersCanCopyContent

Returns:

  • (Boolean)


2251
2252
2253
# File 'lib/google/apis/drive_v3/classes.rb', line 2251

def can_change_viewers_can_copy_content
  @can_change_viewers_can_copy_content
end

#can_commentBoolean Also known as: can_comment?

Output only. Whether the current user can comment on this file. Corresponds to the JSON property canComment

Returns:

  • (Boolean)


2257
2258
2259
# File 'lib/google/apis/drive_v3/classes.rb', line 2257

def can_comment
  @can_comment
end

#can_copyBoolean Also known as: can_copy?

Output only. Whether the current user can copy this file. For an item in a shared drive, whether the current user can copy non-folder descendants of this item, or this item if it's not a folder. Corresponds to the JSON property canCopy

Returns:

  • (Boolean)


2265
2266
2267
# File 'lib/google/apis/drive_v3/classes.rb', line 2265

def can_copy
  @can_copy
end

#can_deleteBoolean Also known as: can_delete?

Output only. Whether the current user can delete this file. Corresponds to the JSON property canDelete

Returns:

  • (Boolean)


2271
2272
2273
# File 'lib/google/apis/drive_v3/classes.rb', line 2271

def can_delete
  @can_delete
end

#can_delete_childrenBoolean Also known as: can_delete_children?

Output only. Whether the current user can delete children of this folder. This is false when the item isn't a folder. Only populated for items in shared drives. Corresponds to the JSON property canDeleteChildren

Returns:

  • (Boolean)


2279
2280
2281
# File 'lib/google/apis/drive_v3/classes.rb', line 2279

def can_delete_children
  @can_delete_children
end

#can_disable_inherited_permissionsBoolean Also known as: can_disable_inherited_permissions?

Whether a user can disable inherited permissions. Corresponds to the JSON property canDisableInheritedPermissions

Returns:

  • (Boolean)


2285
2286
2287
# File 'lib/google/apis/drive_v3/classes.rb', line 2285

def can_disable_inherited_permissions
  @can_disable_inherited_permissions
end

#can_downloadBoolean Also known as: can_download?

Output only. Whether the current user can download this file. Corresponds to the JSON property canDownload

Returns:

  • (Boolean)


2291
2292
2293
# File 'lib/google/apis/drive_v3/classes.rb', line 2291

def can_download
  @can_download
end

#can_editBoolean Also known as: can_edit?

Output only. Whether the current user can edit this file. Other factors may limit the type of changes a user can make to a file. For example, see canChangeCopyRequiresWriterPermission or canModifyContent. Corresponds to the JSON property canEdit

Returns:

  • (Boolean)


2299
2300
2301
# File 'lib/google/apis/drive_v3/classes.rb', line 2299

def can_edit
  @can_edit
end

#can_enable_inherited_permissionsBoolean Also known as: can_enable_inherited_permissions?

Whether a user can re-enable inherited permissions. Corresponds to the JSON property canEnableInheritedPermissions

Returns:

  • (Boolean)


2305
2306
2307
# File 'lib/google/apis/drive_v3/classes.rb', line 2305

def can_enable_inherited_permissions
  @can_enable_inherited_permissions
end

#can_list_childrenBoolean Also known as: can_list_children?

Output only. Whether the current user can list the children of this folder. This is always false when the item isn't a folder. Corresponds to the JSON property canListChildren

Returns:

  • (Boolean)


2312
2313
2314
# File 'lib/google/apis/drive_v3/classes.rb', line 2312

def can_list_children
  @can_list_children
end

#can_modify_contentBoolean Also known as: can_modify_content?

Output only. Whether the current user can modify the content of this file. Corresponds to the JSON property canModifyContent

Returns:

  • (Boolean)


2318
2319
2320
# File 'lib/google/apis/drive_v3/classes.rb', line 2318

def can_modify_content
  @can_modify_content
end

#can_modify_content_restrictionBoolean Also known as: can_modify_content_restriction?

Deprecated: Output only. Use one of canModifyEditorContentRestriction, canModifyOwnerContentRestriction, or canRemoveContentRestriction. Corresponds to the JSON property canModifyContentRestriction

Returns:

  • (Boolean)


2325
2326
2327
# File 'lib/google/apis/drive_v3/classes.rb', line 2325

def can_modify_content_restriction
  @can_modify_content_restriction
end

#can_modify_editor_content_restrictionBoolean Also known as: can_modify_editor_content_restriction?

Output only. Whether the current user can add or modify content restrictions on the file which are editor restricted. Corresponds to the JSON property canModifyEditorContentRestriction

Returns:

  • (Boolean)


2332
2333
2334
# File 'lib/google/apis/drive_v3/classes.rb', line 2332

def can_modify_editor_content_restriction
  @can_modify_editor_content_restriction
end

#can_modify_labelsBoolean Also known as: can_modify_labels?

Output only. Whether the current user can modify the labels on the file. Corresponds to the JSON property canModifyLabels

Returns:

  • (Boolean)


2338
2339
2340
# File 'lib/google/apis/drive_v3/classes.rb', line 2338

def can_modify_labels
  @can_modify_labels
end

#can_modify_owner_content_restrictionBoolean Also known as: can_modify_owner_content_restriction?

Output only. Whether the current user can add or modify content restrictions which are owner restricted. Corresponds to the JSON property canModifyOwnerContentRestriction

Returns:

  • (Boolean)


2345
2346
2347
# File 'lib/google/apis/drive_v3/classes.rb', line 2345

def can_modify_owner_content_restriction
  @can_modify_owner_content_restriction
end

#can_move_children_out_of_driveBoolean Also known as: can_move_children_out_of_drive?

Output only. Whether the current user can move children of this folder outside of the shared drive. This is false when the item isn't a folder. Only populated for items in shared drives. Corresponds to the JSON property canMoveChildrenOutOfDrive

Returns:

  • (Boolean)


2353
2354
2355
# File 'lib/google/apis/drive_v3/classes.rb', line 2353

def can_move_children_out_of_drive
  @can_move_children_out_of_drive
end

#can_move_children_out_of_team_driveBoolean Also known as: can_move_children_out_of_team_drive?

Deprecated: Output only. Use canMoveChildrenOutOfDrive instead. Corresponds to the JSON property canMoveChildrenOutOfTeamDrive

Returns:

  • (Boolean)


2359
2360
2361
# File 'lib/google/apis/drive_v3/classes.rb', line 2359

def can_move_children_out_of_team_drive
  @can_move_children_out_of_team_drive
end

#can_move_children_within_driveBoolean Also known as: can_move_children_within_drive?

Output only. Whether the current user can move children of this folder within this drive. This is false when the item isn't a folder. Note that a request to move the child may still fail depending on the current user's access to the child and to the destination folder. Corresponds to the JSON property canMoveChildrenWithinDrive

Returns:

  • (Boolean)


2368
2369
2370
# File 'lib/google/apis/drive_v3/classes.rb', line 2368

def can_move_children_within_drive
  @can_move_children_within_drive
end

#can_move_children_within_team_driveBoolean Also known as: can_move_children_within_team_drive?

Deprecated: Output only. Use canMoveChildrenWithinDrive instead. Corresponds to the JSON property canMoveChildrenWithinTeamDrive

Returns:

  • (Boolean)


2374
2375
2376
# File 'lib/google/apis/drive_v3/classes.rb', line 2374

def can_move_children_within_team_drive
  @can_move_children_within_team_drive
end

#can_move_item_into_team_driveBoolean Also known as: can_move_item_into_team_drive?

Deprecated: Output only. Use canMoveItemOutOfDrive instead. Corresponds to the JSON property canMoveItemIntoTeamDrive

Returns:

  • (Boolean)


2380
2381
2382
# File 'lib/google/apis/drive_v3/classes.rb', line 2380

def can_move_item_into_team_drive
  @can_move_item_into_team_drive
end

#can_move_item_out_of_driveBoolean Also known as: can_move_item_out_of_drive?

Output only. Whether the current user can move this item outside of this drive by changing its parent. Note that a request to change the parent of the item may still fail depending on the new parent that's being added. Corresponds to the JSON property canMoveItemOutOfDrive

Returns:

  • (Boolean)


2388
2389
2390
# File 'lib/google/apis/drive_v3/classes.rb', line 2388

def can_move_item_out_of_drive
  @can_move_item_out_of_drive
end

#can_move_item_out_of_team_driveBoolean Also known as: can_move_item_out_of_team_drive?

Deprecated: Output only. Use canMoveItemOutOfDrive instead. Corresponds to the JSON property canMoveItemOutOfTeamDrive

Returns:

  • (Boolean)


2394
2395
2396
# File 'lib/google/apis/drive_v3/classes.rb', line 2394

def can_move_item_out_of_team_drive
  @can_move_item_out_of_team_drive
end

#can_move_item_within_driveBoolean Also known as: can_move_item_within_drive?

Output only. Whether the current user can move this item within this drive. Note that a request to change the parent of the item may still fail depending on the new parent that's being added and the parent that is being removed. Corresponds to the JSON property canMoveItemWithinDrive

Returns:

  • (Boolean)


2402
2403
2404
# File 'lib/google/apis/drive_v3/classes.rb', line 2402

def can_move_item_within_drive
  @can_move_item_within_drive
end

#can_move_item_within_team_driveBoolean Also known as: can_move_item_within_team_drive?

Deprecated: Output only. Use canMoveItemWithinDrive instead. Corresponds to the JSON property canMoveItemWithinTeamDrive

Returns:

  • (Boolean)


2408
2409
2410
# File 'lib/google/apis/drive_v3/classes.rb', line 2408

def can_move_item_within_team_drive
  @can_move_item_within_team_drive
end

#can_move_team_drive_itemBoolean Also known as: can_move_team_drive_item?

Deprecated: Output only. Use canMoveItemWithinDrive or canMoveItemOutOfDrive instead. Corresponds to the JSON property canMoveTeamDriveItem

Returns:

  • (Boolean)


2415
2416
2417
# File 'lib/google/apis/drive_v3/classes.rb', line 2415

def can_move_team_drive_item
  @can_move_team_drive_item
end

#can_read_driveBoolean Also known as: can_read_drive?

Output only. Whether the current user can read the shared drive to which this file belongs. Only populated for items in shared drives. Corresponds to the JSON property canReadDrive

Returns:

  • (Boolean)


2422
2423
2424
# File 'lib/google/apis/drive_v3/classes.rb', line 2422

def can_read_drive
  @can_read_drive
end

#can_read_labelsBoolean Also known as: can_read_labels?

Output only. Whether the current user can read the labels on the file. Corresponds to the JSON property canReadLabels

Returns:

  • (Boolean)


2428
2429
2430
# File 'lib/google/apis/drive_v3/classes.rb', line 2428

def can_read_labels
  @can_read_labels
end

#can_read_revisionsBoolean Also known as: can_read_revisions?

Output only. Whether the current user can read the revisions resource of this file. For a shared drive item, whether revisions of non-folder descendants of this item, or this item if it's not a folder, can be read. Corresponds to the JSON property canReadRevisions

Returns:

  • (Boolean)


2436
2437
2438
# File 'lib/google/apis/drive_v3/classes.rb', line 2436

def can_read_revisions
  @can_read_revisions
end

#can_read_team_driveBoolean Also known as: can_read_team_drive?

Deprecated: Output only. Use canReadDrive instead. Corresponds to the JSON property canReadTeamDrive

Returns:

  • (Boolean)


2442
2443
2444
# File 'lib/google/apis/drive_v3/classes.rb', line 2442

def can_read_team_drive
  @can_read_team_drive
end

#can_remove_childrenBoolean Also known as: can_remove_children?

Output only. Whether the current user can remove children from this folder. This is always false when the item isn't a folder. For a folder in a shared drive, use canDeleteChildren or canTrashChildren instead. Corresponds to the JSON property canRemoveChildren

Returns:

  • (Boolean)


2450
2451
2452
# File 'lib/google/apis/drive_v3/classes.rb', line 2450

def can_remove_children
  @can_remove_children
end

#can_remove_content_restrictionBoolean Also known as: can_remove_content_restriction?

Output only. Whether there's a content restriction on the file that can be removed by the current user. Corresponds to the JSON property canRemoveContentRestriction

Returns:

  • (Boolean)


2457
2458
2459
# File 'lib/google/apis/drive_v3/classes.rb', line 2457

def can_remove_content_restriction
  @can_remove_content_restriction
end

#can_remove_my_drive_parentBoolean Also known as: can_remove_my_drive_parent?

Output only. Whether the current user can remove a parent from the item without adding another parent in the same request. Not populated for shared drive files. Corresponds to the JSON property canRemoveMyDriveParent

Returns:

  • (Boolean)


2465
2466
2467
# File 'lib/google/apis/drive_v3/classes.rb', line 2465

def can_remove_my_drive_parent
  @can_remove_my_drive_parent
end

#can_renameBoolean Also known as: can_rename?

Output only. Whether the current user can rename this file. Corresponds to the JSON property canRename

Returns:

  • (Boolean)


2471
2472
2473
# File 'lib/google/apis/drive_v3/classes.rb', line 2471

def can_rename
  @can_rename
end

#can_shareBoolean Also known as: can_share?

Output only. Whether the current user can modify the sharing settings for this file. Corresponds to the JSON property canShare

Returns:

  • (Boolean)


2478
2479
2480
# File 'lib/google/apis/drive_v3/classes.rb', line 2478

def can_share
  @can_share
end

#can_trashBoolean Also known as: can_trash?

Output only. Whether the current user can move this file to trash. Corresponds to the JSON property canTrash

Returns:

  • (Boolean)


2484
2485
2486
# File 'lib/google/apis/drive_v3/classes.rb', line 2484

def can_trash
  @can_trash
end

#can_trash_childrenBoolean Also known as: can_trash_children?

Output only. Whether the current user can trash children of this folder. This is false when the item isn't a folder. Only populated for items in shared drives. Corresponds to the JSON property canTrashChildren

Returns:

  • (Boolean)


2492
2493
2494
# File 'lib/google/apis/drive_v3/classes.rb', line 2492

def can_trash_children
  @can_trash_children
end

#can_untrashBoolean Also known as: can_untrash?

Output only. Whether the current user can restore this file from trash. Corresponds to the JSON property canUntrash

Returns:

  • (Boolean)


2498
2499
2500
# File 'lib/google/apis/drive_v3/classes.rb', line 2498

def can_untrash
  @can_untrash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2506
2507
2508
2509
2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
# File 'lib/google/apis/drive_v3/classes.rb', line 2506

def update!(**args)
  @can_accept_ownership = args[:can_accept_ownership] if args.key?(:can_accept_ownership)
  @can_add_children = args[:can_add_children] if args.key?(:can_add_children)
  @can_add_folder_from_another_drive = args[:can_add_folder_from_another_drive] if args.key?(:can_add_folder_from_another_drive)
  @can_add_my_drive_parent = args[:can_add_my_drive_parent] if args.key?(:can_add_my_drive_parent)
  @can_change_copy_requires_writer_permission = args[:can_change_copy_requires_writer_permission] if args.key?(:can_change_copy_requires_writer_permission)
  @can_change_item_download_restriction = args[:can_change_item_download_restriction] if args.key?(:can_change_item_download_restriction)
  @can_change_security_update_enabled = args[:can_change_security_update_enabled] if args.key?(:can_change_security_update_enabled)
  @can_change_viewers_can_copy_content = args[:can_change_viewers_can_copy_content] if args.key?(:can_change_viewers_can_copy_content)
  @can_comment = args[:can_comment] if args.key?(:can_comment)
  @can_copy = args[:can_copy] if args.key?(:can_copy)
  @can_delete = args[:can_delete] if args.key?(:can_delete)
  @can_delete_children = args[:can_delete_children] if args.key?(:can_delete_children)
  @can_disable_inherited_permissions = args[:can_disable_inherited_permissions] if args.key?(:can_disable_inherited_permissions)
  @can_download = args[:can_download] if args.key?(:can_download)
  @can_edit = args[:can_edit] if args.key?(:can_edit)
  @can_enable_inherited_permissions = args[:can_enable_inherited_permissions] if args.key?(:can_enable_inherited_permissions)
  @can_list_children = args[:can_list_children] if args.key?(:can_list_children)
  @can_modify_content = args[:can_modify_content] if args.key?(:can_modify_content)
  @can_modify_content_restriction = args[:can_modify_content_restriction] if args.key?(:can_modify_content_restriction)
  @can_modify_editor_content_restriction = args[:can_modify_editor_content_restriction] if args.key?(:can_modify_editor_content_restriction)
  @can_modify_labels = args[:can_modify_labels] if args.key?(:can_modify_labels)
  @can_modify_owner_content_restriction = args[:can_modify_owner_content_restriction] if args.key?(:can_modify_owner_content_restriction)
  @can_move_children_out_of_drive = args[:can_move_children_out_of_drive] if args.key?(:can_move_children_out_of_drive)
  @can_move_children_out_of_team_drive = args[:can_move_children_out_of_team_drive] if args.key?(:can_move_children_out_of_team_drive)
  @can_move_children_within_drive = args[:can_move_children_within_drive] if args.key?(:can_move_children_within_drive)
  @can_move_children_within_team_drive = args[:can_move_children_within_team_drive] if args.key?(:can_move_children_within_team_drive)
  @can_move_item_into_team_drive = args[:can_move_item_into_team_drive] if args.key?(:can_move_item_into_team_drive)
  @can_move_item_out_of_drive = args[:can_move_item_out_of_drive] if args.key?(:can_move_item_out_of_drive)
  @can_move_item_out_of_team_drive = args[:can_move_item_out_of_team_drive] if args.key?(:can_move_item_out_of_team_drive)
  @can_move_item_within_drive = args[:can_move_item_within_drive] if args.key?(:can_move_item_within_drive)
  @can_move_item_within_team_drive = args[:can_move_item_within_team_drive] if args.key?(:can_move_item_within_team_drive)
  @can_move_team_drive_item = args[:can_move_team_drive_item] if args.key?(:can_move_team_drive_item)
  @can_read_drive = args[:can_read_drive] if args.key?(:can_read_drive)
  @can_read_labels = args[:can_read_labels] if args.key?(:can_read_labels)
  @can_read_revisions = args[:can_read_revisions] if args.key?(:can_read_revisions)
  @can_read_team_drive = args[:can_read_team_drive] if args.key?(:can_read_team_drive)
  @can_remove_children = args[:can_remove_children] if args.key?(:can_remove_children)
  @can_remove_content_restriction = args[:can_remove_content_restriction] if args.key?(:can_remove_content_restriction)
  @can_remove_my_drive_parent = args[:can_remove_my_drive_parent] if args.key?(:can_remove_my_drive_parent)
  @can_rename = args[:can_rename] if args.key?(:can_rename)
  @can_share = args[:can_share] if args.key?(:can_share)
  @can_trash = args[:can_trash] if args.key?(:can_trash)
  @can_trash_children = args[:can_trash_children] if args.key?(:can_trash_children)
  @can_untrash = args[:can_untrash] if args.key?(:can_untrash)
end