Class: Google::Apis::DriveV3::File::ContentHints
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::File::ContentHints
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Additional information about the content of the file. These fields are never populated in responses.
Defined Under Namespace
Classes: Thumbnail
Instance Attribute Summary collapse
-
#indexable_text ⇒ String
Text to be indexed for the file to improve fullText queries.
-
#thumbnail ⇒ Google::Apis::DriveV3::File::ContentHints::Thumbnail
A thumbnail for the file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentHints
constructor
A new instance of ContentHints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentHints
Returns a new instance of ContentHints.
2678 2679 2680 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#indexable_text ⇒ String
Text to be indexed for the file to improve fullText queries. This is limited
to 128 KB in length and may contain HTML elements.
Corresponds to the JSON property indexableText
2670 2671 2672 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2670 def indexable_text @indexable_text end |
#thumbnail ⇒ Google::Apis::DriveV3::File::ContentHints::Thumbnail
A thumbnail for the file. This will only be used if Google Drive cannot
generate a standard thumbnail.
Corresponds to the JSON property thumbnail
2676 2677 2678 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2676 def thumbnail @thumbnail end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2683 2684 2685 2686 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2683 def update!(**args) @indexable_text = args[:indexable_text] if args.key?(:indexable_text) @thumbnail = args[:thumbnail] if args.key?(:thumbnail) end |