Class: Google::Apis::DriveV3::File::ImageMediaMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Output only. Additional metadata about image media, if available.

Defined Under Namespace

Classes: Location

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageMediaMetadata

Returns a new instance of ImageMediaMetadata.



2829
2830
2831
# File 'lib/google/apis/drive_v3/classes.rb', line 2829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apertureFloat

Output only. The aperture used to create the photo (f-number). Corresponds to the JSON property aperture

Returns:

  • (Float)


2724
2725
2726
# File 'lib/google/apis/drive_v3/classes.rb', line 2724

def aperture
  @aperture
end

#camera_makeString

Output only. The make of the camera used to create the photo. Corresponds to the JSON property cameraMake

Returns:

  • (String)


2729
2730
2731
# File 'lib/google/apis/drive_v3/classes.rb', line 2729

def camera_make
  @camera_make
end

#camera_modelString

Output only. The model of the camera used to create the photo. Corresponds to the JSON property cameraModel

Returns:

  • (String)


2734
2735
2736
# File 'lib/google/apis/drive_v3/classes.rb', line 2734

def camera_model
  @camera_model
end

#color_spaceString

Output only. The color space of the photo. Corresponds to the JSON property colorSpace

Returns:

  • (String)


2739
2740
2741
# File 'lib/google/apis/drive_v3/classes.rb', line 2739

def color_space
  @color_space
end

#exposure_biasFloat

Output only. The exposure bias of the photo (APEX value). Corresponds to the JSON property exposureBias

Returns:

  • (Float)


2744
2745
2746
# File 'lib/google/apis/drive_v3/classes.rb', line 2744

def exposure_bias
  @exposure_bias
end

#exposure_modeString

Output only. The exposure mode used to create the photo. Corresponds to the JSON property exposureMode

Returns:

  • (String)


2749
2750
2751
# File 'lib/google/apis/drive_v3/classes.rb', line 2749

def exposure_mode
  @exposure_mode
end

#exposure_timeFloat

Output only. The length of the exposure, in seconds. Corresponds to the JSON property exposureTime

Returns:

  • (Float)


2754
2755
2756
# File 'lib/google/apis/drive_v3/classes.rb', line 2754

def exposure_time
  @exposure_time
end

#flash_usedBoolean Also known as: flash_used?

Output only. Whether a flash was used to create the photo. Corresponds to the JSON property flashUsed

Returns:

  • (Boolean)


2759
2760
2761
# File 'lib/google/apis/drive_v3/classes.rb', line 2759

def flash_used
  @flash_used
end

#focal_lengthFloat

Output only. The focal length used to create the photo, in millimeters. Corresponds to the JSON property focalLength

Returns:

  • (Float)


2765
2766
2767
# File 'lib/google/apis/drive_v3/classes.rb', line 2765

def focal_length
  @focal_length
end

#heightFixnum

Output only. The height of the image in pixels. Corresponds to the JSON property height

Returns:

  • (Fixnum)


2770
2771
2772
# File 'lib/google/apis/drive_v3/classes.rb', line 2770

def height
  @height
end

#iso_speedFixnum

Output only. The ISO speed used to create the photo. Corresponds to the JSON property isoSpeed

Returns:

  • (Fixnum)


2775
2776
2777
# File 'lib/google/apis/drive_v3/classes.rb', line 2775

def iso_speed
  @iso_speed
end

#lensString

Output only. The lens used to create the photo. Corresponds to the JSON property lens

Returns:

  • (String)


2780
2781
2782
# File 'lib/google/apis/drive_v3/classes.rb', line 2780

def lens
  @lens
end

#locationGoogle::Apis::DriveV3::File::ImageMediaMetadata::Location

Output only. Geographic location information stored in the image. Corresponds to the JSON property location



2785
2786
2787
# File 'lib/google/apis/drive_v3/classes.rb', line 2785

def location
  @location
end

#max_aperture_valueFloat

Output only. The smallest f-number of the lens at the focal length used to create the photo (APEX value). Corresponds to the JSON property maxApertureValue

Returns:

  • (Float)


2791
2792
2793
# File 'lib/google/apis/drive_v3/classes.rb', line 2791

def max_aperture_value
  @max_aperture_value
end

#metering_modeString

Output only. The metering mode used to create the photo. Corresponds to the JSON property meteringMode

Returns:

  • (String)


2796
2797
2798
# File 'lib/google/apis/drive_v3/classes.rb', line 2796

def metering_mode
  @metering_mode
end

#rotationFixnum

Output only. The number of clockwise 90 degree rotations applied from the image's original orientation. Corresponds to the JSON property rotation

Returns:

  • (Fixnum)


2802
2803
2804
# File 'lib/google/apis/drive_v3/classes.rb', line 2802

def rotation
  @rotation
end

#sensorString

Output only. The type of sensor used to create the photo. Corresponds to the JSON property sensor

Returns:

  • (String)


2807
2808
2809
# File 'lib/google/apis/drive_v3/classes.rb', line 2807

def sensor
  @sensor
end

#subject_distanceFixnum

Output only. The distance to the subject of the photo, in meters. Corresponds to the JSON property subjectDistance

Returns:

  • (Fixnum)


2812
2813
2814
# File 'lib/google/apis/drive_v3/classes.rb', line 2812

def subject_distance
  @subject_distance
end

#timeString

Output only. The date and time the photo was taken (EXIF DateTime). Corresponds to the JSON property time

Returns:

  • (String)


2817
2818
2819
# File 'lib/google/apis/drive_v3/classes.rb', line 2817

def time
  @time
end

#white_balanceString

Output only. The white balance mode used to create the photo. Corresponds to the JSON property whiteBalance

Returns:

  • (String)


2822
2823
2824
# File 'lib/google/apis/drive_v3/classes.rb', line 2822

def white_balance
  @white_balance
end

#widthFixnum

Output only. The width of the image in pixels. Corresponds to the JSON property width

Returns:

  • (Fixnum)


2827
2828
2829
# File 'lib/google/apis/drive_v3/classes.rb', line 2827

def width
  @width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
# File 'lib/google/apis/drive_v3/classes.rb', line 2834

def update!(**args)
  @aperture = args[:aperture] if args.key?(:aperture)
  @camera_make = args[:camera_make] if args.key?(:camera_make)
  @camera_model = args[:camera_model] if args.key?(:camera_model)
  @color_space = args[:color_space] if args.key?(:color_space)
  @exposure_bias = args[:exposure_bias] if args.key?(:exposure_bias)
  @exposure_mode = args[:exposure_mode] if args.key?(:exposure_mode)
  @exposure_time = args[:exposure_time] if args.key?(:exposure_time)
  @flash_used = args[:flash_used] if args.key?(:flash_used)
  @focal_length = args[:focal_length] if args.key?(:focal_length)
  @height = args[:height] if args.key?(:height)
  @iso_speed = args[:iso_speed] if args.key?(:iso_speed)
  @lens = args[:lens] if args.key?(:lens)
  @location = args[:location] if args.key?(:location)
  @max_aperture_value = args[:max_aperture_value] if args.key?(:max_aperture_value)
  @metering_mode = args[:metering_mode] if args.key?(:metering_mode)
  @rotation = args[:rotation] if args.key?(:rotation)
  @sensor = args[:sensor] if args.key?(:sensor)
  @subject_distance = args[:subject_distance] if args.key?(:subject_distance)
  @time = args[:time] if args.key?(:time)
  @white_balance = args[:white_balance] if args.key?(:white_balance)
  @width = args[:width] if args.key?(:width)
end