Class: Google::Apis::DriveV3::FileList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A list of files.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileList

Returns a new instance of FileList.



3053
3054
3055
# File 'lib/google/apis/drive_v3/classes.rb', line 3053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filesArray<Google::Apis::DriveV3::File>

The list of files. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property files

Returns:



3026
3027
3028
# File 'lib/google/apis/drive_v3/classes.rb', line 3026

def files
  @files
end

#incomplete_searchBoolean Also known as: incomplete_search?

Whether the search process was incomplete. If true, then some search results might be missing, since all documents were not searched. This can occur when searching multiple drives with the allDrives corpora, but all corpora couldn' t be searched. When this happens, it's suggested that clients narrow their query by choosing a different corpus such as user or drive. Corresponds to the JSON property incompleteSearch

Returns:

  • (Boolean)


3035
3036
3037
# File 'lib/google/apis/drive_v3/classes.rb', line 3035

def incomplete_search
  @incomplete_search
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "drive# fileList". Corresponds to the JSON property kind

Returns:

  • (String)


3042
3043
3044
# File 'lib/google/apis/drive_v3/classes.rb', line 3042

def kind
  @kind
end

#next_page_tokenString

The page token for the next page of files. This will be absent if the end of the files list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. The page token is typically valid for several hours. However, if new items are added or removed, your expected results might differ. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3051
3052
3053
# File 'lib/google/apis/drive_v3/classes.rb', line 3051

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3058
3059
3060
3061
3062
3063
# File 'lib/google/apis/drive_v3/classes.rb', line 3058

def update!(**args)
  @files = args[:files] if args.key?(:files)
  @incomplete_search = args[:incomplete_search] if args.key?(:incomplete_search)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end