Class: Google::Apis::DriveV3::FileList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::FileList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of files.
Instance Attribute Summary collapse
-
#files ⇒ Array<Google::Apis::DriveV3::File>
The list of files.
-
#incomplete_search ⇒ Boolean
(also: #incomplete_search?)
Whether the search process was incomplete.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The page token for the next page of files.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileList
constructor
A new instance of FileList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileList
Returns a new instance of FileList.
3040 3041 3042 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#files ⇒ Array<Google::Apis::DriveV3::File>
The list of files. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property files
3013 3014 3015 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3013 def files @files end |
#incomplete_search ⇒ Boolean Also known as: incomplete_search?
Whether the search process was incomplete. If true, then some search results
might be missing, since all documents were not searched. This can occur when
searching multiple drives with the allDrives corpora, but all corpora couldn'
t be searched. When this happens, it's suggested that clients narrow their
query by choosing a different corpus such as user or drive.
Corresponds to the JSON property incompleteSearch
3022 3023 3024 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3022 def incomplete_search @incomplete_search end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
fileList".
Corresponds to the JSON property kind
3029 3030 3031 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3029 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of files. This will be absent if the end of
the files list has been reached. If the token is rejected for any reason, it
should be discarded, and pagination should be restarted from the first page of
results. The page token is typically valid for several hours. However, if new
items are added or removed, your expected results might differ.
Corresponds to the JSON property nextPageToken
3038 3039 3040 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3038 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3045 3046 3047 3048 3049 3050 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3045 def update!(**args) @files = args[:files] if args.key?(:files) @incomplete_search = args[:incomplete_search] if args.key?(:incomplete_search) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |