Class: Google::Apis::DriveV3::FileList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::FileList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of files.
Instance Attribute Summary collapse
-
#files ⇒ Array<Google::Apis::DriveV3::File>
The list of files.
-
#incomplete_search ⇒ Boolean
(also: #incomplete_search?)
Whether the search process was incomplete.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The page token for the next page of files.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileList
constructor
A new instance of FileList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileList
Returns a new instance of FileList.
2935 2936 2937 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2935 def initialize(**args) update!(**args) end |
Instance Attribute Details
#files ⇒ Array<Google::Apis::DriveV3::File>
The list of files. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property files
2908 2909 2910 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2908 def files @files end |
#incomplete_search ⇒ Boolean Also known as: incomplete_search?
Whether the search process was incomplete. If true, then some search results
might be missing, since all documents were not searched. This can occur when
searching multiple drives with the allDrives corpora, but all corpora couldn'
t be searched. When this happens, it's suggested that clients narrow their
query by choosing a different corpus such as user or drive.
Corresponds to the JSON property incompleteSearch
2917 2918 2919 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2917 def incomplete_search @incomplete_search end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
fileList".
Corresponds to the JSON property kind
2924 2925 2926 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2924 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of files. This will be absent if the end of
the files list has been reached. If the token is rejected for any reason, it
should be discarded, and pagination should be restarted from the first page of
results. The page token is typically valid for several hours. However, if new
items are added or removed, your expected results might differ.
Corresponds to the JSON property nextPageToken
2933 2934 2935 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2933 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2940 2941 2942 2943 2944 2945 |
# File 'lib/google/apis/drive_v3/classes.rb', line 2940 def update!(**args) @files = args[:files] if args.key?(:files) @incomplete_search = args[:incomplete_search] if args.key?(:incomplete_search) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |