Class: Google::Apis::DriveV3::LabelList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A list of labels applied to a file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LabelList

Returns a new instance of LabelList.



3211
3212
3213
# File 'lib/google/apis/drive_v3/classes.rb', line 3211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

This is always "drive#labelList". Corresponds to the JSON property kind

Returns:

  • (String)


3195
3196
3197
# File 'lib/google/apis/drive_v3/classes.rb', line 3195

def kind
  @kind
end

#labelsArray<Google::Apis::DriveV3::Label>

The list of labels. Corresponds to the JSON property labels

Returns:



3200
3201
3202
# File 'lib/google/apis/drive_v3/classes.rb', line 3200

def labels
  @labels
end

#next_page_tokenString

The page token for the next page of labels. This field will be absent if the end of the list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. The page token is typically valid for several hours. However, if new items are added or removed, your expected results might differ. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3209
3210
3211
# File 'lib/google/apis/drive_v3/classes.rb', line 3209

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3216
3217
3218
3219
3220
# File 'lib/google/apis/drive_v3/classes.rb', line 3216

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @labels = args[:labels] if args.key?(:labels)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end