Class: Google::Apis::DriveV3::ListAccessProposalsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

The response to an access proposal list request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAccessProposalsResponse

Returns a new instance of ListAccessProposalsResponse.



3385
3386
3387
# File 'lib/google/apis/drive_v3/classes.rb', line 3385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_proposalsArray<Google::Apis::DriveV3::AccessProposal>

The list of access proposals. This field is only populated in Drive API v3. Corresponds to the JSON property accessProposals



3375
3376
3377
# File 'lib/google/apis/drive_v3/classes.rb', line 3375

def access_proposals
  @access_proposals
end

#next_page_tokenString

The continuation token for the next page of results. This will be absent if the end of the results list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3383
3384
3385
# File 'lib/google/apis/drive_v3/classes.rb', line 3383

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3390
3391
3392
3393
# File 'lib/google/apis/drive_v3/classes.rb', line 3390

def update!(**args)
  @access_proposals = args[:access_proposals] if args.key?(:access_proposals)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end