Class: Google::Apis::DriveV3::PermissionList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::PermissionList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of permissions for a file.
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The page token for the next page of permissions.
-
#permissions ⇒ Array<Google::Apis::DriveV3::Permission>
The list of permissions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PermissionList
constructor
A new instance of PermissionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PermissionList
Returns a new instance of PermissionList.
3786 3787 3788 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
permissionList".
Corresponds to the JSON property kind
3768 3769 3770 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3768 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of permissions. This field will be absent if
the end of the permissions list has been reached. If the token is rejected for
any reason, it should be discarded, and pagination should be restarted from
the first page of results. The page token is typically valid for several hours.
However, if new items are added or removed, your expected results might
differ.
Corresponds to the JSON property nextPageToken
3778 3779 3780 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3778 def next_page_token @next_page_token end |
#permissions ⇒ Array<Google::Apis::DriveV3::Permission>
The list of permissions. If nextPageToken is populated, then this list may
be incomplete and an additional page of results should be fetched.
Corresponds to the JSON property permissions
3784 3785 3786 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3784 def @permissions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3791 3792 3793 3794 3795 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3791 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @permissions = args[:permissions] if args.key?(:permissions) end |