Class: Google::Apis::DriveV3::PermissionList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A list of permissions for a file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PermissionList

Returns a new instance of PermissionList.



3665
3666
3667
# File 'lib/google/apis/drive_v3/classes.rb', line 3665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Identifies what kind of resource this is. Value: the fixed string "drive# permissionList". Corresponds to the JSON property kind

Returns:

  • (String)


3647
3648
3649
# File 'lib/google/apis/drive_v3/classes.rb', line 3647

def kind
  @kind
end

#next_page_tokenString

The page token for the next page of permissions. This field will be absent if the end of the permissions list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. The page token is typically valid for several hours. However, if new items are added or removed, your expected results might differ. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3657
3658
3659
# File 'lib/google/apis/drive_v3/classes.rb', line 3657

def next_page_token
  @next_page_token
end

#permissionsArray<Google::Apis::DriveV3::Permission>

The list of permissions. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property permissions



3663
3664
3665
# File 'lib/google/apis/drive_v3/classes.rb', line 3663

def permissions
  @permissions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3670
3671
3672
3673
3674
# File 'lib/google/apis/drive_v3/classes.rb', line 3670

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @permissions = args[:permissions] if args.key?(:permissions)
end