Class: Google::Apis::DriveV3::Reply

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A reply to a comment on a file. Some resource methods (such as replies.update ) require a replyId. Use the replies.list method to retrieve the ID for a reply.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reply

Returns a new instance of Reply.



3746
3747
3748
# File 'lib/google/apis/drive_v3/classes.rb', line 3746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

The action the reply performed to the parent comment. The supported values are:

  • resolve * reopen Corresponds to the JSON property action

Returns:

  • (String)


3687
3688
3689
# File 'lib/google/apis/drive_v3/classes.rb', line 3687

def action
  @action
end

#assignee_email_addressString

Output only. The email address of the user assigned to this comment. If no user is assigned, the field is unset. Corresponds to the JSON property assigneeEmailAddress

Returns:

  • (String)


3693
3694
3695
# File 'lib/google/apis/drive_v3/classes.rb', line 3693

def assignee_email_address
  @assignee_email_address
end

#authorGoogle::Apis::DriveV3::User

Information about a Drive user. Corresponds to the JSON property author



3698
3699
3700
# File 'lib/google/apis/drive_v3/classes.rb', line 3698

def author
  @author
end

#contentString

The plain text content of the reply. This field is used for setting the content, while htmlContent should be displayed. This field is required by the create method if no action value is specified. Corresponds to the JSON property content

Returns:

  • (String)


3705
3706
3707
# File 'lib/google/apis/drive_v3/classes.rb', line 3705

def content
  @content
end

#created_timeDateTime

The time at which the reply was created (RFC 3339 date-time). Corresponds to the JSON property createdTime

Returns:

  • (DateTime)


3710
3711
3712
# File 'lib/google/apis/drive_v3/classes.rb', line 3710

def created_time
  @created_time
end

#deletedBoolean Also known as: deleted?

Output only. Whether the reply has been deleted. A deleted reply has no content. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


3716
3717
3718
# File 'lib/google/apis/drive_v3/classes.rb', line 3716

def deleted
  @deleted
end

#html_contentString

Output only. The content of the reply with HTML formatting. Corresponds to the JSON property htmlContent

Returns:

  • (String)


3722
3723
3724
# File 'lib/google/apis/drive_v3/classes.rb', line 3722

def html_content
  @html_content
end

#idString

Output only. The ID of the reply. Corresponds to the JSON property id

Returns:

  • (String)


3727
3728
3729
# File 'lib/google/apis/drive_v3/classes.rb', line 3727

def id
  @id
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "drive#reply". Corresponds to the JSON property kind

Returns:

  • (String)


3733
3734
3735
# File 'lib/google/apis/drive_v3/classes.rb', line 3733

def kind
  @kind
end

#mentioned_email_addressesArray<String>

Output only. A list of email addresses for users mentioned in this comment. If no users are mentioned, the list is empty. Corresponds to the JSON property mentionedEmailAddresses

Returns:

  • (Array<String>)


3739
3740
3741
# File 'lib/google/apis/drive_v3/classes.rb', line 3739

def mentioned_email_addresses
  @mentioned_email_addresses
end

#modified_timeDateTime

The last time the reply was modified (RFC 3339 date-time). Corresponds to the JSON property modifiedTime

Returns:

  • (DateTime)


3744
3745
3746
# File 'lib/google/apis/drive_v3/classes.rb', line 3744

def modified_time
  @modified_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
# File 'lib/google/apis/drive_v3/classes.rb', line 3751

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @assignee_email_address = args[:assignee_email_address] if args.key?(:assignee_email_address)
  @author = args[:author] if args.key?(:author)
  @content = args[:content] if args.key?(:content)
  @created_time = args[:created_time] if args.key?(:created_time)
  @deleted = args[:deleted] if args.key?(:deleted)
  @html_content = args[:html_content] if args.key?(:html_content)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @mentioned_email_addresses = args[:mentioned_email_addresses] if args.key?(:mentioned_email_addresses)
  @modified_time = args[:modified_time] if args.key?(:modified_time)
end