Class: Google::Apis::DriveV3::ReplyList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

A list of replies to a comment on a file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplyList

Returns a new instance of ReplyList.



3968
3969
3970
# File 'lib/google/apis/drive_v3/classes.rb', line 3968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Identifies what kind of resource this is. Value: the fixed string "drive# replyList". Corresponds to the JSON property kind

Returns:

  • (String)


3951
3952
3953
# File 'lib/google/apis/drive_v3/classes.rb', line 3951

def kind
  @kind
end

#next_page_tokenString

The page token for the next page of replies. This will be absent if the end of the replies list has been reached. If the token is rejected for any reason, it should be discarded, and pagination should be restarted from the first page of results. The page token is typically valid for several hours. However, if new items are added or removed, your expected results might differ. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3960
3961
3962
# File 'lib/google/apis/drive_v3/classes.rb', line 3960

def next_page_token
  @next_page_token
end

#repliesArray<Google::Apis::DriveV3::Reply>

The list of replies. If nextPageToken is populated, then this list may be incomplete and an additional page of results should be fetched. Corresponds to the JSON property replies

Returns:



3966
3967
3968
# File 'lib/google/apis/drive_v3/classes.rb', line 3966

def replies
  @replies
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3973
3974
3975
3976
3977
# File 'lib/google/apis/drive_v3/classes.rb', line 3973

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @replies = args[:replies] if args.key?(:replies)
end