Class: Google::Apis::DriveV3::ReplyList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::ReplyList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of replies to a comment on a file.
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The page token for the next page of replies.
-
#replies ⇒ Array<Google::Apis::DriveV3::Reply>
The list of replies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplyList
constructor
A new instance of ReplyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplyList
Returns a new instance of ReplyList.
3791 3792 3793 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
replyList".
Corresponds to the JSON property kind
3774 3775 3776 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3774 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of replies. This will be absent if the end of
the replies list has been reached. If the token is rejected for any reason, it
should be discarded, and pagination should be restarted from the first page of
results. The page token is typically valid for several hours. However, if new
items are added or removed, your expected results might differ.
Corresponds to the JSON property nextPageToken
3783 3784 3785 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3783 def next_page_token @next_page_token end |
#replies ⇒ Array<Google::Apis::DriveV3::Reply>
The list of replies. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property replies
3789 3790 3791 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3789 def replies @replies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3796 3797 3798 3799 3800 |
# File 'lib/google/apis/drive_v3/classes.rb', line 3796 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @replies = args[:replies] if args.key?(:replies) end |