Class: Google::Apis::DriveV3::ResolveAccessProposalRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Request message for resolving an AccessProposal on a file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResolveAccessProposalRequest

Returns a new instance of ResolveAccessProposalRequest.



3833
3834
3835
# File 'lib/google/apis/drive_v3/classes.rb', line 3833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. The action to take on the access proposal. Corresponds to the JSON property action

Returns:

  • (String)


3810
3811
3812
# File 'lib/google/apis/drive_v3/classes.rb', line 3810

def action
  @action
end

#roleArray<String>

Optional. The roles that the approver has allowed, if any. For more information, see Roles and permissions. Note: This field is required for the ACCEPT action. Corresponds to the JSON property role

Returns:

  • (Array<String>)


3818
3819
3820
# File 'lib/google/apis/drive_v3/classes.rb', line 3818

def role
  @role
end

#send_notificationBoolean Also known as: send_notification?

Optional. Whether to send an email to the requester when the access proposal is denied or accepted. Corresponds to the JSON property sendNotification

Returns:

  • (Boolean)


3824
3825
3826
# File 'lib/google/apis/drive_v3/classes.rb', line 3824

def send_notification
  @send_notification
end

#viewString

Optional. Indicates the view for this access proposal. This should only be set when the proposal belongs to a view. Only published is supported. Corresponds to the JSON property view

Returns:

  • (String)


3831
3832
3833
# File 'lib/google/apis/drive_v3/classes.rb', line 3831

def view
  @view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3838
3839
3840
3841
3842
3843
# File 'lib/google/apis/drive_v3/classes.rb', line 3838

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @role = args[:role] if args.key?(:role)
  @send_notification = args[:send_notification] if args.key?(:send_notification)
  @view = args[:view] if args.key?(:view)
end