Class: Google::Apis::DriveV3::Revision
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::Revision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
The metadata for a revision to a file. Some resource methods (such as
revisions.update) require a revisionId. Use the revisions.list method to
retrieve the ID for a revision.
Instance Attribute Summary collapse
-
#export_links ⇒ Hash<String,String>
Output only.
-
#id ⇒ String
Output only.
-
#keep_forever ⇒ Boolean
(also: #keep_forever?)
Whether to keep this revision forever, even if it is no longer the head revision.
-
#kind ⇒ String
Output only.
-
#last_modifying_user ⇒ Google::Apis::DriveV3::User
Information about a Drive user.
-
#md5_checksum ⇒ String
Output only.
-
#mime_type ⇒ String
Output only.
-
#modified_time ⇒ DateTime
The last time the revision was modified (RFC 3339 date-time).
-
#original_filename ⇒ String
Output only.
-
#publish_auto ⇒ Boolean
(also: #publish_auto?)
Whether subsequent revisions will be automatically republished.
-
#published ⇒ Boolean
(also: #published?)
Whether this revision is published.
-
#published_link ⇒ String
Output only.
-
#published_outside_domain ⇒ Boolean
(also: #published_outside_domain?)
Whether this revision is published outside the domain.
-
#size ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Revision
constructor
A new instance of Revision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Revision
Returns a new instance of Revision.
4147 4148 4149 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_links ⇒ Hash<String,String>
Output only. Links for exporting Docs Editors files to specific formats.
Corresponds to the JSON property exportLinks
4065 4066 4067 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4065 def export_links @export_links end |
#id ⇒ String
Output only. The ID of the revision.
Corresponds to the JSON property id
4070 4071 4072 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4070 def id @id end |
#keep_forever ⇒ Boolean Also known as: keep_forever?
Whether to keep this revision forever, even if it is no longer the head
revision. If not set, the revision will be automatically purged 30 days after
newer content is uploaded. This can be set on a maximum of 200 revisions for a
file. This field is only applicable to files with binary content in Drive.
Corresponds to the JSON property keepForever
4078 4079 4080 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4078 def keep_forever @keep_forever end |
#kind ⇒ String
Output only. Identifies what kind of resource this is. Value: the fixed string
"drive#revision".
Corresponds to the JSON property kind
4085 4086 4087 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4085 def kind @kind end |
#last_modifying_user ⇒ Google::Apis::DriveV3::User
Information about a Drive user.
Corresponds to the JSON property lastModifyingUser
4090 4091 4092 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4090 def @last_modifying_user end |
#md5_checksum ⇒ String
Output only. The MD5 checksum of the revision's content. This is only
applicable to files with binary content in Drive.
Corresponds to the JSON property md5Checksum
4096 4097 4098 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4096 def md5_checksum @md5_checksum end |
#mime_type ⇒ String
Output only. The MIME type of the revision.
Corresponds to the JSON property mimeType
4101 4102 4103 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4101 def mime_type @mime_type end |
#modified_time ⇒ DateTime
The last time the revision was modified (RFC 3339 date-time).
Corresponds to the JSON property modifiedTime
4106 4107 4108 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4106 def modified_time @modified_time end |
#original_filename ⇒ String
Output only. The original filename used to create this revision. This is only
applicable to files with binary content in Drive.
Corresponds to the JSON property originalFilename
4112 4113 4114 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4112 def original_filename @original_filename end |
#publish_auto ⇒ Boolean Also known as: publish_auto?
Whether subsequent revisions will be automatically republished. This is only
applicable to Docs Editors files.
Corresponds to the JSON property publishAuto
4118 4119 4120 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4118 def publish_auto @publish_auto end |
#published ⇒ Boolean Also known as: published?
Whether this revision is published. This is only applicable to Docs Editors
files.
Corresponds to the JSON property published
4125 4126 4127 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4125 def published @published end |
#published_link ⇒ String
Output only. A link to the published revision. This is only populated for Docs
Editors files.
Corresponds to the JSON property publishedLink
4132 4133 4134 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4132 def published_link @published_link end |
#published_outside_domain ⇒ Boolean Also known as: published_outside_domain?
Whether this revision is published outside the domain. This is only applicable
to Docs Editors files.
Corresponds to the JSON property publishedOutsideDomain
4138 4139 4140 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4138 def published_outside_domain @published_outside_domain end |
#size ⇒ Fixnum
Output only. The size of the revision's content in bytes. This is only
applicable to files with binary content in Drive.
Corresponds to the JSON property size
4145 4146 4147 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4145 def size @size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4152 def update!(**args) @export_links = args[:export_links] if args.key?(:export_links) @id = args[:id] if args.key?(:id) @keep_forever = args[:keep_forever] if args.key?(:keep_forever) @kind = args[:kind] if args.key?(:kind) @last_modifying_user = args[:last_modifying_user] if args.key?(:last_modifying_user) @md5_checksum = args[:md5_checksum] if args.key?(:md5_checksum) @mime_type = args[:mime_type] if args.key?(:mime_type) @modified_time = args[:modified_time] if args.key?(:modified_time) @original_filename = args[:original_filename] if args.key?(:original_filename) @publish_auto = args[:publish_auto] if args.key?(:publish_auto) @published = args[:published] if args.key?(:published) @published_link = args[:published_link] if args.key?(:published_link) @published_outside_domain = args[:published_outside_domain] if args.key?(:published_outside_domain) @size = args[:size] if args.key?(:size) end |