Class: Google::Apis::DriveV3::Revision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

The metadata for a revision to a file. Some resource methods (such as revisions.update) require a revisionId. Use the revisions.list method to retrieve the ID for a revision.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Revision

Returns a new instance of Revision.



3968
3969
3970
# File 'lib/google/apis/drive_v3/classes.rb', line 3968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Output only. Links for exporting Docs Editors files to specific formats. Corresponds to the JSON property exportLinks

Returns:

  • (Hash<String,String>)


3886
3887
3888
# File 'lib/google/apis/drive_v3/classes.rb', line 3886

def export_links
  @export_links
end

#idString

Output only. The ID of the revision. Corresponds to the JSON property id

Returns:

  • (String)


3891
3892
3893
# File 'lib/google/apis/drive_v3/classes.rb', line 3891

def id
  @id
end

#keep_foreverBoolean Also known as: keep_forever?

Whether to keep this revision forever, even if it is no longer the head revision. If not set, the revision will be automatically purged 30 days after newer content is uploaded. This can be set on a maximum of 200 revisions for a file. This field is only applicable to files with binary content in Drive. Corresponds to the JSON property keepForever

Returns:

  • (Boolean)


3899
3900
3901
# File 'lib/google/apis/drive_v3/classes.rb', line 3899

def keep_forever
  @keep_forever
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "drive#revision". Corresponds to the JSON property kind

Returns:

  • (String)


3906
3907
3908
# File 'lib/google/apis/drive_v3/classes.rb', line 3906

def kind
  @kind
end

#last_modifying_userGoogle::Apis::DriveV3::User

Information about a Drive user. Corresponds to the JSON property lastModifyingUser



3911
3912
3913
# File 'lib/google/apis/drive_v3/classes.rb', line 3911

def last_modifying_user
  @last_modifying_user
end

#md5_checksumString

Output only. The MD5 checksum of the revision's content. This is only applicable to files with binary content in Drive. Corresponds to the JSON property md5Checksum

Returns:

  • (String)


3917
3918
3919
# File 'lib/google/apis/drive_v3/classes.rb', line 3917

def md5_checksum
  @md5_checksum
end

#mime_typeString

Output only. The MIME type of the revision. Corresponds to the JSON property mimeType

Returns:

  • (String)


3922
3923
3924
# File 'lib/google/apis/drive_v3/classes.rb', line 3922

def mime_type
  @mime_type
end

#modified_timeDateTime

The last time the revision was modified (RFC 3339 date-time). Corresponds to the JSON property modifiedTime

Returns:

  • (DateTime)


3927
3928
3929
# File 'lib/google/apis/drive_v3/classes.rb', line 3927

def modified_time
  @modified_time
end

#original_filenameString

Output only. The original filename used to create this revision. This is only applicable to files with binary content in Drive. Corresponds to the JSON property originalFilename

Returns:

  • (String)


3933
3934
3935
# File 'lib/google/apis/drive_v3/classes.rb', line 3933

def original_filename
  @original_filename
end

#publish_autoBoolean Also known as: publish_auto?

Whether subsequent revisions will be automatically republished. This is only applicable to Docs Editors files. Corresponds to the JSON property publishAuto

Returns:

  • (Boolean)


3939
3940
3941
# File 'lib/google/apis/drive_v3/classes.rb', line 3939

def publish_auto
  @publish_auto
end

#publishedBoolean Also known as: published?

Whether this revision is published. This is only applicable to Docs Editors files. Corresponds to the JSON property published

Returns:

  • (Boolean)


3946
3947
3948
# File 'lib/google/apis/drive_v3/classes.rb', line 3946

def published
  @published
end

Output only. A link to the published revision. This is only populated for Docs Editors files. Corresponds to the JSON property publishedLink

Returns:

  • (String)


3953
3954
3955
# File 'lib/google/apis/drive_v3/classes.rb', line 3953

def published_link
  @published_link
end

#published_outside_domainBoolean Also known as: published_outside_domain?

Whether this revision is published outside the domain. This is only applicable to Docs Editors files. Corresponds to the JSON property publishedOutsideDomain

Returns:

  • (Boolean)


3959
3960
3961
# File 'lib/google/apis/drive_v3/classes.rb', line 3959

def published_outside_domain
  @published_outside_domain
end

#sizeFixnum

Output only. The size of the revision's content in bytes. This is only applicable to files with binary content in Drive. Corresponds to the JSON property size

Returns:

  • (Fixnum)


3966
3967
3968
# File 'lib/google/apis/drive_v3/classes.rb', line 3966

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
# File 'lib/google/apis/drive_v3/classes.rb', line 3973

def update!(**args)
  @export_links = args[:export_links] if args.key?(:export_links)
  @id = args[:id] if args.key?(:id)
  @keep_forever = args[:keep_forever] if args.key?(:keep_forever)
  @kind = args[:kind] if args.key?(:kind)
  @last_modifying_user = args[:last_modifying_user] if args.key?(:last_modifying_user)
  @md5_checksum = args[:md5_checksum] if args.key?(:md5_checksum)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @modified_time = args[:modified_time] if args.key?(:modified_time)
  @original_filename = args[:original_filename] if args.key?(:original_filename)
  @publish_auto = args[:publish_auto] if args.key?(:publish_auto)
  @published = args[:published] if args.key?(:published)
  @published_link = args[:published_link] if args.key?(:published_link)
  @published_outside_domain = args[:published_outside_domain] if args.key?(:published_outside_domain)
  @size = args[:size] if args.key?(:size)
end