Class: Google::Apis::DriveV3::RevisionList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::RevisionList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of revisions of a file.
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The page token for the next page of revisions.
-
#revisions ⇒ Array<Google::Apis::DriveV3::Revision>
The list of revisions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RevisionList
constructor
A new instance of RevisionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RevisionList
Returns a new instance of RevisionList.
4180 4181 4182 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4180 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
revisionList".
Corresponds to the JSON property kind
4163 4164 4165 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4163 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of revisions. This will be absent if the end
of the revisions list has been reached. If the token is rejected for any
reason, it should be discarded, and pagination should be restarted from the
first page of results. The page token is typically valid for several hours.
However, if new items are added or removed, your expected results might differ.
Corresponds to the JSON property nextPageToken
4172 4173 4174 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4172 def next_page_token @next_page_token end |
#revisions ⇒ Array<Google::Apis::DriveV3::Revision>
The list of revisions. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property revisions
4178 4179 4180 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4178 def revisions @revisions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4185 4186 4187 4188 4189 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4185 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @revisions = args[:revisions] if args.key?(:revisions) end |