Class: Google::Apis::DriveV3::StartApprovalRequest
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::StartApprovalRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Allows creating an approval on a file.
Instance Attribute Summary collapse
-
#due_time ⇒ String
Optional.
-
#lock_file ⇒ Boolean
(also: #lock_file?)
Optional.
-
#message ⇒ String
Optional.
-
#reviewer_emails ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StartApprovalRequest
constructor
A new instance of StartApprovalRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StartApprovalRequest
Returns a new instance of StartApprovalRequest.
4218 4219 4220 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#due_time ⇒ String
Optional. The time that the approval is due.
Corresponds to the JSON property dueTime
4199 4200 4201 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4199 def due_time @due_time end |
#lock_file ⇒ Boolean Also known as: lock_file?
Optional. Whether to lock the file when starting the approval.
Corresponds to the JSON property lockFile
4204 4205 4206 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4204 def lock_file @lock_file end |
#message ⇒ String
Optional. A message to send to reviewers when notifying them of the approval
request.
Corresponds to the JSON property message
4211 4212 4213 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4211 def @message end |
#reviewer_emails ⇒ Array<String>
Required. The emails of the users who are set to review the approval.
Corresponds to the JSON property reviewerEmails
4216 4217 4218 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4216 def reviewer_emails @reviewer_emails end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4223 4224 4225 4226 4227 4228 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4223 def update!(**args) @due_time = args[:due_time] if args.key?(:due_time) @lock_file = args[:lock_file] if args.key?(:lock_file) @message = args[:message] if args.key?(:message) @reviewer_emails = args[:reviewer_emails] if args.key?(:reviewer_emails) end |