Class: Google::Apis::DriveV3::TeamDrive
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::TeamDrive
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Deprecated: use the drive collection instead. Next ID: 33
Defined Under Namespace
Classes: BackgroundImageFile, Capabilities, Restrictions
Instance Attribute Summary collapse
-
#background_image_file ⇒ Google::Apis::DriveV3::TeamDrive::BackgroundImageFile
The background image file for a Team Drive.
-
#background_image_link ⇒ String
A short-lived link to this Team Drive's background image.
-
#capabilities ⇒ Google::Apis::DriveV3::TeamDrive::Capabilities
Capabilities the current user has on this Team Drive.
-
#color_rgb ⇒ String
The color of this Team Drive as an RGB hex string.
-
#created_time ⇒ DateTime
The time at which the Team Drive was created (RFC 3339 date-time).
-
#id ⇒ String
The ID of this Team Drive which is also the ID of the top level folder of this Team Drive.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
The name of this Team Drive.
-
#org_unit_id ⇒ String
The organizational unit of this shared drive.
-
#restrictions ⇒ Google::Apis::DriveV3::TeamDrive::Restrictions
A set of restrictions that apply to this Team Drive or items inside this Team Drive.
-
#theme_id ⇒ String
The ID of the theme from which the background image and color will be set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TeamDrive
constructor
A new instance of TeamDrive.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TeamDrive
Returns a new instance of TeamDrive.
4388 4389 4390 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_image_file ⇒ Google::Apis::DriveV3::TeamDrive::BackgroundImageFile
The background image file for a Team Drive.
Corresponds to the JSON property backgroundImageFile
4325 4326 4327 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4325 def background_image_file @background_image_file end |
#background_image_link ⇒ String
A short-lived link to this Team Drive's background image.
Corresponds to the JSON property backgroundImageLink
4330 4331 4332 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4330 def background_image_link @background_image_link end |
#capabilities ⇒ Google::Apis::DriveV3::TeamDrive::Capabilities
Capabilities the current user has on this Team Drive.
Corresponds to the JSON property capabilities
4335 4336 4337 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4335 def capabilities @capabilities end |
#color_rgb ⇒ String
The color of this Team Drive as an RGB hex string. It can only be set on a
drive.teamdrives.update request that does not set themeId.
Corresponds to the JSON property colorRgb
4341 4342 4343 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4341 def color_rgb @color_rgb end |
#created_time ⇒ DateTime
The time at which the Team Drive was created (RFC 3339 date-time).
Corresponds to the JSON property createdTime
4346 4347 4348 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4346 def created_time @created_time end |
#id ⇒ String
The ID of this Team Drive which is also the ID of the top level folder of this
Team Drive.
Corresponds to the JSON property id
4352 4353 4354 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4352 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
teamDrive".
Corresponds to the JSON property kind
4358 4359 4360 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4358 def kind @kind end |
#name ⇒ String
The name of this Team Drive.
Corresponds to the JSON property name
4363 4364 4365 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4363 def name @name end |
#org_unit_id ⇒ String
The organizational unit of this shared drive. This field is only populated on
drives.list responses when the useDomainAdminAccess parameter is set to
true.
Corresponds to the JSON property orgUnitId
4370 4371 4372 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4370 def org_unit_id @org_unit_id end |
#restrictions ⇒ Google::Apis::DriveV3::TeamDrive::Restrictions
A set of restrictions that apply to this Team Drive or items inside this Team
Drive.
Corresponds to the JSON property restrictions
4376 4377 4378 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4376 def restrictions @restrictions end |
#theme_id ⇒ String
The ID of the theme from which the background image and color will be set. The
set of possible teamDriveThemes can be retrieved from a drive.about.get
response. When not specified on a drive.teamdrives.create request, a random
theme is chosen from which the background image and color are set. This is a
write-only field; it can only be set on requests that don't set colorRgb or
backgroundImageFile.
Corresponds to the JSON property themeId
4386 4387 4388 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4386 def theme_id @theme_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4393 def update!(**args) @background_image_file = args[:background_image_file] if args.key?(:background_image_file) @background_image_link = args[:background_image_link] if args.key?(:background_image_link) @capabilities = args[:capabilities] if args.key?(:capabilities) @color_rgb = args[:color_rgb] if args.key?(:color_rgb) @created_time = args[:created_time] if args.key?(:created_time) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) @restrictions = args[:restrictions] if args.key?(:restrictions) @theme_id = args[:theme_id] if args.key?(:theme_id) end |