Class: Google::Apis::DriveV3::TeamDrive

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Deprecated: use the drive collection instead. Next ID: 33

Defined Under Namespace

Classes: BackgroundImageFile, Capabilities, Restrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TeamDrive

Returns a new instance of TeamDrive.



4374
4375
4376
# File 'lib/google/apis/drive_v3/classes.rb', line 4374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_image_fileGoogle::Apis::DriveV3::TeamDrive::BackgroundImageFile

The background image file for a Team Drive. Corresponds to the JSON property backgroundImageFile



4311
4312
4313
# File 'lib/google/apis/drive_v3/classes.rb', line 4311

def background_image_file
  @background_image_file
end

A short-lived link to this Team Drive's background image. Corresponds to the JSON property backgroundImageLink

Returns:

  • (String)


4316
4317
4318
# File 'lib/google/apis/drive_v3/classes.rb', line 4316

def background_image_link
  @background_image_link
end

#capabilitiesGoogle::Apis::DriveV3::TeamDrive::Capabilities

Capabilities the current user has on this Team Drive. Corresponds to the JSON property capabilities



4321
4322
4323
# File 'lib/google/apis/drive_v3/classes.rb', line 4321

def capabilities
  @capabilities
end

#color_rgbString

The color of this Team Drive as an RGB hex string. It can only be set on a drive.teamdrives.update request that does not set themeId. Corresponds to the JSON property colorRgb

Returns:

  • (String)


4327
4328
4329
# File 'lib/google/apis/drive_v3/classes.rb', line 4327

def color_rgb
  @color_rgb
end

#created_timeDateTime

The time at which the Team Drive was created (RFC 3339 date-time). Corresponds to the JSON property createdTime

Returns:

  • (DateTime)


4332
4333
4334
# File 'lib/google/apis/drive_v3/classes.rb', line 4332

def created_time
  @created_time
end

#idString

The ID of this Team Drive which is also the ID of the top level folder of this Team Drive. Corresponds to the JSON property id

Returns:

  • (String)


4338
4339
4340
# File 'lib/google/apis/drive_v3/classes.rb', line 4338

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "drive# teamDrive". Corresponds to the JSON property kind

Returns:

  • (String)


4344
4345
4346
# File 'lib/google/apis/drive_v3/classes.rb', line 4344

def kind
  @kind
end

#nameString

The name of this Team Drive. Corresponds to the JSON property name

Returns:

  • (String)


4349
4350
4351
# File 'lib/google/apis/drive_v3/classes.rb', line 4349

def name
  @name
end

#org_unit_idString

The organizational unit of this shared drive. This field is only populated on drives.list responses when the useDomainAdminAccess parameter is set to true. Corresponds to the JSON property orgUnitId

Returns:

  • (String)


4356
4357
4358
# File 'lib/google/apis/drive_v3/classes.rb', line 4356

def org_unit_id
  @org_unit_id
end

#restrictionsGoogle::Apis::DriveV3::TeamDrive::Restrictions

A set of restrictions that apply to this Team Drive or items inside this Team Drive. Corresponds to the JSON property restrictions



4362
4363
4364
# File 'lib/google/apis/drive_v3/classes.rb', line 4362

def restrictions
  @restrictions
end

#theme_idString

The ID of the theme from which the background image and color will be set. The set of possible teamDriveThemes can be retrieved from a drive.about.get response. When not specified on a drive.teamdrives.create request, a random theme is chosen from which the background image and color are set. This is a write-only field; it can only be set on requests that don't set colorRgb or backgroundImageFile. Corresponds to the JSON property themeId

Returns:

  • (String)


4372
4373
4374
# File 'lib/google/apis/drive_v3/classes.rb', line 4372

def theme_id
  @theme_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
# File 'lib/google/apis/drive_v3/classes.rb', line 4379

def update!(**args)
  @background_image_file = args[:background_image_file] if args.key?(:background_image_file)
  @background_image_link = args[:background_image_link] if args.key?(:background_image_link)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @color_rgb = args[:color_rgb] if args.key?(:color_rgb)
  @created_time = args[:created_time] if args.key?(:created_time)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id)
  @restrictions = args[:restrictions] if args.key?(:restrictions)
  @theme_id = args[:theme_id] if args.key?(:theme_id)
end