Class: Google::Apis::DriveV3::TeamDrive
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::TeamDrive
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Deprecated: use the drive collection instead. Next ID: 33
Defined Under Namespace
Classes: BackgroundImageFile, Capabilities, Restrictions
Instance Attribute Summary collapse
-
#background_image_file ⇒ Google::Apis::DriveV3::TeamDrive::BackgroundImageFile
The background image file for a Team Drive.
-
#background_image_link ⇒ String
A short-lived link to this Team Drive's background image.
-
#capabilities ⇒ Google::Apis::DriveV3::TeamDrive::Capabilities
Capabilities the current user has on this Team Drive.
-
#color_rgb ⇒ String
The color of this Team Drive as an RGB hex string.
-
#created_time ⇒ DateTime
The time at which the Team Drive was created (RFC 3339 date-time).
-
#id ⇒ String
The ID of this Team Drive which is also the ID of the top level folder of this Team Drive.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
The name of this Team Drive.
-
#org_unit_id ⇒ String
The organizational unit of this shared drive.
-
#restrictions ⇒ Google::Apis::DriveV3::TeamDrive::Restrictions
A set of restrictions that apply to this Team Drive or items inside this Team Drive.
-
#theme_id ⇒ String
The ID of the theme from which the background image and color will be set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TeamDrive
constructor
A new instance of TeamDrive.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TeamDrive
Returns a new instance of TeamDrive.
4367 4368 4369 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4367 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_image_file ⇒ Google::Apis::DriveV3::TeamDrive::BackgroundImageFile
The background image file for a Team Drive.
Corresponds to the JSON property backgroundImageFile
4304 4305 4306 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4304 def background_image_file @background_image_file end |
#background_image_link ⇒ String
A short-lived link to this Team Drive's background image.
Corresponds to the JSON property backgroundImageLink
4309 4310 4311 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4309 def background_image_link @background_image_link end |
#capabilities ⇒ Google::Apis::DriveV3::TeamDrive::Capabilities
Capabilities the current user has on this Team Drive.
Corresponds to the JSON property capabilities
4314 4315 4316 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4314 def capabilities @capabilities end |
#color_rgb ⇒ String
The color of this Team Drive as an RGB hex string. It can only be set on a
drive.teamdrives.update request that does not set themeId.
Corresponds to the JSON property colorRgb
4320 4321 4322 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4320 def color_rgb @color_rgb end |
#created_time ⇒ DateTime
The time at which the Team Drive was created (RFC 3339 date-time).
Corresponds to the JSON property createdTime
4325 4326 4327 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4325 def created_time @created_time end |
#id ⇒ String
The ID of this Team Drive which is also the ID of the top level folder of this
Team Drive.
Corresponds to the JSON property id
4331 4332 4333 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4331 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
teamDrive".
Corresponds to the JSON property kind
4337 4338 4339 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4337 def kind @kind end |
#name ⇒ String
The name of this Team Drive.
Corresponds to the JSON property name
4342 4343 4344 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4342 def name @name end |
#org_unit_id ⇒ String
The organizational unit of this shared drive. This field is only populated on
drives.list responses when the useDomainAdminAccess parameter is set to
true.
Corresponds to the JSON property orgUnitId
4349 4350 4351 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4349 def org_unit_id @org_unit_id end |
#restrictions ⇒ Google::Apis::DriveV3::TeamDrive::Restrictions
A set of restrictions that apply to this Team Drive or items inside this Team
Drive.
Corresponds to the JSON property restrictions
4355 4356 4357 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4355 def restrictions @restrictions end |
#theme_id ⇒ String
The ID of the theme from which the background image and color will be set. The
set of possible teamDriveThemes can be retrieved from a drive.about.get
response. When not specified on a drive.teamdrives.create request, a random
theme is chosen from which the background image and color are set. This is a
write-only field; it can only be set on requests that don't set colorRgb or
backgroundImageFile.
Corresponds to the JSON property themeId
4365 4366 4367 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4365 def theme_id @theme_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4372 def update!(**args) @background_image_file = args[:background_image_file] if args.key?(:background_image_file) @background_image_link = args[:background_image_link] if args.key?(:background_image_link) @capabilities = args[:capabilities] if args.key?(:capabilities) @color_rgb = args[:color_rgb] if args.key?(:color_rgb) @created_time = args[:created_time] if args.key?(:created_time) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) @restrictions = args[:restrictions] if args.key?(:restrictions) @theme_id = args[:theme_id] if args.key?(:theme_id) end |