Class: Google::Apis::DriveV3::TeamDrive
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::TeamDrive
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Deprecated: use the drive collection instead.
Defined Under Namespace
Classes: BackgroundImageFile, Capabilities, Restrictions
Instance Attribute Summary collapse
-
#background_image_file ⇒ Google::Apis::DriveV3::TeamDrive::BackgroundImageFile
An image file and cropping parameters from which a background image for this Team Drive is set.
-
#background_image_link ⇒ String
A short-lived link to this Team Drive's background image.
-
#capabilities ⇒ Google::Apis::DriveV3::TeamDrive::Capabilities
Capabilities the current user has on this Team Drive.
-
#color_rgb ⇒ String
The color of this Team Drive as an RGB hex string.
-
#created_time ⇒ DateTime
The time at which the Team Drive was created (RFC 3339 date-time).
-
#id ⇒ String
The ID of this Team Drive which is also the ID of the top level folder of this Team Drive.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
The name of this Team Drive.
-
#org_unit_id ⇒ String
The organizational unit of this shared drive.
-
#restrictions ⇒ Google::Apis::DriveV3::TeamDrive::Restrictions
A set of restrictions that apply to this Team Drive or items inside this Team Drive.
-
#theme_id ⇒ String
The ID of the theme from which the background image and color will be set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TeamDrive
constructor
A new instance of TeamDrive.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TeamDrive
Returns a new instance of TeamDrive.
4167 4168 4169 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4167 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_image_file ⇒ Google::Apis::DriveV3::TeamDrive::BackgroundImageFile
An image file and cropping parameters from which a background image for this
Team Drive is set. This is a write only field; it can only be set on drive.
teamdrives.update requests that don't set themeId. When specified, all
fields of the backgroundImageFile must be set.
Corresponds to the JSON property backgroundImageFile
4104 4105 4106 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4104 def background_image_file @background_image_file end |
#background_image_link ⇒ String
A short-lived link to this Team Drive's background image.
Corresponds to the JSON property backgroundImageLink
4109 4110 4111 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4109 def background_image_link @background_image_link end |
#capabilities ⇒ Google::Apis::DriveV3::TeamDrive::Capabilities
Capabilities the current user has on this Team Drive.
Corresponds to the JSON property capabilities
4114 4115 4116 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4114 def capabilities @capabilities end |
#color_rgb ⇒ String
The color of this Team Drive as an RGB hex string. It can only be set on a
drive.teamdrives.update request that does not set themeId.
Corresponds to the JSON property colorRgb
4120 4121 4122 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4120 def color_rgb @color_rgb end |
#created_time ⇒ DateTime
The time at which the Team Drive was created (RFC 3339 date-time).
Corresponds to the JSON property createdTime
4125 4126 4127 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4125 def created_time @created_time end |
#id ⇒ String
The ID of this Team Drive which is also the ID of the top level folder of this
Team Drive.
Corresponds to the JSON property id
4131 4132 4133 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4131 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
teamDrive".
Corresponds to the JSON property kind
4137 4138 4139 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4137 def kind @kind end |
#name ⇒ String
The name of this Team Drive.
Corresponds to the JSON property name
4142 4143 4144 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4142 def name @name end |
#org_unit_id ⇒ String
The organizational unit of this shared drive. This field is only populated on
drives.list responses when the useDomainAdminAccess parameter is set to
true.
Corresponds to the JSON property orgUnitId
4149 4150 4151 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4149 def org_unit_id @org_unit_id end |
#restrictions ⇒ Google::Apis::DriveV3::TeamDrive::Restrictions
A set of restrictions that apply to this Team Drive or items inside this Team
Drive.
Corresponds to the JSON property restrictions
4155 4156 4157 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4155 def restrictions @restrictions end |
#theme_id ⇒ String
The ID of the theme from which the background image and color will be set. The
set of possible teamDriveThemes can be retrieved from a drive.about.get
response. When not specified on a drive.teamdrives.create request, a random
theme is chosen from which the background image and color are set. This is a
write-only field; it can only be set on requests that don't set colorRgb or
backgroundImageFile.
Corresponds to the JSON property themeId
4165 4166 4167 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4165 def theme_id @theme_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4172 4173 4174 4175 4176 4177 4178 4179 4180 4181 4182 4183 4184 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4172 def update!(**args) @background_image_file = args[:background_image_file] if args.key?(:background_image_file) @background_image_link = args[:background_image_link] if args.key?(:background_image_link) @capabilities = args[:capabilities] if args.key?(:capabilities) @color_rgb = args[:color_rgb] if args.key?(:color_rgb) @created_time = args[:created_time] if args.key?(:created_time) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) @restrictions = args[:restrictions] if args.key?(:restrictions) @theme_id = args[:theme_id] if args.key?(:theme_id) end |