Class: Google::Apis::DriveV3::TeamDrive::Capabilities
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::TeamDrive::Capabilities
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
Capabilities the current user has on this Team Drive.
Instance Attribute Summary collapse
-
#can_add_children ⇒ Boolean
(also: #can_add_children?)
Whether the current user can add children to folders in this Team Drive.
-
#can_change_copy_requires_writer_permission_restriction ⇒ Boolean
(also: #can_change_copy_requires_writer_permission_restriction?)
Whether the current user can change the
copyRequiresWriterPermissionrestriction of this Team Drive. -
#can_change_domain_users_only_restriction ⇒ Boolean
(also: #can_change_domain_users_only_restriction?)
Whether the current user can change the
domainUsersOnlyrestriction of this Team Drive. -
#can_change_download_restriction ⇒ Boolean
(also: #can_change_download_restriction?)
Output only.
-
#can_change_sharing_folders_requires_organizer_permission_restriction ⇒ Boolean
(also: #can_change_sharing_folders_requires_organizer_permission_restriction?)
Whether the current user can change the
sharingFoldersRequiresOrganizerPermissionrestriction of this Team Drive. -
#can_change_team_drive_background ⇒ Boolean
(also: #can_change_team_drive_background?)
Whether the current user can change the background of this Team Drive.
-
#can_change_team_members_only_restriction ⇒ Boolean
(also: #can_change_team_members_only_restriction?)
Whether the current user can change the
teamMembersOnlyrestriction of this Team Drive. -
#can_comment ⇒ Boolean
(also: #can_comment?)
Whether the current user can comment on files in this Team Drive.
-
#can_copy ⇒ Boolean
(also: #can_copy?)
Whether the current user can copy files in this Team Drive.
-
#can_delete_children ⇒ Boolean
(also: #can_delete_children?)
Whether the current user can delete children from folders in this Team Drive.
-
#can_delete_team_drive ⇒ Boolean
(also: #can_delete_team_drive?)
Whether the current user can delete this Team Drive.
-
#can_download ⇒ Boolean
(also: #can_download?)
Whether the current user can download files in this Team Drive.
-
#can_edit ⇒ Boolean
(also: #can_edit?)
Whether the current user can edit files in this Team Drive Corresponds to the JSON property
canEdit. -
#can_list_children ⇒ Boolean
(also: #can_list_children?)
Whether the current user can list the children of folders in this Team Drive.
-
#can_manage_members ⇒ Boolean
(also: #can_manage_members?)
Whether the current user can add members to this Team Drive or remove them or change their role.
-
#can_read_revisions ⇒ Boolean
(also: #can_read_revisions?)
Whether the current user can read the revisions resource of files in this Team Drive.
-
#can_remove_children ⇒ Boolean
(also: #can_remove_children?)
Deprecated: Use
canDeleteChildrenorcanTrashChildreninstead. -
#can_rename ⇒ Boolean
(also: #can_rename?)
Whether the current user can rename files or folders in this Team Drive.
-
#can_rename_team_drive ⇒ Boolean
(also: #can_rename_team_drive?)
Whether the current user can rename this Team Drive.
-
#can_reset_team_drive_restrictions ⇒ Boolean
(also: #can_reset_team_drive_restrictions?)
Whether the current user can reset the Team Drive restrictions to defaults.
-
#can_share ⇒ Boolean
(also: #can_share?)
Whether the current user can share files or folders in this Team Drive.
-
#can_trash_children ⇒ Boolean
(also: #can_trash_children?)
Whether the current user can trash children from folders in this Team Drive.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Capabilities
constructor
A new instance of Capabilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Capabilities
Returns a new instance of Capabilities.
4577 4578 4579 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4577 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_add_children ⇒ Boolean Also known as: can_add_children?
Whether the current user can add children to folders in this Team Drive.
Corresponds to the JSON property canAddChildren
4440 4441 4442 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4440 def can_add_children @can_add_children end |
#can_change_copy_requires_writer_permission_restriction ⇒ Boolean Also known as: can_change_copy_requires_writer_permission_restriction?
Whether the current user can change the copyRequiresWriterPermission
restriction of this Team Drive.
Corresponds to the JSON property canChangeCopyRequiresWriterPermissionRestriction
4447 4448 4449 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4447 def @can_change_copy_requires_writer_permission_restriction end |
#can_change_domain_users_only_restriction ⇒ Boolean Also known as: can_change_domain_users_only_restriction?
Whether the current user can change the domainUsersOnly restriction of this
Team Drive.
Corresponds to the JSON property canChangeDomainUsersOnlyRestriction
4454 4455 4456 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4454 def can_change_domain_users_only_restriction @can_change_domain_users_only_restriction end |
#can_change_download_restriction ⇒ Boolean Also known as: can_change_download_restriction?
Output only. Whether the current user can change organizer-applied download
restrictions of this shared drive.
Corresponds to the JSON property canChangeDownloadRestriction
4461 4462 4463 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4461 def can_change_download_restriction @can_change_download_restriction end |
#can_change_sharing_folders_requires_organizer_permission_restriction ⇒ Boolean Also known as: can_change_sharing_folders_requires_organizer_permission_restriction?
Whether the current user can change the
sharingFoldersRequiresOrganizerPermission restriction of this Team Drive.
Corresponds to the JSON property canChangeSharingFoldersRequiresOrganizerPermissionRestriction
4468 4469 4470 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4468 def @can_change_sharing_folders_requires_organizer_permission_restriction end |
#can_change_team_drive_background ⇒ Boolean Also known as: can_change_team_drive_background?
Whether the current user can change the background of this Team Drive.
Corresponds to the JSON property canChangeTeamDriveBackground
4474 4475 4476 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4474 def can_change_team_drive_background @can_change_team_drive_background end |
#can_change_team_members_only_restriction ⇒ Boolean Also known as: can_change_team_members_only_restriction?
Whether the current user can change the teamMembersOnly restriction of this
Team Drive.
Corresponds to the JSON property canChangeTeamMembersOnlyRestriction
4481 4482 4483 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4481 def can_change_team_members_only_restriction @can_change_team_members_only_restriction end |
#can_comment ⇒ Boolean Also known as: can_comment?
Whether the current user can comment on files in this Team Drive.
Corresponds to the JSON property canComment
4487 4488 4489 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4487 def can_comment @can_comment end |
#can_copy ⇒ Boolean Also known as: can_copy?
Whether the current user can copy files in this Team Drive.
Corresponds to the JSON property canCopy
4493 4494 4495 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4493 def can_copy @can_copy end |
#can_delete_children ⇒ Boolean Also known as: can_delete_children?
Whether the current user can delete children from folders in this Team Drive.
Corresponds to the JSON property canDeleteChildren
4499 4500 4501 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4499 def can_delete_children @can_delete_children end |
#can_delete_team_drive ⇒ Boolean Also known as: can_delete_team_drive?
Whether the current user can delete this Team Drive. Attempting to delete the
Team Drive may still fail if there are untrashed items inside the Team Drive.
Corresponds to the JSON property canDeleteTeamDrive
4506 4507 4508 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4506 def can_delete_team_drive @can_delete_team_drive end |
#can_download ⇒ Boolean Also known as: can_download?
Whether the current user can download files in this Team Drive.
Corresponds to the JSON property canDownload
4512 4513 4514 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4512 def can_download @can_download end |
#can_edit ⇒ Boolean Also known as: can_edit?
Whether the current user can edit files in this Team Drive
Corresponds to the JSON property canEdit
4518 4519 4520 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4518 def can_edit @can_edit end |
#can_list_children ⇒ Boolean Also known as: can_list_children?
Whether the current user can list the children of folders in this Team Drive.
Corresponds to the JSON property canListChildren
4524 4525 4526 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4524 def can_list_children @can_list_children end |
#can_manage_members ⇒ Boolean Also known as: can_manage_members?
Whether the current user can add members to this Team Drive or remove them or
change their role.
Corresponds to the JSON property canManageMembers
4531 4532 4533 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4531 def can_manage_members @can_manage_members end |
#can_read_revisions ⇒ Boolean Also known as: can_read_revisions?
Whether the current user can read the revisions resource of files in this Team
Drive.
Corresponds to the JSON property canReadRevisions
4538 4539 4540 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4538 def can_read_revisions @can_read_revisions end |
#can_remove_children ⇒ Boolean Also known as: can_remove_children?
Deprecated: Use canDeleteChildren or canTrashChildren instead.
Corresponds to the JSON property canRemoveChildren
4544 4545 4546 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4544 def can_remove_children @can_remove_children end |
#can_rename ⇒ Boolean Also known as: can_rename?
Whether the current user can rename files or folders in this Team Drive.
Corresponds to the JSON property canRename
4550 4551 4552 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4550 def can_rename @can_rename end |
#can_rename_team_drive ⇒ Boolean Also known as: can_rename_team_drive?
Whether the current user can rename this Team Drive.
Corresponds to the JSON property canRenameTeamDrive
4556 4557 4558 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4556 def can_rename_team_drive @can_rename_team_drive end |
#can_reset_team_drive_restrictions ⇒ Boolean Also known as: can_reset_team_drive_restrictions?
Whether the current user can reset the Team Drive restrictions to defaults.
Corresponds to the JSON property canResetTeamDriveRestrictions
4562 4563 4564 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4562 def can_reset_team_drive_restrictions @can_reset_team_drive_restrictions end |
#can_share ⇒ Boolean Also known as:
Whether the current user can share files or folders in this Team Drive.
Corresponds to the JSON property canShare
4568 4569 4570 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4568 def can_share @can_share end |
#can_trash_children ⇒ Boolean Also known as: can_trash_children?
Whether the current user can trash children from folders in this Team Drive.
Corresponds to the JSON property canTrashChildren
4574 4575 4576 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4574 def can_trash_children @can_trash_children end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4582 def update!(**args) @can_add_children = args[:can_add_children] if args.key?(:can_add_children) @can_change_copy_requires_writer_permission_restriction = args[:can_change_copy_requires_writer_permission_restriction] if args.key?(:can_change_copy_requires_writer_permission_restriction) @can_change_domain_users_only_restriction = args[:can_change_domain_users_only_restriction] if args.key?(:can_change_domain_users_only_restriction) @can_change_download_restriction = args[:can_change_download_restriction] if args.key?(:can_change_download_restriction) @can_change_sharing_folders_requires_organizer_permission_restriction = args[:can_change_sharing_folders_requires_organizer_permission_restriction] if args.key?(:can_change_sharing_folders_requires_organizer_permission_restriction) @can_change_team_drive_background = args[:can_change_team_drive_background] if args.key?(:can_change_team_drive_background) @can_change_team_members_only_restriction = args[:can_change_team_members_only_restriction] if args.key?(:can_change_team_members_only_restriction) @can_comment = args[:can_comment] if args.key?(:can_comment) @can_copy = args[:can_copy] if args.key?(:can_copy) @can_delete_children = args[:can_delete_children] if args.key?(:can_delete_children) @can_delete_team_drive = args[:can_delete_team_drive] if args.key?(:can_delete_team_drive) @can_download = args[:can_download] if args.key?(:can_download) @can_edit = args[:can_edit] if args.key?(:can_edit) @can_list_children = args[:can_list_children] if args.key?(:can_list_children) @can_manage_members = args[:can_manage_members] if args.key?(:can_manage_members) @can_read_revisions = args[:can_read_revisions] if args.key?(:can_read_revisions) @can_remove_children = args[:can_remove_children] if args.key?(:can_remove_children) @can_rename = args[:can_rename] if args.key?(:can_rename) @can_rename_team_drive = args[:can_rename_team_drive] if args.key?(:can_rename_team_drive) @can_reset_team_drive_restrictions = args[:can_reset_team_drive_restrictions] if args.key?(:can_reset_team_drive_restrictions) @can_share = args[:can_share] if args.key?(:can_share) @can_trash_children = args[:can_trash_children] if args.key?(:can_trash_children) end |