Class: Google::Apis::DriveV3::TeamDrive::Restrictions
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::TeamDrive::Restrictions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A set of restrictions that apply to this Team Drive or items inside this Team Drive.
Instance Attribute Summary collapse
-
#admin_managed_restrictions ⇒ Boolean
(also: #admin_managed_restrictions?)
Whether administrative privileges on this Team Drive are required to modify restrictions.
-
#copy_requires_writer_permission ⇒ Boolean
(also: #copy_requires_writer_permission?)
Whether the options to copy, print, or download files inside this Team Drive, should be disabled for readers and commenters.
-
#domain_users_only ⇒ Boolean
(also: #domain_users_only?)
Whether access to this Team Drive and items inside this Team Drive is restricted to users of the domain to which this Team Drive belongs.
-
#download_restriction ⇒ Google::Apis::DriveV3::DownloadRestriction
A restriction for copy and download of the file.
-
#sharing_folders_requires_organizer_permission ⇒ Boolean
(also: #sharing_folders_requires_organizer_permission?)
If true, only users with the organizer role can share folders.
-
#team_members_only ⇒ Boolean
(also: #team_members_only?)
Whether access to items inside this Team Drive is restricted to members of this Team Drive.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Restrictions
constructor
A new instance of Restrictions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Restrictions
Returns a new instance of Restrictions.
4664 4665 4666 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4664 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_managed_restrictions ⇒ Boolean Also known as: admin_managed_restrictions?
Whether administrative privileges on this Team Drive are required to modify
restrictions.
Corresponds to the JSON property adminManagedRestrictions
4624 4625 4626 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4624 def admin_managed_restrictions @admin_managed_restrictions end |
#copy_requires_writer_permission ⇒ Boolean Also known as: copy_requires_writer_permission?
Whether the options to copy, print, or download files inside this Team Drive,
should be disabled for readers and commenters. When this restriction is set to
true, it will override the similarly named field to true for any file
inside this Team Drive.
Corresponds to the JSON property copyRequiresWriterPermission
4633 4634 4635 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4633 def @copy_requires_writer_permission end |
#domain_users_only ⇒ Boolean Also known as: domain_users_only?
Whether access to this Team Drive and items inside this Team Drive is
restricted to users of the domain to which this Team Drive belongs. This
restriction may be overridden by other sharing policies controlled outside of
this Team Drive.
Corresponds to the JSON property domainUsersOnly
4642 4643 4644 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4642 def domain_users_only @domain_users_only end |
#download_restriction ⇒ Google::Apis::DriveV3::DownloadRestriction
A restriction for copy and download of the file.
Corresponds to the JSON property downloadRestriction
4648 4649 4650 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4648 def download_restriction @download_restriction end |
#sharing_folders_requires_organizer_permission ⇒ Boolean Also known as:
If true, only users with the organizer role can share folders. If false, users
with either the organizer role or the file organizer role can share folders.
Corresponds to the JSON property sharingFoldersRequiresOrganizerPermission
4654 4655 4656 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4654 def @sharing_folders_requires_organizer_permission end |
#team_members_only ⇒ Boolean Also known as: team_members_only?
Whether access to items inside this Team Drive is restricted to members of
this Team Drive.
Corresponds to the JSON property teamMembersOnly
4661 4662 4663 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4661 def team_members_only @team_members_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4669 def update!(**args) @admin_managed_restrictions = args[:admin_managed_restrictions] if args.key?(:admin_managed_restrictions) @copy_requires_writer_permission = args[:copy_requires_writer_permission] if args.key?(:copy_requires_writer_permission) @domain_users_only = args[:domain_users_only] if args.key?(:domain_users_only) @download_restriction = args[:download_restriction] if args.key?(:download_restriction) @sharing_folders_requires_organizer_permission = args[:sharing_folders_requires_organizer_permission] if args.key?(:sharing_folders_requires_organizer_permission) @team_members_only = args[:team_members_only] if args.key?(:team_members_only) end |