Class: Google::Apis::DriveV3::TeamDriveList
- Inherits:
-
Object
- Object
- Google::Apis::DriveV3::TeamDriveList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb
Overview
A list of Team Drives.
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The page token for the next page of Team Drives.
-
#team_drives ⇒ Array<Google::Apis::DriveV3::TeamDrive>
The list of Team Drives.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TeamDriveList
constructor
A new instance of TeamDriveList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TeamDriveList
Returns a new instance of TeamDriveList.
4705 4706 4707 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "drive#
teamDriveList".
Corresponds to the JSON property kind
4688 4689 4690 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4688 def kind @kind end |
#next_page_token ⇒ String
The page token for the next page of Team Drives. This will be absent if the
end of the Team Drives list has been reached. If the token is rejected for any
reason, it should be discarded, and pagination should be restarted from the
first page of results. The page token is typically valid for several hours.
However, if new items are added or removed, your expected results might differ.
Corresponds to the JSON property nextPageToken
4697 4698 4699 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4697 def next_page_token @next_page_token end |
#team_drives ⇒ Array<Google::Apis::DriveV3::TeamDrive>
The list of Team Drives. If nextPageToken is populated, then this list may be
incomplete and an additional page of results should be fetched.
Corresponds to the JSON property teamDrives
4703 4704 4705 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4703 def team_drives @team_drives end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4710 4711 4712 4713 4714 |
# File 'lib/google/apis/drive_v3/classes.rb', line 4710 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @team_drives = args[:team_drives] if args.key?(:team_drives) end |