Class: Google::Apis::DriveV3::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/drive_v3/classes.rb,
lib/google/apis/drive_v3/representations.rb,
lib/google/apis/drive_v3/representations.rb

Overview

Information about a Drive user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



4754
4755
4756
# File 'lib/google/apis/drive_v3/classes.rb', line 4754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. A plain text displayable name for this user. Corresponds to the JSON property displayName

Returns:

  • (String)


4724
4725
4726
# File 'lib/google/apis/drive_v3/classes.rb', line 4724

def display_name
  @display_name
end

#email_addressString

Output only. The email address of the user. This may not be present in certain contexts if the user has not made their email address visible to the requester. Corresponds to the JSON property emailAddress

Returns:

  • (String)


4730
4731
4732
# File 'lib/google/apis/drive_v3/classes.rb', line 4730

def email_address
  @email_address
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string drive#user. Corresponds to the JSON property kind

Returns:

  • (String)


4736
4737
4738
# File 'lib/google/apis/drive_v3/classes.rb', line 4736

def kind
  @kind
end

#meBoolean Also known as: me?

Output only. Whether this user is the requesting user. Corresponds to the JSON property me

Returns:

  • (Boolean)


4741
4742
4743
# File 'lib/google/apis/drive_v3/classes.rb', line 4741

def me
  @me
end

#permission_idString

Output only. The user's ID as visible in Permission resources. Corresponds to the JSON property permissionId

Returns:

  • (String)


4747
4748
4749
# File 'lib/google/apis/drive_v3/classes.rb', line 4747

def permission_id
  @permission_id
end

Output only. A link to the user's profile photo, if available. Corresponds to the JSON property photoLink

Returns:

  • (String)


4752
4753
4754
# File 'lib/google/apis/drive_v3/classes.rb', line 4752

def photo_link
  @photo_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4759
4760
4761
4762
4763
4764
4765
4766
# File 'lib/google/apis/drive_v3/classes.rb', line 4759

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @email_address = args[:email_address] if args.key?(:email_address)
  @kind = args[:kind] if args.key?(:kind)
  @me = args[:me] if args.key?(:me)
  @permission_id = args[:permission_id] if args.key?(:permission_id)
  @photo_link = args[:photo_link] if args.key?(:photo_link)
end